//------------------------------------------------------------------------------
// DiagCode.cpp
// Generated diagnostic helpers
//
// SPDX-FileCopyrightText: Michael Popoloski
// SPDX-License-Identifier: MIT
//------------------------------------------------------------------------------
#include "slang/diagnostics/AllDiags.h"

#include <ostream>

#include "slang/util/Hash.h"

namespace slang {

static const flat_hash_map<DiagCode, std::tuple<std::string_view, std::string_view, DiagnosticSeverity, std::string_view>> data = {
    {diag::BindTypeParamMismatch, std::make_tuple("BindTypeParamMismatch"sv, "bind type parameter '{}' resolves to {} in source scope but {} in target scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BindTypeParamNotFound, std::make_tuple("BindTypeParamNotFound"sv, "bind type parameter '{}' resolves to {} which cannot be found in source scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigParamsIgnored, std::make_tuple("ConfigParamsIgnored"sv, "parameter overrides provided by config rule are ignored because the target instance is using a different nested config '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIExportDifferentScope, std::make_tuple("DPIExportDifferentScope"sv, "exported subroutines must be defined in the same scope as the export directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIExportDuplicate, std::make_tuple("DPIExportDuplicate"sv, "duplicate export of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIExportDuplicateCId, std::make_tuple("DPIExportDuplicateCId"sv, "more than one DPI export with the same C identifier '{}' in the same scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIExportImportedFunc, std::make_tuple("DPIExportImportedFunc"sv, "cannot export an imported DPI subroutine"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIExportKindMismatch, std::make_tuple("DPIExportKindMismatch"sv, "mismatch between 'function' and 'task' declared in DPI export"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPISignatureMismatch, std::make_tuple("DPISignatureMismatch"sv, "more than one DPI subroutine with C identifier '{}' declared with mismatching type signatures"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefParamCycle, std::make_tuple("DefParamCycle"sv, "cyclic dependency found when resolving defparam"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefParamTargetChange, std::make_tuple("DefParamTargetChange"sv, "defparam target resolves differently post-elaboration; see '{}' vs '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExternDeclMismatchImpl, std::make_tuple("ExternDeclMismatchImpl"sv, "extern {} '{}' does not match implementation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExternDeclMismatchPrev, std::make_tuple("ExternDeclMismatchPrev"sv, "extern {} '{}' does not match previous extern definition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InfinitelyRecursiveHierarchy, std::make_tuple("InfinitelyRecursiveHierarchy"sv, "infinitely recursive instantiation of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidBindTarget, std::make_tuple("InvalidBindTarget"sv, "'{}' is not a valid bind target; only modules and interfaces are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDPICIdentifier, std::make_tuple("InvalidDPICIdentifier"sv, "'{}' is not a valid C identifier for DPI subroutine"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidParamOverrideOpt, std::make_tuple("InvalidParamOverrideOpt"sv, "'{}' is not a valid form of parameter override"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidTopModule, std::make_tuple("InvalidTopModule"sv, "'{}' is not a valid top-level module"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MaxInstanceDepthExceeded, std::make_tuple("MaxInstanceDepthExceeded"sv, "{} instantiation exceeded maximum depth of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingExportImpl, std::make_tuple("MissingExportImpl"sv, "no implementation for modport export '{}' provided by '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingExternImpl, std::make_tuple("MissingExternImpl"sv, "no implementation found for extern {} {}.{}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingExternModuleImpl, std::make_tuple("MissingExternModuleImpl"sv, "missing implementation for extern {} '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingTimeScale, std::make_tuple("MissingTimeScale"sv, "design element does not have a time scale defined but others in the design do"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultClocking, std::make_tuple("MultipleDefaultClocking"sv, "scope already has a default clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultDisable, std::make_tuple("MultipleDefaultDisable"sv, "scope already has a default disable declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleGlobalClocking, std::make_tuple("MultipleGlobalClocking"sv, "scope already has a global clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleTopDupName, std::make_tuple("MultipleTopDupName"sv, "more than one top module specified with the name '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedConfigMultipleTops, std::make_tuple("NestedConfigMultipleTops"sv, "non-top config '{}' has more than one top cell specified"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoDeclInClass, std::make_tuple("NoDeclInClass"sv, "out-of-block definition of '{}' does not match any declaration in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TopModuleIfacePort, std::make_tuple("TopModuleIfacePort"sv, "top-level module '{}' has unconnected interface port '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TopModuleRefPort, std::make_tuple("TopModuleRefPort"sv, "top-level module '{}' has unconnected 'ref' port '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TopModuleUnnamedRefPort, std::make_tuple("TopModuleUnnamedRefPort"sv, "top-level module '{}' has unconnected unnamed 'ref' port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownLibrary, std::make_tuple("UnknownLibrary"sv, "unknown library '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WrongBindTargetDef, std::make_tuple("WrongBindTargetDef"sv, "bind target '{}' is not an instance of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateDefparam, std::make_tuple("DuplicateDefparam"sv, "parameter already has a defparam override applied; ignoring this one"sv, DiagnosticSeverity::Warning, "duplicate-defparam"sv)},
    {diag::NoTopModules, std::make_tuple("NoTopModules"sv, "no top-level modules found in design"sv, DiagnosticSeverity::Warning, "missing-top"sv)},
    {diag::UnassignedVariable, std::make_tuple("UnassignedVariable"sv, "variable '{}' is never assigned a value"sv, DiagnosticSeverity::Warning, "unassigned-variable"sv)},
    {diag::UndrivenNet, std::make_tuple("UndrivenNet"sv, "net '{}' is never driven"sv, DiagnosticSeverity::Warning, "undriven-net"sv)},
    {diag::UndrivenPort, std::make_tuple("UndrivenPort"sv, "undriven output port '{}'"sv, DiagnosticSeverity::Warning, "undriven-port"sv)},
    {diag::UnusedArgument, std::make_tuple("UnusedArgument"sv, "unused formal argument '{}'"sv, DiagnosticSeverity::Warning, "unused-argument"sv)},
    {diag::UnusedAssertionDecl, std::make_tuple("UnusedAssertionDecl"sv, "unused {} '{}'"sv, DiagnosticSeverity::Warning, "unused-assertion-decl"sv)},
    {diag::UnusedButSetNet, std::make_tuple("UnusedButSetNet"sv, "net '{}' is driven but its value is never used"sv, DiagnosticSeverity::Warning, "unused-but-set-net"sv)},
    {diag::UnusedButSetPort, std::make_tuple("UnusedButSetPort"sv, "'inout' port '{}' is driven but its value is never used"sv, DiagnosticSeverity::Warning, "unused-but-set-port"sv)},
    {diag::UnusedButSetVariable, std::make_tuple("UnusedButSetVariable"sv, "variable '{}' is assigned but its value is never used"sv, DiagnosticSeverity::Warning, "unused-but-set-variable"sv)},
    {diag::UnusedDefinition, std::make_tuple("UnusedDefinition"sv, "{} definition is unused"sv, DiagnosticSeverity::Warning, "unused-def"sv)},
    {diag::UnusedGenvar, std::make_tuple("UnusedGenvar"sv, "unused genvar '{}'"sv, DiagnosticSeverity::Warning, "unused-genvar"sv)},
    {diag::UnusedImplicitNet, std::make_tuple("UnusedImplicitNet"sv, "implicit net '{}' is unused elsewhere"sv, DiagnosticSeverity::Warning, "unused-implicit-net"sv)},
    {diag::UnusedImport, std::make_tuple("UnusedImport"sv, "unused import '{}'"sv, DiagnosticSeverity::Warning, "unused-import"sv)},
    {diag::UnusedNet, std::make_tuple("UnusedNet"sv, "unused net '{}'"sv, DiagnosticSeverity::Warning, "unused-net"sv)},
    {diag::UnusedParameter, std::make_tuple("UnusedParameter"sv, "unused parameter '{}'"sv, DiagnosticSeverity::Warning, "unused-parameter"sv)},
    {diag::UnusedPort, std::make_tuple("UnusedPort"sv, "unused port signal '{}'"sv, DiagnosticSeverity::Warning, "unused-port"sv)},
    {diag::UnusedTypeParameter, std::make_tuple("UnusedTypeParameter"sv, "unused type parameter '{}'"sv, DiagnosticSeverity::Warning, "unused-type-parameter"sv)},
    {diag::UnusedTypedef, std::make_tuple("UnusedTypedef"sv, "unused typedef '{}'"sv, DiagnosticSeverity::Warning, "unused-typedef"sv)},
    {diag::UnusedVariable, std::make_tuple("UnusedVariable"sv, "unused variable '{}'"sv, DiagnosticSeverity::Warning, "unused-variable"sv)},
    {diag::UnusedWildcardImport, std::make_tuple("UnusedWildcardImport"sv, "unused wildcard import"sv, DiagnosticSeverity::Warning, "unused-wildcard-import"sv)},
    {diag::ConstEvalAssertionFailed, std::make_tuple("ConstEvalAssertionFailed"sv, "assertion failed in constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalAssociativeIndexInvalid, std::make_tuple("ConstEvalAssociativeIndexInvalid"sv, "index {} has x or z bits which is invalid"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalBitstreamCastSize, std::make_tuple("ConstEvalBitstreamCastSize"sv, "bit-stream casting argument size {} cannot fit casting type {} in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalCaseItemsNotUnique, std::make_tuple("ConstEvalCaseItemsNotUnique"sv, "more than one match found in unique case statement for value {} in constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalCheckers, std::make_tuple("ConstEvalCheckers"sv, "checkers are not allowed in constant functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalClassType, std::make_tuple("ConstEvalClassType"sv, "class types are not allowed in constant expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalCovergroupType, std::make_tuple("ConstEvalCovergroupType"sv, "covergroup types are not allowed in constant expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalDPINotConstant, std::make_tuple("ConstEvalDPINotConstant"sv, "cannot call DPI import function in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalDisableTarget, std::make_tuple("ConstEvalDisableTarget"sv, "disable statement in a constant function cannot target a block that is not currently executing"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalDynamicToFixedSize, std::make_tuple("ConstEvalDynamicToFixedSize"sv, "cannot assign {} of length {} to {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalExceededMaxCallDepth, std::make_tuple("ConstEvalExceededMaxCallDepth"sv, "constant evaluation exceeded maximum depth of {} calls"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalExceededMaxSteps, std::make_tuple("ConstEvalExceededMaxSteps"sv, "constant evaluation hit maximum step limit; possible infinite loop?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalFunctionArgDirection, std::make_tuple("ConstEvalFunctionArgDirection"sv, "cannot call a function with output, inout, or ref arguments in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalFunctionIdentifiersMustBeLocal, std::make_tuple("ConstEvalFunctionIdentifiersMustBeLocal"sv, "all identifiers that are not parameters or enums must be declared locally to a constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalFunctionInsideGenerate, std::make_tuple("ConstEvalFunctionInsideGenerate"sv, "cannot call a function declared inside a generate block in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalHierarchicalName, std::make_tuple("ConstEvalHierarchicalName"sv, "reference to '{}' by hierarchical name is not allowed in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalIdUsedInCEBeforeDecl, std::make_tuple("ConstEvalIdUsedInCEBeforeDecl"sv, "identifier '{}' is declared after the invocation of the current constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalIfItemsNotUnique, std::make_tuple("ConstEvalIfItemsNotUnique"sv, "more than one match found in unique if statement for value {} in constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalMethodNotConstant, std::make_tuple("ConstEvalMethodNotConstant"sv, "cannot call class method in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalNoCaseItemsMatched, std::make_tuple("ConstEvalNoCaseItemsMatched"sv, "no items in {} case statement matched value {} in constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalNoIfItemsMatched, std::make_tuple("ConstEvalNoIfItemsMatched"sv, "no items in {} if statement matched value {} in constant function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalNonConstVariable, std::make_tuple("ConstEvalNonConstVariable"sv, "reference to non-constant variable '{}' is not allowed in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalParallelBlockNotConst, std::make_tuple("ConstEvalParallelBlockNotConst"sv, "parallel blocks are not allowed in constant functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalParamCycle, std::make_tuple("ConstEvalParamCycle"sv, "cyclic dependency found when determining value of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalProceduralAssign, std::make_tuple("ConstEvalProceduralAssign"sv, "procedural assign and deassign statements are not allowed in constant functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalRandValue, std::make_tuple("ConstEvalRandValue"sv, "random value statements are not allowed in constant functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalReplicationCountInvalid, std::make_tuple("ConstEvalReplicationCountInvalid"sv, "string replication count {} is invalid in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalSubroutineNotConstant, std::make_tuple("ConstEvalSubroutineNotConstant"sv, "'{}' is not callable in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalTaggedUnion, std::make_tuple("ConstEvalTaggedUnion"sv, "cannot access '{}' because it is not the currently active member of the tagged union"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalTaskNotConstant, std::make_tuple("ConstEvalTaskNotConstant"sv, "cannot invoke a task in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalTimedStmtNotConst, std::make_tuple("ConstEvalTimedStmtNotConst"sv, "constant expressions cannot schedule events"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstEvalVoidNotConstant, std::make_tuple("ConstEvalVoidNotConstant"sv, "cannot call a void function in a constant expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteInCallTo, std::make_tuple("NoteInCallTo"sv, "in call to '{}'"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteSkippingFrames, std::make_tuple("NoteSkippingFrames"sv, "(skipping {} calls in backtrace; use --constexpr-backtrace-limit=0 to see all)"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::ConstEvalAssociativeElementNotFound, std::make_tuple("ConstEvalAssociativeElementNotFound"sv, "element {} does not exist in associative array"sv, DiagnosticSeverity::Warning, "elem-not-found"sv)},
    {diag::ConstEvalDynamicArrayIndex, std::make_tuple("ConstEvalDynamicArrayIndex"sv, "invalid index {} for {} of length {}"sv, DiagnosticSeverity::Warning, "dynarray-index"sv)},
    {diag::ConstEvalDynamicArrayRange, std::make_tuple("ConstEvalDynamicArrayRange"sv, "invalid range [{}:{}] for {} of length {}"sv, DiagnosticSeverity::Warning, "dynarray-range"sv)},
    {diag::ConstEvalEmptyQueue, std::make_tuple("ConstEvalEmptyQueue"sv, "pop from empty queue"sv, DiagnosticSeverity::Warning, "empty-queue"sv)},
    {diag::ConstEvalQueueRange, std::make_tuple("ConstEvalQueueRange"sv, "reversed selection range [{}:{}] for queue will always yield an empty result"sv, DiagnosticSeverity::Warning, "queue-range"sv)},
    {diag::ConstEvalStaticSkipped, std::make_tuple("ConstEvalStaticSkipped"sv, "static variable initialization is skipped in constant function calls"sv, DiagnosticSeverity::Warning, "static-skipped"sv)},
    {diag::ConstSysTaskIgnored, std::make_tuple("ConstSysTaskIgnored"sv, "system task '{}' is ignored in constant expression"sv, DiagnosticSeverity::Warning, "task-ignored"sv)},
    {diag::ConstantConversion, std::make_tuple("ConstantConversion"sv, "implicit conversion from {} to {} changes value from {} to {}"sv, DiagnosticSeverity::Warning, "constant-conversion"sv)},
    {diag::AlwaysInChecker, std::make_tuple("AlwaysInChecker"sv, "always procedures are not allowed in checkers (use always_comb, always_latch, or always_ff)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AnsiIfacePortDefault, std::make_tuple("AnsiIfacePortDefault"sv, "interface port cannot have an initializer expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionPortOutputDefault, std::make_tuple("AssertionPortOutputDefault"sv, "assertion port with 'output' or 'inout' direction cannot specify a default value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignedToLocalBodyParam, std::make_tuple("AssignedToLocalBodyParam"sv, "can't assign a value to a localparam (parameters in the body of a module are implicitly local when you have a parameter port list)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignedToLocalPortParam, std::make_tuple("AssignedToLocalPortParam"sv, "can't assign a value to a localparam"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutomaticNotAllowed, std::make_tuple("AutomaticNotAllowed"sv, "automatic variables can only be declared in procedural contexts"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadTypeParamExpr, std::make_tuple("BadTypeParamExpr"sv, "invalid initializer for type parameter '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BaseConstructorDuplicate, std::make_tuple("BaseConstructorDuplicate"sv, "cannot provide both 'super.new' as well as class constructor arguments in 'extends' clause"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BaseConstructorNotCalled, std::make_tuple("BaseConstructorNotCalled"sv, "class '{}' must provide arguments for constructing base class '{}' via 'super.new' or the 'extends' clause"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BiDiSwitchNetTypes, std::make_tuple("BiDiSwitchNetTypes"sv, "bidirectional switch cannot connect nets of two different user-defined net types or a user-defined net type and a built-in net type ('{}' and '{}')"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BindTargetPrimitive, std::make_tuple("BindTargetPrimitive"sv, "cannot bind a primitive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BindUnderBind, std::make_tuple("BindUnderBind"sv, "cannot bind an instance underneath the scope of another bind instance"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BodyForPure, std::make_tuple("BodyForPure"sv, "pure virtual methods cannot have a function body defined"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BodyForPureConstraint, std::make_tuple("BodyForPureConstraint"sv, "pure constraints cannot have a body defined"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BodyParamNoInitializer, std::make_tuple("BodyParamNoInitializer"sv, "parameter declaration is missing an initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CantDeclarePortSigned, std::make_tuple("CantDeclarePortSigned"sv, "'{}' cannot be declared '{}' because its type {} is not integral"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerBlockingAssign, std::make_tuple("CheckerBlockingAssign"sv, "blocking assignments in checkers can only occur in always_comb and always_latch procedures"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerClassBadInstantiation, std::make_tuple("CheckerClassBadInstantiation"sv, "class '{}' cannot be instantiated this way -- are you missing a 'new' expression?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerFuncArg, std::make_tuple("CheckerFuncArg"sv, "cannot call a function with output, inout, or ref arguments in a checker variable assignment"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerFuncBadInstantiation, std::make_tuple("CheckerFuncBadInstantiation"sv, "invalid syntax for calling '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerInCheckerProc, std::make_tuple("CheckerInCheckerProc"sv, "checkers cannot be instantiated inside the procedures of other checkers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerInForkJoin, std::make_tuple("CheckerInForkJoin"sv, "checkers cannot be instantiated inside fork-join blocks"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerOutputBadType, std::make_tuple("CheckerOutputBadType"sv, "checker output ports cannot be of type 'untyped', 'sequence', or 'property'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerParameterAssign, std::make_tuple("CheckerParameterAssign"sv, "checkers cannot have parameter assignments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerPortDirectionType, std::make_tuple("CheckerPortDirectionType"sv, "checker ports with an explicit direction declared must also declare a type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerTimingControl, std::make_tuple("CheckerTimingControl"sv, "procedural timing control statements in checkers can only use event controls"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigDupTop, std::make_tuple("ConfigDupTop"sv, "config design specifies more than one top cell named '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigInstanceUnderOtherConfig, std::make_tuple("ConfigInstanceUnderOtherConfig"sv, "config instance rule applies to an instance that is within a hierarchy specified by another config"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigInstanceWrongTop, std::make_tuple("ConfigInstanceWrongTop"sv, "config instance path must start with one of the cells named in the 'design' statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigOverrideTop, std::make_tuple("ConfigOverrideTop"sv, "config rule can't override a top cell with a different target"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigParamsForPrimitive, std::make_tuple("ConfigParamsForPrimitive"sv, "cannot provide parameter assignments for primitive instance"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstPortNotAllowed, std::make_tuple("ConstPortNotAllowed"sv, "'const' is not allowed on port declarations"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstVarNoInitializer, std::make_tuple("ConstVarNoInitializer"sv, "constant variable must have an initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstraintNotInClass, std::make_tuple("ConstraintNotInClass"sv, "constraint block can only be declared inside a class"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageBinTargetName, std::make_tuple("CoverageBinTargetName"sv, "expected 'with' target name to match the name of the parent coverpoint"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageOptionDup, std::make_tuple("CoverageOptionDup"sv, "duplicate option assignment for '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageSetType, std::make_tuple("CoverageSetType"sv, "invalid set covergroup expression type {} -- expected non-associative array of coverpoint type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CovergroupOutArg, std::make_tuple("CovergroupOutArg"sv, "covergroups cannot have 'output' or 'inout' arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIPureArg, std::make_tuple("DPIPureArg"sv, "DPI imports marked 'pure' cannot have 'output' or 'inout' arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIPureReturn, std::make_tuple("DPIPureReturn"sv, "DPI imports marked 'pure' cannot return 'void'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DPIRefArg, std::make_tuple("DPIRefArg"sv, "DPI subroutines cannot have 'ref' arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefParamLocal, std::make_tuple("DefParamLocal"sv, "'{}' is a localparam and so cannot be the target of a defparam"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefParamTarget, std::make_tuple("DefParamTarget"sv, "target of defparam must be a parameter"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefaultSuperArgLocalReference, std::make_tuple("DefaultSuperArgLocalReference"sv, "cannot use 'default' here because the superclass constructor argument '{}' refers to local member '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefparamBadHierarchy, std::make_tuple("DefparamBadHierarchy"sv, "defparam in a hierarchy in or under a generate block, array of instances, or bind instantiation cannot change a parameter value outside that hierarchy"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::Delay3OnVar, std::make_tuple("Delay3OnVar"sv, "continuous assignments to variables cannot have multi-value delays"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DimensionRequiresConstRange, std::make_tuple("DimensionRequiresConstRange"sv, "dimension requires a constant range"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DirectionWithInterfacePort, std::make_tuple("DirectionWithInterfacePort"sv, "port direction not allowed on an interface port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DisallowedPortDefault, std::make_tuple("DisallowedPortDefault"sv, "only 'output' variable port declarations may have an initializer expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DupInterfaceExternMethod, std::make_tuple("DupInterfaceExternMethod"sv, "more than one implementation provided for extern {} {}.{}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateParamAssignment, std::make_tuple("DuplicateParamAssignment"sv, "duplicate assignment for parameter '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicatePortConnection, std::make_tuple("DuplicatePortConnection"sv, "duplicate connection for port '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateWildcardPortConnection, std::make_tuple("DuplicateWildcardPortConnection"sv, "duplicate wildcard port connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ErrorTask, std::make_tuple("ErrorTask"sv, "$error encountered{}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedImportExport, std::make_tuple("ExpectedImportExport"sv, "expected 'import' or 'export' for subroutine '{}' in modport"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExtendClassFromIface, std::make_tuple("ExtendClassFromIface"sv, "an interface class cannot extend non-interface class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExtendFromFinal, std::make_tuple("ExtendFromFinal"sv, "cannot extend '{}' because it is marked 'final'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExtendIfaceFromClass, std::make_tuple("ExtendIfaceFromClass"sv, "a normal (or virtual) class cannot extend interface class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExternFuncForkJoin, std::make_tuple("ExternFuncForkJoin"sv, "only extern tasks can be declared 'forkjoin'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExternIfaceArrayMethod, std::make_tuple("ExternIfaceArrayMethod"sv, "cannot connect extern subroutine to interface array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FatalTask, std::make_tuple("FatalTask"sv, "$fatal encountered{}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GenvarDuplicate, std::make_tuple("GenvarDuplicate"sv, "loop generation value {} repeats more than once"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GenvarUnknownBits, std::make_tuple("GenvarUnknownBits"sv, "value of {} is invalid for loop generation value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GlobalClockingGenerate, std::make_tuple("GlobalClockingGenerate"sv, "global clocking cannot be declared in a generate block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceMethodHidden, std::make_tuple("IfaceMethodHidden"sv, "'{}' hides method inherited from '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceMethodNoImpl, std::make_tuple("IfaceMethodNoImpl"sv, "class '{}' must provide an implementation for method '{}' specified in interface class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceMethodNotExtern, std::make_tuple("IfaceMethodNotExtern"sv, "cannot provide an implementation for an interface method '{}' that is not declared 'extern'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceMethodNotVirtual, std::make_tuple("IfaceMethodNotVirtual"sv, "class '{}' must provide an implementation for method '{}' specified in interface class '{}' (existing method is not virtual)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceNameConflict, std::make_tuple("IfaceNameConflict"sv, "'{}' in '{}' conflicts with another member already inherited from '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfacePortInExpr, std::make_tuple("IfacePortInExpr"sv, "invalid use of interface port '{}' in port expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ImplementNonIface, std::make_tuple("ImplementNonIface"sv, "cannot implement non-interface class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ImplicitConnNetInconsistent, std::make_tuple("ImplicitConnNetInconsistent"sv, "net type '{}' of implicit named connection is inconsistent with net type '{}' of port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ImplicitNamedPortNotFound, std::make_tuple("ImplicitNamedPortNotFound"sv, "could not find connection for implicit named port '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InOutPortCannotBeVariable, std::make_tuple("InOutPortCannotBeVariable"sv, "variable port '{}' cannot have direction 'inout'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InOutUWirePort, std::make_tuple("InOutUWirePort"sv, "'uwire' port '{}' cannot have direction 'inout'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InheritFromAbstract, std::make_tuple("InheritFromAbstract"sv, "'{}' cannot inherit from virtual class '{}' without providing an implementation for pure virtual method '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InheritFromAbstractConstraint, std::make_tuple("InheritFromAbstractConstraint"sv, "'{}' cannot inherit from virtual class '{}' without providing an implementation for pure constraint '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InstanceMissingParens, std::make_tuple("InstanceMissingParens"sv, "{} instantiation is missing port list parentheses"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InstanceNameRequired, std::make_tuple("InstanceNameRequired"sv, "instance name is required"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InstanceWithDelay, std::make_tuple("InstanceWithDelay"sv, "missing '(' in parameter list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InstanceWithStrength, std::make_tuple("InstanceWithStrength"sv, "cannot instantiate '{}' with a drive strength"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectMultiPort, std::make_tuple("InterconnectMultiPort"sv, "cannot use interconnect nets in a port concatenation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectPortVar, std::make_tuple("InterconnectPortVar"sv, "cannot connect '{}' to an interconnect port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterfacePortNotConnected, std::make_tuple("InterfacePortNotConnected"sv, "interface port '{}' not connected"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterfacePortTypeMismatch, std::make_tuple("InterfacePortTypeMismatch"sv, "cannot connect instance of interface '{}' to port of interface '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidClockingSignal, std::make_tuple("InvalidClockingSignal"sv, "clocking signal '{}' must refer to a net or variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDPIArgType, std::make_tuple("InvalidDPIArgType"sv, "{} is not a valid argument type in a DPI subroutine"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDPIReturnType, std::make_tuple("InvalidDPIReturnType"sv, "{} is not a valid return type for a DPI subroutine"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDimensionRange, std::make_tuple("InvalidDimensionRange"sv, "invalid dimension range"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidInstanceForParent, std::make_tuple("InvalidInstanceForParent"sv, "cannot instantiate {} in {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidMethodOverride, std::make_tuple("InvalidMethodOverride"sv, "cannot override built-in method '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidNGateCount, std::make_tuple("InvalidNGateCount"sv, "instance of '{}' requires at least one input and one output connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidNetType, std::make_tuple("InvalidNetType"sv, "{} is not a valid type for a net; only 4-state integral types and unpacked structs/unions and arrays of such types are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPortSubType, std::make_tuple("InvalidPortSubType"sv, "{} is not a valid type for a port because it contains type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPortType, std::make_tuple("InvalidPortType"sv, "{} is not a valid type for a port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPrimInstanceForParent, std::make_tuple("InvalidPrimInstanceForParent"sv, "cannot instantiate a primitive in this scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPrimitivePortConn, std::make_tuple("InvalidPrimitivePortConn"sv, "only simple expressions are allowed for primitive port connections"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidRandType, std::make_tuple("InvalidRandType"sv, "{} is not a valid type for a '{}' property"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidRandomizeOverride, std::make_tuple("InvalidRandomizeOverride"sv, "override for '{}' should be a public non-static function that returns void and takes no parameters"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSpecifyDest, std::make_tuple("InvalidSpecifyDest"sv, "specify path destination '{}' must be an 'output' or 'inout' net, variable, or modport port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSpecifyPath, std::make_tuple("InvalidSpecifyPath"sv, "specify path must be a simple reference to a module port signal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSpecifySource, std::make_tuple("InvalidSpecifySource"sv, "specify path source '{}' must be an 'input' or 'inout' net or modport port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSpecifyType, std::make_tuple("InvalidSpecifyType"sv, "specify path terminal '{}' has non-integral type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidStmtInChecker, std::make_tuple("InvalidStmtInChecker"sv, "statement is not allowed in '{}' procedure inside a checker"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidTimingCheckNotifierArg, std::make_tuple("InvalidTimingCheckNotifierArg"sv, "invalid timing check argument; expecting a notifier variable name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidUserDefinedNetType, std::make_tuple("InvalidUserDefinedNetType"sv, "{} is not a valid type for a user-defined nettype; only integral types, floating types, and unpacked structs, unions, and arrays of such types are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalParamNoInitializer, std::make_tuple("LocalParamNoInitializer"sv, "local parameter is missing an initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalVarTypeRequired, std::make_tuple("LocalVarTypeRequired"sv, "local variable argument must specify an explicit type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MaxGenerateStepsExceeded, std::make_tuple("MaxGenerateStepsExceeded"sv, "generate loop hit maximum step limit; possible infinite loop?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MaxInstanceArrayExceeded, std::make_tuple("MaxInstanceArrayExceeded"sv, "{} array exceeded maximum size of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MemberDefinitionBeforeClass, std::make_tuple("MemberDefinitionBeforeClass"sv, "definition of '{}' must come after its containing class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgCountMismatch, std::make_tuple("MethodArgCountMismatch"sv, "definition of method '{}' has different number of arguments from its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgDefaultMismatch, std::make_tuple("MethodArgDefaultMismatch"sv, "default value for method argument '{}' must exactly match the expression given in its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgDirectionMismatch, std::make_tuple("MethodArgDirectionMismatch"sv, "direction of method argument '{}' differs from the direction given in its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgNameMismatch, std::make_tuple("MethodArgNameMismatch"sv, "method argument name '{}' doesn't match '{}' given in its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgNoDefault, std::make_tuple("MethodArgNoDefault"sv, "method argument '{}' provides a default value but its prototype does not"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodArgTypeMismatch, std::make_tuple("MethodArgTypeMismatch"sv, "method argument '{}' is of type {} which differs from {} given in its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodKindMismatch, std::make_tuple("MethodKindMismatch"sv, "mismatch between 'function' and 'task' declared in prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodReturnMismatch, std::make_tuple("MethodReturnMismatch"sv, "return type {} of method '{}' does not match {} declared in its prototype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodReturnTypeScoped, std::make_tuple("MethodReturnTypeScoped"sv, "return type for out-of-block method '{}' must use class scope '{}::' to access nested type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchConstraintSpecifiers, std::make_tuple("MismatchConstraintSpecifiers"sv, "mismatch of override specifiers between constraint prototype and declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchStaticConstraint, std::make_tuple("MismatchStaticConstraint"sv, "mismatch of 'static' keyword between constraint prototype and declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchedTimeScales, std::make_tuple("MismatchedTimeScales"sv, "duplicate time scale declaration must match previous value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchedUserDefPortConn, std::make_tuple("MismatchedUserDefPortConn"sv, "user-defined nettype '{}' on one side of this connection means that the type of the port {} must match the type of the connection {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchedUserDefPortDir, std::make_tuple("MismatchedUserDefPortDir"sv, "user-defined nettype '{}' on one side of this connection means that the port must have 'input' or 'output' direction"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingExternWildcardPorts, std::make_tuple("MissingExternWildcardPorts"sv, "could not find extern declaration for '{}' from which to take port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingPortIODeclaration, std::make_tuple("MissingPortIODeclaration"sv, "port '{}' has no I/O member declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MixingOrderedAndNamedParams, std::make_tuple("MixingOrderedAndNamedParams"sv, "mixing ordered and named parameter assignments is not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MixingOrderedAndNamedPorts, std::make_tuple("MixingOrderedAndNamedPorts"sv, "mixing ordered and named port connections is not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MixingSubroutinePortKinds, std::make_tuple("MixingSubroutinePortKinds"sv, "port declarations not allowed when subroutine defines a formal argument list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ModportConnMismatch, std::make_tuple("ModportConnMismatch"sv, "cannot connect modport '{}.{}' to port requiring modport '{}.{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultConstructorArg, std::make_tuple("MultipleDefaultConstructorArg"sv, "'default' cannot be used more than once in constructor argument list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultInputSkew, std::make_tuple("MultipleDefaultInputSkew"sv, "default input skew already defined for this clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultOutputSkew, std::make_tuple("MultipleDefaultOutputSkew"sv, "default output skew already defined for this clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NetAliasCommonNetType, std::make_tuple("NetAliasCommonNetType"sv, "all nets in a net alias statement must have a common nettype -- '{}' has nettype '{}' but previously saw '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NetAliasHierarchical, std::make_tuple("NetAliasHierarchical"sv, "cannot use hierarchical references in net alias statements"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NetAliasNotANet, std::make_tuple("NetAliasNotANet"sv, "'{}' is not a net and so cannot be used in a net alias statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NetAliasWidthMismatch, std::make_tuple("NetAliasWidthMismatch"sv, "all aliased nets must have the same width; expression has width of {}, previously seen width was {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoChangeEdgeRequired, std::make_tuple("NoChangeEdgeRequired"sv, "trigger for first argument to '$nochange' must be posedge or negedge only"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoMemberImplFound, std::make_tuple("NoMemberImplFound"sv, "no implementation found in parent scope for '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAChecker, std::make_tuple("NotAChecker"sv, "invalid reference to '{}' -- this looks like a module/interface/program/checker instantiation but '{}' is none of those things"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAClockingBlock, std::make_tuple("NotAClockingBlock"sv, "'{}' is not a clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAProduction, std::make_tuple("NotAProduction"sv, "'{}' is not a randsequence production"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInModport, std::make_tuple("NotAllowedInModport"sv, "'{}' cannot be listed in a modport"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NullPortExpression, std::make_tuple("NullPortExpression"sv, "expression given for null port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::OverridingFinal, std::make_tuple("OverridingFinal"sv, "'{}' overrides a base class member that is marked 'final'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::OverridingInitial, std::make_tuple("OverridingInitial"sv, "'{}' is marked 'initial' but overrides a base class member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackageExportSelf, std::make_tuple("PackageExportSelf"sv, "package cannot export itself"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackageImportSelf, std::make_tuple("PackageImportSelf"sv, "package cannot import itself"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackageNetInit, std::make_tuple("PackageNetInit"sv, "net declarations in packages cannot have assignments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedDimsRequireFullRange, std::make_tuple("PackedDimsRequireFullRange"sv, "packed dimensions require a full range specification"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ParallelPathWidth, std::make_tuple("ParallelPathWidth"sv, "parallel specify path source type {} has different width than destination type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ParamHasNoValue, std::make_tuple("ParamHasNoValue"sv, "instance of '{}' does not provide a value for parameter '{}' and it does not have a default value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ParameterDoesNotExist, std::make_tuple("ParameterDoesNotExist"sv, "parameter '{}' does not exist in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PathPulseInvalidPathName, std::make_tuple("PathPulseInvalidPathName"sv, "PATHPULSE$ path '{}' must be of the form 'source$dest'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortConcatInOut, std::make_tuple("PortConcatInOut"sv, "port concatentation can't contain any 'inout' ports because not all of the ports are resolvable nets"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortConcatRef, std::make_tuple("PortConcatRef"sv, "port concatentation can't contain any 'ref' ports because not all of the ports are variables"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortConnDimensionsMismatch, std::make_tuple("PortConnDimensionsMismatch"sv, "dimensions of connection for port '{}' do not match its declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortDeclDimensionsMismatch, std::make_tuple("PortDeclDimensionsMismatch"sv, "inconsistent dimensions declared for '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortDeclInANSIModule, std::make_tuple("PortDeclInANSIModule"sv, "can't use port declaration in module with ANSI style port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortDoesNotExist, std::make_tuple("PortDoesNotExist"sv, "port '{}' does not exist in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortTypeNotInterfaceOrData, std::make_tuple("PortTypeNotInterfaceOrData"sv, "port type '{}' is neither an interface nor a data type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveAnsiMix, std::make_tuple("PrimitiveAnsiMix"sv, "primitives cannot mix an ansi-style header with port declarations inside their bodies"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveDupInitial, std::make_tuple("PrimitiveDupInitial"sv, "primitive cannot have both an initial statement and an output initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveDupOutput, std::make_tuple("PrimitiveDupOutput"sv, "primitives must have one and only one output port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveInitVal, std::make_tuple("PrimitiveInitVal"sv, "initial value for a primitive output must be a single-bit binary literal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveInitialInComb, std::make_tuple("PrimitiveInitialInComb"sv, "combinational primitives cannot contain an initial statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveOutputFirst, std::make_tuple("PrimitiveOutputFirst"sv, "the first port in a primitive must be an output port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitivePortCountWrong, std::make_tuple("PrimitivePortCountWrong"sv, "wrong number of port connections for '{}' instance ({} given, expected {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitivePortDup, std::make_tuple("PrimitivePortDup"sv, "port '{}' already declared"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitivePortMissing, std::make_tuple("PrimitivePortMissing"sv, "port '{}' is missing a corresponding body declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitivePortUnknown, std::make_tuple("PrimitivePortUnknown"sv, "port declaration '{}' does not match any port in the primitive's port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveRegDup, std::make_tuple("PrimitiveRegDup"sv, "only one 'reg' port is allowed per primitive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveRegInput, std::make_tuple("PrimitiveRegInput"sv, "input port '{}' cannot be declared as a 'reg'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveTwoPorts, std::make_tuple("PrimitiveTwoPorts"sv, "primitives must have at least one input and one output port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PrimitiveWrongInitial, std::make_tuple("PrimitiveWrongInitial"sv, "'{}' is not this primitive's output port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropertyPortInLet, std::make_tuple("PropertyPortInLet"sv, "port of type '{}' is not allowed in a 'let' declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropertyPortInSeq, std::make_tuple("PropertyPortInSeq"sv, "port of type 'property' is not allowed in a sequence"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PureConstraintInAbstract, std::make_tuple("PureConstraintInAbstract"sv, "pure constraints can only be declared in virtual classes"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PureInAbstract, std::make_tuple("PureInAbstract"sv, "pure virtual methods can only be declared in virtual classes"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandJoinNotNumeric, std::make_tuple("RandJoinNotNumeric"sv, "rand join expression type {} is not numeric"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointBins, std::make_tuple("RealCoverpointBins"sv, "coverpoints of real expressions must specify at least one explicit bin"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointDefaultArray, std::make_tuple("RealCoverpointDefaultArray"sv, "default bin for coverpoint of real expression cannot be an array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointImplicit, std::make_tuple("RealCoverpointImplicit"sv, "cannot declare implicit coverpoint for real value '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointTransBins, std::make_tuple("RealCoverpointTransBins"sv, "coverpoints of real expressions cannot specify transition bins"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointWildcardBins, std::make_tuple("RealCoverpointWildcardBins"sv, "coverpoints of real expressions cannot be marked 'wildcard'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealCoverpointWithExpr, std::make_tuple("RealCoverpointWithExpr"sv, "'with' expressions are not allowed for bins of a real type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefArgAutomaticFunc, std::make_tuple("RefArgAutomaticFunc"sv, "'ref' arguments can only be used in 'automatic' subroutines"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefPortMustBeVariable, std::make_tuple("RefPortMustBeVariable"sv, "ref port '{}' cannot be of net type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefPortUnconnected, std::make_tuple("RefPortUnconnected"sv, "'ref' port '{}' cannot be left unconnected"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefPortUnnamedUnconnected, std::make_tuple("RefPortUnnamedUnconnected"sv, "an unnamed 'ref' port has been left unconnected"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SingleBitVectored, std::make_tuple("SingleBitVectored"sv, "net of width 1 cannot be 'vectored' or 'scalared'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SpecifyPathMultiDim, std::make_tuple("SpecifyPathMultiDim"sv, "specify path references can only have a single select dimension"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::StaticAssert, std::make_tuple("StaticAssert"sv, "static assertion failed{}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::StaticConstNoInitializer, std::make_tuple("StaticConstNoInitializer"sv, "static constant class properties must have initializers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SubroutinePortInitializer, std::make_tuple("SubroutinePortInitializer"sv, "subroutine port declaration cannot contain an initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TimeScaleFirstInScope, std::make_tuple("TimeScaleFirstInScope"sv, "time scale declaration must come before all other items in scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TimingCheckEventEdgeRequired, std::make_tuple("TimingCheckEventEdgeRequired"sv, "'{}' event argument requires an edge trigger"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TimingCheckEventNotAllowed, std::make_tuple("TimingCheckEventNotAllowed"sv, "timing check event expression not allowed for this argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyParamAssignments, std::make_tuple("TooManyParamAssignments"sv, "too many parameter assignments given for '{}' ({} given, expected {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyPortConnections, std::make_tuple("TooManyPortConnections"sv, "too many port connections given to instantiation of '{}' ({} given, expected {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeRestrictionMismatch, std::make_tuple("TypeRestrictionMismatch"sv, "type restriction '{}' does not match assigned type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpAllX, std::make_tuple("UdpAllX"sv, "primitive table row has all 'x' inputs so its output must also be 'x'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpDupDiffOutput, std::make_tuple("UdpDupDiffOutput"sv, "primitive table row duplicates a set of inputs with a different specified output value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpWrongInputCount, std::make_tuple("UdpWrongInputCount"sv, "incorrect number of input fields in table row; have {} but expect {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownCovergroupBase, std::make_tuple("UnknownCovergroupBase"sv, "'{}' is not a covergroup in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownInterface, std::make_tuple("UnknownInterface"sv, "unknown interface '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownModule, std::make_tuple("UnknownModule"sv, "unknown module '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownPackage, std::make_tuple("UnknownPackage"sv, "unknown package '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownPrimitive, std::make_tuple("UnknownPrimitive"sv, "unknown user-defined primitive '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownSystemTimingCheck, std::make_tuple("UnknownSystemTimingCheck"sv, "unknown system timing check '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnpackedArrayParamType, std::make_tuple("UnpackedArrayParamType"sv, "unpacked array parameter requires explicit data type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnusedPortDecl, std::make_tuple("UnusedPortDecl"sv, "port declaration '{}' does not match any port in the module's port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UserDefPortMixedConcat, std::make_tuple("UserDefPortMixedConcat"sv, "cannot mix and match nets with user-defined nettypes in port concatenation (see '{}' and '{}')"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UserDefPortTwoSided, std::make_tuple("UserDefPortTwoSided"sv, "user-defined nettype '{}' of the port does not match '{}' of the connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VarDeclWithDelay, std::make_tuple("VarDeclWithDelay"sv, "cannot specify a net delay for a variable declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VarWithInterfacePort, std::make_tuple("VarWithInterfacePort"sv, "'var' keyword may not be used with an interface port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgCountMismatch, std::make_tuple("VirtualArgCountMismatch"sv, "virtual method '{}' has different number of arguments from its superclass method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgDirectionMismatch, std::make_tuple("VirtualArgDirectionMismatch"sv, "direction of virtual method argument '{}' differs from the direction given in its superclass method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgNameMismatch, std::make_tuple("VirtualArgNameMismatch"sv, "virtual method argument name '{}' doesn't match '{}' given in its superclass method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgNoDerivedDefault, std::make_tuple("VirtualArgNoDerivedDefault"sv, "virtual method argument '{}' does not provide a default value but its superclass method argument does"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgNoParentDefault, std::make_tuple("VirtualArgNoParentDefault"sv, "virtual method argument '{}' provides a default value but its superclass method argument does not"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualArgTypeMismatch, std::make_tuple("VirtualArgTypeMismatch"sv, "virtual method argument '{}' is of type {} which differs from {} given in its superclass method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualInterfaceIfaceMember, std::make_tuple("VirtualInterfaceIfaceMember"sv, "virtual interfaces cannot be used as the type for interface items"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualKindMismatch, std::make_tuple("VirtualKindMismatch"sv, "mismatch between 'function' and 'task' declared in superclass method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualReturnMismatch, std::make_tuple("VirtualReturnMismatch"sv, "return type {} of virtual method '{}' does not match {} declared in its superclass"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WildcardPortGenericIface, std::make_tuple("WildcardPortGenericIface"sv, "cannot use wildcard connection for generic interface port '{}' (use a named connection instead)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InfoTask, std::make_tuple("InfoTask"sv, "$info encountered{}"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteCommonAncestor, std::make_tuple("NoteCommonAncestor"sv, "common ancestor here violates that constraint"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteComparisonReduces, std::make_tuple("NoteComparisonReduces"sv, "comparison reduces to ({} {} {})"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::CaseGenerateDup, std::make_tuple("CaseGenerateDup"sv, "more than one case generate block matches the value {}"sv, DiagnosticSeverity::Warning, "case-gen-dup"sv)},
    {diag::CaseGenerateNoBlock, std::make_tuple("CaseGenerateNoBlock"sv, "no case generate expression matches the value {}"sv, DiagnosticSeverity::Warning, "case-gen-none"sv)},
    {diag::DPISpecDisallowed, std::make_tuple("DPISpecDisallowed"sv, "'DPI' specified subroutines are not supported and will be treated as 'DPI-C'. Note that this may require changes to the application's C code."sv, DiagnosticSeverity::Warning, "dpi-spec"sv)},
    {diag::DupConfigRule, std::make_tuple("DupConfigRule"sv, "duplicate config rule for {} -- ignoring this one"sv, DiagnosticSeverity::Warning, "dup-config-rule"sv)},
    {diag::DupTimingPath, std::make_tuple("DupTimingPath"sv, "duplicate timing path"sv, DiagnosticSeverity::Warning, "dup-timing-path"sv)},
    {diag::DuplicateAttribute, std::make_tuple("DuplicateAttribute"sv, "duplicate attribute definition '{}'; taking last value"sv, DiagnosticSeverity::Warning, "dup-attr"sv)},
    {diag::EmptyMember, std::make_tuple("EmptyMember"sv, "extra ';' has no effect"sv, DiagnosticSeverity::Warning, "empty-member"sv)},
    {diag::EmptyUdpPort, std::make_tuple("EmptyUdpPort"sv, "primitive port connection is empty"sv, DiagnosticSeverity::Warning, "udp-port-empty"sv)},
    {diag::ImplicitNamedPortTypeMismatch, std::make_tuple("ImplicitNamedPortTypeMismatch"sv, "implicit named port '{}' of type {} connects to value of inequivalent type {}"sv, DiagnosticSeverity::Warning, "implicit-port-type-mismatch"sv)},
    {diag::ImplicitNetPortNoDefault, std::make_tuple("ImplicitNetPortNoDefault"sv, "implicit net port disallowed because `default_nettype is set to 'none'"sv, DiagnosticSeverity::Warning, "implicit-net-port"sv)},
    {diag::InvalidPulseStyle, std::make_tuple("InvalidPulseStyle"sv, "invalid use of {} for '{}' since it has previously appeared in a path declaration"sv, DiagnosticSeverity::Warning, "invalid-pulsestyle"sv)},
    {diag::NetInconsistent, std::make_tuple("NetInconsistent"sv, "net type '{}' of connection is inconsistent with net type '{}' of port"sv, DiagnosticSeverity::Warning, "net-inconsistent"sv)},
    {diag::NetRangeInconsistent, std::make_tuple("NetRangeInconsistent"sv, "net type '{}' of connection bits [{}:{}] is inconsistent with net type '{}' of corresponding port range"sv, DiagnosticSeverity::Warning, "net-inconsistent"sv)},
    {diag::NoConstraintBody, std::make_tuple("NoConstraintBody"sv, "no body for implicit constraint block '{}'"sv, DiagnosticSeverity::Warning, "constraint-missing"sv)},
    {diag::SignednessNoEffect, std::make_tuple("SignednessNoEffect"sv, "'{}' on I/O declaration has no effect on type {}"sv, DiagnosticSeverity::Warning, "ineffective-sign"sv)},
    {diag::StaticInitOrder, std::make_tuple("StaticInitOrder"sv, "initializer for static variable '{}' refers to another static variable '{}' which will be initialized in an indeterminate order"sv, DiagnosticSeverity::Warning, "static-init-order"sv)},
    {diag::StaticInitValue, std::make_tuple("StaticInitValue"sv, "initializer for static variable '{}' refers to '{}' which will not have a value at initialization time"sv, DiagnosticSeverity::Warning, "static-init-value"sv)},
    {diag::StaticInitializerMustBeExplicit, std::make_tuple("StaticInitializerMustBeExplicit"sv, "initializing a static variable in a procedural context requires an explicit 'static' keyword"sv, DiagnosticSeverity::Warning, "explicit-static"sv)},
    {diag::UnconnectedNamedPort, std::make_tuple("UnconnectedNamedPort"sv, "port '{}' has no connection"sv, DiagnosticSeverity::Warning, "unconnected-port"sv)},
    {diag::UnconnectedUnnamedPort, std::make_tuple("UnconnectedUnnamedPort"sv, "instance does not provide a connection for an unnamed port"sv, DiagnosticSeverity::Warning, "unconnected-unnamed-port"sv)},
    {diag::UnusedConfigCell, std::make_tuple("UnusedConfigCell"sv, "unused cell config rule"sv, DiagnosticSeverity::Warning, "unused-config-cell"sv)},
    {diag::UnusedConfigInstance, std::make_tuple("UnusedConfigInstance"sv, "unused config rule -- instance path does not exist in the design"sv, DiagnosticSeverity::Warning, "unused-config-instance"sv)},
    {diag::WarnUnknownLibrary, std::make_tuple("WarnUnknownLibrary"sv, "unknown library '{}'"sv, DiagnosticSeverity::Warning, "unknown-library"sv)},
    {diag::WarningTask, std::make_tuple("WarningTask"sv, "$warning encountered{}"sv, DiagnosticSeverity::Warning, "warning-task"sv)},
    {diag::ArgCannotBeEmpty, std::make_tuple("ArgCannotBeEmpty"sv, "argument '{}' cannot be empty because it does not have a default value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ArgDoesNotExist, std::make_tuple("ArgDoesNotExist"sv, "argument '{}' does not exist in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionArgNeedsRegExpr, std::make_tuple("AssertionArgNeedsRegExpr"sv, "cannot pass a sequence or property expression to an argument of type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionArgTypeMismatch, std::make_tuple("AssertionArgTypeMismatch"sv, "argument of type {} is not cast compatible with formal port type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionArgTypeSequence, std::make_tuple("AssertionArgTypeSequence"sv, "expected a sequence expression for port of type 'sequence'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionDelayFormalType, std::make_tuple("AssertionDelayFormalType"sv, "a typed formal argument used in a cycle delay or sequence repetition must be of type 'shortint', 'int', or 'longint', not {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionFuncArg, std::make_tuple("AssertionFuncArg"sv, "cannot call a function with output, inout, or ref arguments from a concurrent assertion expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionOutputLocalVar, std::make_tuple("AssertionOutputLocalVar"sv, "an argument bound to an 'inout' or 'output' local variable formal argument must itself be a reference to a local variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionPortTypedLValue, std::make_tuple("AssertionPortTypedLValue"sv, "typed formal argument '{}' cannot be modified because it is not marked 'local'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignToCHandle, std::make_tuple("AssignToCHandle"sv, "cannot assign to a chandle outside of a procedural context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignToNet, std::make_tuple("AssignToNet"sv, "cannot assign to a net within a procedural context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentNotAllowed, std::make_tuple("AssignmentNotAllowed"sv, "assignment expressions are not allowed in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternAssociativeType, std::make_tuple("AssignmentPatternAssociativeType"sv, "assignment pattern for associative array must specify key:value pairs"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternDynamicDefault, std::make_tuple("AssignmentPatternDynamicDefault"sv, "assignment pattern for dynamic array or queue cannot have default key"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternDynamicType, std::make_tuple("AssignmentPatternDynamicType"sv, "assignment patterns for dynamic arrays, associative arrays, and queues cannot have type keys"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternKeyDupDefault, std::make_tuple("AssignmentPatternKeyDupDefault"sv, "assignment pattern has multiple default keys"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternKeyDupName, std::make_tuple("AssignmentPatternKeyDupName"sv, "assignment pattern has multiple keys for member '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternKeyDupValue, std::make_tuple("AssignmentPatternKeyDupValue"sv, "assignment pattern has multiple keys for index {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternKeyExpr, std::make_tuple("AssignmentPatternKeyExpr"sv, "expression is not a valid assignment pattern member name or type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternLValueDynamic, std::make_tuple("AssignmentPatternLValueDynamic"sv, "lvalue assignment patterns cannot be assigned from dynamic arrays"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternMissingElements, std::make_tuple("AssignmentPatternMissingElements"sv, "not all elements of array are covered by an assignment pattern key"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternNoContext, std::make_tuple("AssignmentPatternNoContext"sv, "assignment pattern target type cannot be deduced in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentPatternNoMember, std::make_tuple("AssignmentPatternNoMember"sv, "member '{}' is not covered by any assignment pattern key"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentRequiresParens, std::make_tuple("AssignmentRequiresParens"sv, "assignment expressions must be parenthesized"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssignmentToConstVar, std::make_tuple("AssignmentToConstVar"sv, "cannot assign to read-only variable '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoFromNonBlockingTiming, std::make_tuple("AutoFromNonBlockingTiming"sv, "cannot refer to automatic variable '{}' from intra-assignment event control of nonblocking assignment"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoFromNonProcedural, std::make_tuple("AutoFromNonProcedural"sv, "cannot refer to automatic variable '{}' from non-procedural context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoFromStaticInit, std::make_tuple("AutoFromStaticInit"sv, "cannot refer to automatic variable '{}' from static initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoVarToRefStatic, std::make_tuple("AutoVarToRefStatic"sv, "cannot pass automatic variables or elements of dynamically sized arrays to 'ref static' argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadAssignment, std::make_tuple("BadAssignment"sv, "value of type {} cannot be assigned to type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadAssignmentPatternType, std::make_tuple("BadAssignmentPatternType"sv, "invalid target type {} for assignment pattern"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadBinaryExpression, std::make_tuple("BadBinaryExpression"sv, "invalid operands to binary expression ({} and {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadCastType, std::make_tuple("BadCastType"sv, "invalid casting type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadConcatExpression, std::make_tuple("BadConcatExpression"sv, "invalid operand type {} in concatenation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadConditionalExpression, std::make_tuple("BadConditionalExpression"sv, "invalid operands to conditional expression ({} and {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadConversion, std::make_tuple("BadConversion"sv, "value of type {} cannot be converted to type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadIndexExpression, std::make_tuple("BadIndexExpression"sv, "value of type {} cannot be indexed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadIntegerCast, std::make_tuple("BadIntegerCast"sv, "cannot change width or signedness of non-integral expression (type is {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadReplicationExpression, std::make_tuple("BadReplicationExpression"sv, "invalid operands to replication expression ({} and {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadSetMembershipType, std::make_tuple("BadSetMembershipType"sv, "invalid type {} for {} expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadSliceType, std::make_tuple("BadSliceType"sv, "value of type {} cannot be sliced"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamCast, std::make_tuple("BadStreamCast"sv, "streaming concatenation cannot be converted to type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamContext, std::make_tuple("BadStreamContext"sv, "streaming operator can only be used in an assignment or bit-stream cast argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamExprType, std::make_tuple("BadStreamExprType"sv, "stream expression type {} is not a bit-stream type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamSize, std::make_tuple("BadStreamSize"sv, "streaming operator target size {} does not fit source size {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamSlice, std::make_tuple("BadStreamSlice"sv, "streaming operator slice size cannot be a dynamically sized type identifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamSourceType, std::make_tuple("BadStreamSourceType"sv, "source type {} of streaming concatenation is not a bit-stream type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamTargetType, std::make_tuple("BadStreamTargetType"sv, "target type {} of streaming concatenation is not a bit-stream type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamWithOrder, std::make_tuple("BadStreamWithOrder"sv, "'with' expression cannot appear after unconstrained dynamically sized stream expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadStreamWithType, std::make_tuple("BadStreamWithType"sv, "stream expression type before 'with' must be a one-dimensional unpacked array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadUnaryExpression, std::make_tuple("BadUnaryExpression"sv, "invalid operand type {} to unary expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadValueRange, std::make_tuple("BadValueRange"sv, "invalid bounds in value range ({} and {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BlockingAssignToFreeVar, std::make_tuple("BlockingAssignToFreeVar"sv, "continuous assignments and blocking procedural assignments to free checker variables are not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CHandleInAssertion, std::make_tuple("CHandleInAssertion"sv, "cannot reference variable of type 'chandle' in concurrent assertion expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CannotCompareTwoInstances, std::make_tuple("CannotCompareTwoInstances"sv, "cannot compare two instances to each other; at least one side must be a virtual interface"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CannotIndexScalar, std::make_tuple("CannotIndexScalar"sv, "scalar type cannot be indexed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CantModifyConst, std::make_tuple("CantModifyConst"sv, "constant '{}' is not modifiable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ChainedMethodParens, std::make_tuple("ChainedMethodParens"sv, "parentheses are required when chaining method calls"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerArgCannotBeEmpty, std::make_tuple("CheckerArgCannotBeEmpty"sv, "checker port connection for '{}' cannot be empty"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClassMemberInAssertion, std::make_tuple("ClassMemberInAssertion"sv, "cannot reference non-static class members in concurrent assertion expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClassPrivateMembersBitstream, std::make_tuple("ClassPrivateMembersBitstream"sv, "cannot use class type {} as a bit-stream because it has local or protected members that are not accessible in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockVarAssignConcat, std::make_tuple("ClockVarAssignConcat"sv, "clocking signal '{}' cannot be part of a concatenation or assignment pattern lvalue"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockVarBadTiming, std::make_tuple("ClockVarBadTiming"sv, "clocking signals cannot be driven with a timing control other than a cycle delay"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockVarOutputRead, std::make_tuple("ClockVarOutputRead"sv, "cannot read from output clocking signal '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockVarTargetAssign, std::make_tuple("ClockVarTargetAssign"sv, "cannot write to '{}' with a continuous assignment since it's associated with an output clocking signal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConcatWithStringInt, std::make_tuple("ConcatWithStringInt"sv, "cannot mix strings and integers in a concatenation (use a cast if this is desired)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstVarToRef, std::make_tuple("ConstVarToRef"sv, "cannot bind const variable to 'ref' argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CopyClassTarget, std::make_tuple("CopyClassTarget"sv, "expected {} to be a class type for shallow copy expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverOptionImmutable, std::make_tuple("CoverOptionImmutable"sv, "the '{}' option cannot be modified outside of the covergroup definition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageExprVar, std::make_tuple("CoverageExprVar"sv, "coverage expressions can only reference constants and non-ref formal arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageSampleFormal, std::make_tuple("CoverageSampleFormal"sv, "sample formal argument '{}' can only be referenced in a coverpoint, cross, or conditional guard expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CycleDelayNonClock, std::make_tuple("CycleDelayNonClock"sv, "intra-assignment cycle delays can only be used with clocking signals"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DistRealRangeWeight, std::make_tuple("DistRealRangeWeight"sv, "'dist' for a range of real values must include an explicit weight and must use the ':/' operator"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateArgAssignment, std::make_tuple("DuplicateArgAssignment"sv, "duplicate assignment for argument '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DynamicNotProcedural, std::make_tuple("DynamicNotProcedural"sv, "cannot refer to an element or member of a dynamic type outside of a procedural context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EmptyArgNotAllowed, std::make_tuple("EmptyArgNotAllowed"sv, "empty argument not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EmptyConcatNotAllowed, std::make_tuple("EmptyConcatNotAllowed"sv, "concatenation cannot be empty"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumValueSizeMismatch, std::make_tuple("EnumValueSizeMismatch"sv, "expression width of {} does not exactly match declared enum type width of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EventExprAssertionArg, std::make_tuple("EventExprAssertionArg"sv, "argument of type 'event' can only be used in places where event expressions are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EventExpressionFuncArg, std::make_tuple("EventExpressionFuncArg"sv, "cannot call a function with output, inout, or ref arguments from an event expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIterationExpression, std::make_tuple("ExpectedIterationExpression"sv, "expected a single array iteration expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIteratorName, std::make_tuple("ExpectedIteratorName"sv, "expected name of iterator for use with 'with' expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedNetDelay, std::make_tuple("ExpectedNetDelay"sv, "invalid net delay; expected min:typ:max or single expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExprMustBeIntegral, std::make_tuple("ExprMustBeIntegral"sv, "expression type {} is not integral"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpressionNotAssignable, std::make_tuple("ExpressionNotAssignable"sv, "expression is not assignable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpressionNotCallable, std::make_tuple("ExpressionNotCallable"sv, "expression is not callable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GateUDNTConn, std::make_tuple("GateUDNTConn"sv, "gate cannot connect to net '{}' with user-defined net type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InOutUWireConn, std::make_tuple("InOutUWireConn"sv, "'uwire' net '{}' cannot be connected to 'inout' port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InOutVarPortConn, std::make_tuple("InOutVarPortConn"sv, "'{}' cannot be connected to 'inout' port (only nets are allowed)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IncDecNotAllowed, std::make_tuple("IncDecNotAllowed"sv, "increment and decrement expressions are not allowed in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IndexValueInvalid, std::make_tuple("IndexValueInvalid"sv, "cannot refer to element {} of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InputPortAssign, std::make_tuple("InputPortAssign"sv, "cannot assign to input port '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectReference, std::make_tuple("InterconnectReference"sv, "cannot reference interconnect net '{}' outside of a net port connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterfacePortInvalidExpression, std::make_tuple("InterfacePortInvalidExpression"sv, "invalid expression for interface port connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidArgumentExpr, std::make_tuple("InvalidArgumentExpr"sv, "sequence and property expressions are not valid in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidBinsMatches, std::make_tuple("InvalidBinsMatches"sv, "'matches' expression is invalid here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidBinsTarget, std::make_tuple("InvalidBinsTarget"sv, "binsof target '{}' is not a coverpoint or coverpoint bin"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidClassAccess, std::make_tuple("InvalidClassAccess"sv, "cannot access '{}' in {} with '.'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidExtendsDefault, std::make_tuple("InvalidExtendsDefault"sv, "constructor must use 'default' in its argument list since 'extends' specifies 'default' for its argument list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidMemberAccess, std::make_tuple("InvalidMemberAccess"sv, "invalid member access for type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidRefArg, std::make_tuple("InvalidRefArg"sv, "invalid expression for pass by reference; only variables, class properties, and members of unpacked structs and arrays are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSuperNewDefault, std::make_tuple("InvalidSuperNewDefault"sv, "cannot use 'default' in super.new since the containing constructor does not use 'default' in its argument list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IteratorArgsWithoutWithClause, std::make_tuple("IteratorArgsWithoutWithClause"sv, "cannot provide arguments to '{}' without corresponding 'with' clause"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LetHierarchical, std::make_tuple("LetHierarchical"sv, "hierarchical references to let declarations are not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalFormalVarMultiAssign, std::make_tuple("LocalFormalVarMultiAssign"sv, "cannot bind local variable '{}' to more than one output or inout local variable formal argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalVarEventExpr, std::make_tuple("LocalVarEventExpr"sv, "local variable '{}' cannot be referenced in an event expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalVarOutputEmptyMatch, std::make_tuple("LocalVarOutputEmptyMatch"sv, "sequence '{}' cannot have an 'inout' or 'output' local variable formal argument because it admits an empty match"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingConstraintBlock, std::make_tuple("MissingConstraintBlock"sv, "missing inline constraint block for 'randomize' call"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingInvocationParens, std::make_tuple("MissingInvocationParens"sv, "parentheses are required when invoking function '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingReturnValue, std::make_tuple("MissingReturnValue"sv, "must provide a return value for non-void function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingReturnValueProd, std::make_tuple("MissingReturnValueProd"sv, "must provide a return value for non-void production"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MixedVarAssigns, std::make_tuple("MixedVarAssigns"sv, "cannot mix continuous and procedural assignments to variable '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MixingOrderedAndNamedArgs, std::make_tuple("MixingOrderedAndNamedArgs"sv, "ordered arguments are not allowed after named arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleAlwaysAssigns, std::make_tuple("MultipleAlwaysAssigns"sv, "variable '{}' driven by {} procedure cannot be written to by any other process"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleContAssigns, std::make_tuple("MultipleContAssigns"sv, "cannot have multiple continuous assignments to variable '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultDistWeight, std::make_tuple("MultipleDefaultDistWeight"sv, "'default' cannot be used more than once in dist item list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleUDNTDrivers, std::make_tuple("MultipleUDNTDrivers"sv, "net '{}' with user-defined nettype '{}' cannot have multiple drivers because it does not specify a resolution function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleUWireDrivers, std::make_tuple("MultipleUWireDrivers"sv, "'uwire' net '{}' cannot have multiple drivers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NameListWithScopeRandomize, std::make_tuple("NameListWithScopeRandomize"sv, "lookup restriction list not allowed for std::randomize call"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NamedArgNotAllowed, std::make_tuple("NamedArgNotAllowed"sv, "named argument not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NewArrayTarget, std::make_tuple("NewArrayTarget"sv, "new array expression can only be used in an assignment to a dynamic array type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NewClassTarget, std::make_tuple("NewClassTarget"sv, "new class expression can only be used in an assignment to a class type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NewInterfaceClass, std::make_tuple("NewInterfaceClass"sv, "cannot create instance of interface class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NewVirtualClass, std::make_tuple("NewVirtualClass"sv, "cannot create instance of virtual class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoCommonComparisonType, std::make_tuple("NoCommonComparisonType"sv, "{} expression of type {} is not comparable to common type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoImplicitConversion, std::make_tuple("NoImplicitConversion"sv, "no implicit conversion from {} to {}; explicit conversion exists, are you missing a cast?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonProceduralFuncArg, std::make_tuple("NonProceduralFuncArg"sv, "cannot call a function with output, inout, or ref arguments outside of a procedural context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonblockingAssignmentToAuto, std::make_tuple("NonblockingAssignmentToAuto"sv, "nonblocking assignment to automatic variable '{}' is not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonblockingDynamicAssign, std::make_tuple("NonblockingDynamicAssign"sv, "nonblocking assignments to elements of dynamically sized arrays are not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotBooleanConvertible, std::make_tuple("NotBooleanConvertible"sv, "value of type {} is not convertible to a boolean predicate"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PathPulseInExpr, std::make_tuple("PathPulseInExpr"sv, "PATHPULSE$ specparams cannot be used in expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PatternStructTooFew, std::make_tuple("PatternStructTooFew"sv, "structure pattern has too few members for target type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PatternStructTooMany, std::make_tuple("PatternStructTooMany"sv, "structure pattern has too many members for target type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PatternStructType, std::make_tuple("PatternStructType"sv, "structure pattern type {} is not a struct"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PatternTaggedType, std::make_tuple("PatternTaggedType"sv, "expected pattern type {} is not a tagged union"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PortConnArrayMismatch, std::make_tuple("PortConnArrayMismatch"sv, "cannot connect {} to each port of type {} in '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RangeSelectAssociative, std::make_tuple("RangeSelectAssociative"sv, "cannot take a slice of an associative array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RangeWidthOverflow, std::make_tuple("RangeWidthOverflow"sv, "select range overflows the bounds of a signed 32-bit integer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursiveLet, std::make_tuple("RecursiveLet"sv, "let declaration '{}' is recursive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursivePropArgExpr, std::make_tuple("RecursivePropArgExpr"sv, "cannot refer to argument '{}' in an argument to a recursive property unless it is the entire argument expression or bound to a local variable formal argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursivePropNegation, std::make_tuple("RecursivePropNegation"sv, "recursive property instance cannot have the operators 'not', 's_nexttime', 's_eventually', 's_always', 's_until', or 's_until_with' applied to it"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursivePropTimeAdvance, std::make_tuple("RecursivePropTimeAdvance"sv, "recursive property instance must occur after a positive advance in time to avoid infinite recursion"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursiveSequence, std::make_tuple("RecursiveSequence"sv, "sequence '{}' is recursive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefArgForkJoin, std::make_tuple("RefArgForkJoin"sv, "cannot refer to 'ref' argument '{}' inside fork-join_any or fork-join_none block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RefTypeMismatch, std::make_tuple("RefTypeMismatch"sv, "argument of type {} connects to 'ref' port of inequivalent type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ReplicationZeroOutsideConcat, std::make_tuple("ReplicationZeroOutsideConcat"sv, "replication constant can only be zero inside of a concatenation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SelectAfterRangeSelect, std::make_tuple("SelectAfterRangeSelect"sv, "cannot chain select expressions after a range select"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SelectEndianDynamic, std::make_tuple("SelectEndianDynamic"sv, "range of selection [{}:{}] into {} is reversed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SelectEndianMismatch, std::make_tuple("SelectEndianMismatch"sv, "endianness of selection must match declared range (type is {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SelectOfVectoredNet, std::make_tuple("SelectOfVectoredNet"sv, "bit-selects and part-selects of vectored nets are disallowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SpecifyPathBadReference, std::make_tuple("SpecifyPathBadReference"sv, "cannot refer to '{}' in state-dependent path condition expression; only locally defined nets and variables are allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SpecparamInConstant, std::make_tuple("SpecparamInConstant"sv, "specparams cannot be used in general constant expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaggedUnionMissingInit, std::make_tuple("TaggedUnionMissingInit"sv, "missing initializer expression for non-void tagged union member '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaggedUnionTarget, std::make_tuple("TaggedUnionTarget"sv, "tagged union expression can only be used in an assignment to a tagged union type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaskFromFinal, std::make_tuple("TaskFromFinal"sv, "cannot invoke a task from within a final block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaskFromFunction, std::make_tuple("TaskFromFunction"sv, "cannot invoke a task from within a function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TimingControlNotAllowed, std::make_tuple("TimingControlNotAllowed"sv, "timing control is not allowed in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooFewArguments, std::make_tuple("TooFewArguments"sv, "too few arguments for '{}'; expected {} but {} were provided"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyArguments, std::make_tuple("TooManyArguments"sv, "too many arguments for '{}'; expected {} but {} were provided"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnboundedNotAllowed, std::make_tuple("UnboundedNotAllowed"sv, "unbounded literal '$' not allowed here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnconnectedArg, std::make_tuple("UnconnectedArg"sv, "argument '{}' is missing a value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedClockingExpr, std::make_tuple("UnexpectedClockingExpr"sv, "unexpected expression after clocking event"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedConstraintBlock, std::make_tuple("UnexpectedConstraintBlock"sv, "unexpected constraint block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedWithClause, std::make_tuple("UnexpectedWithClause"sv, "unexpected 'with' clause"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnpackedConcatAssociative, std::make_tuple("UnpackedConcatAssociative"sv, "array concatenations cannot be used for associative arrays"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnpackedConcatSize, std::make_tuple("UnpackedConcatSize"sv, "array concatenation for {} requires {} elements but {} were provided"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UserDefPartialDriver, std::make_tuple("UserDefPartialDriver"sv, "net '{}' with user-defined nettype cannot be partially driven"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueRangeUnbounded, std::make_tuple("ValueRangeUnbounded"sv, "value range cannot be unbounded on both sides"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualIfaceDefparam, std::make_tuple("VirtualIfaceDefparam"sv, "interface instance cannot be assigned to a virtual interface because it is the target of a defparam or bind directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VoidAssignment, std::make_tuple("VoidAssignment"sv, "expression of type 'void' cannot be used in assignments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WithClauseNotAllowed, std::make_tuple("WithClauseNotAllowed"sv, "cannot use 'with' expression with '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WrongNumberAssignmentPatterns, std::make_tuple("WrongNumberAssignmentPatterns"sv, "assignment pattern for {} requires {} elements but {} were provided"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ArithOpMismatch, std::make_tuple("ArithOpMismatch"sv, "arithmetic between operands of different types ({} and {})"sv, DiagnosticSeverity::Warning, "arith-op-mismatch"sv)},
    {diag::BitwiseOpMismatch, std::make_tuple("BitwiseOpMismatch"sv, "bitwise operation between operands of different types ({} and {})"sv, DiagnosticSeverity::Warning, "bitwise-op-mismatch"sv)},
    {diag::ComparisonMismatch, std::make_tuple("ComparisonMismatch"sv, "comparison between operands of different types ({} and {})"sv, DiagnosticSeverity::Warning, "comparison-mismatch"sv)},
    {diag::FloatBoolConv, std::make_tuple("FloatBoolConv"sv, "implicit conversion from floating point type {} to boolean value"sv, DiagnosticSeverity::Warning, "float-bool-conv"sv)},
    {diag::FloatIntConv, std::make_tuple("FloatIntConv"sv, "implicit conversion from {} to {}"sv, DiagnosticSeverity::Warning, "float-int-conv"sv)},
    {diag::FloatNarrow, std::make_tuple("FloatNarrow"sv, "implicit conversion narrows from {} to {}"sv, DiagnosticSeverity::Warning, "float-narrow"sv)},
    {diag::FloatWiden, std::make_tuple("FloatWiden"sv, "implicit conversion widens from {} to {}"sv, DiagnosticSeverity::Warning, "float-widen"sv)},
    {diag::IgnoredSlice, std::make_tuple("IgnoredSlice"sv, "slice size ignored for left-to-right streaming operator"sv, DiagnosticSeverity::Warning, "ignored-slice"sv)},
    {diag::ImplicitConvert, std::make_tuple("ImplicitConvert"sv, "implicit conversion from {} to {}"sv, DiagnosticSeverity::Warning, "implicit-conv"sv)},
    {diag::IndexOOB, std::make_tuple("IndexOOB"sv, "cannot refer to element {} of {}"sv, DiagnosticSeverity::Warning, "index-oob"sv)},
    {diag::InputPortCoercion, std::make_tuple("InputPortCoercion"sv, "input net port '{}' coerced to 'inout'"sv, DiagnosticSeverity::Warning, "port-coercion"sv)},
    {diag::IntBoolConv, std::make_tuple("IntBoolConv"sv, "implicit conversion from {} to boolean value"sv, DiagnosticSeverity::Warning, "int-bool-conv"sv)},
    {diag::IntFloatConv, std::make_tuple("IntFloatConv"sv, "implicit conversion from {} to {}"sv, DiagnosticSeverity::Warning, "int-float-conv"sv)},
    {diag::NegativeTimingLimit, std::make_tuple("NegativeTimingLimit"sv, "timing check limit value '{}' should not be negative"sv, DiagnosticSeverity::Warning, "negative-timing-limit"sv)},
    {diag::NonblockingInFinal, std::make_tuple("NonblockingInFinal"sv, "nonblocking assignments in final blocks have no effect"sv, DiagnosticSeverity::Warning, "nonblocking-final"sv)},
    {diag::OutputPortCoercion, std::make_tuple("OutputPortCoercion"sv, "output net port '{}' coerced to 'inout'"sv, DiagnosticSeverity::Warning, "port-coercion"sv)},
    {diag::PortWidthExpand, std::make_tuple("PortWidthExpand"sv, "implicit conversion of port connection expands from {} to {} bits"sv, DiagnosticSeverity::Warning, "port-width-expand"sv)},
    {diag::PortWidthTruncate, std::make_tuple("PortWidthTruncate"sv, "implicit conversion of port connection truncates from {} to {} bits"sv, DiagnosticSeverity::Warning, "port-width-trunc"sv)},
    {diag::RangeOOB, std::make_tuple("RangeOOB"sv, "cannot select range of [{}:{}] from {}"sv, DiagnosticSeverity::Warning, "range-oob"sv)},
    {diag::RangeWidthOOB, std::make_tuple("RangeWidthOOB"sv, "cannot select range of {} elements from {}"sv, DiagnosticSeverity::Warning, "range-width-oob"sv)},
    {diag::ReversedValueRange, std::make_tuple("ReversedValueRange"sv, "reversed range will behave as if it were empty"sv, DiagnosticSeverity::Warning, "reversed-range"sv)},
    {diag::SignCompare, std::make_tuple("SignCompare"sv, "comparison of differently signed types ({} and {})"sv, DiagnosticSeverity::Warning, "sign-compare"sv)},
    {diag::SignConversion, std::make_tuple("SignConversion"sv, "implicit conversion changes signedness from {} to {}"sv, DiagnosticSeverity::Warning, "sign-conversion"sv)},
    {diag::SpecifyBlockParam, std::make_tuple("SpecifyBlockParam"sv, "parameters cannot be used in specify blocks"sv, DiagnosticSeverity::Warning, "specify-param"sv)},
    {diag::SpecifyPathConditionExpr, std::make_tuple("SpecifyPathConditionExpr"sv, "expression is not valid in a state-dependent path condition"sv, DiagnosticSeverity::Warning, "specify-condition-expr"sv)},
    {diag::UnsignedArithShift, std::make_tuple("UnsignedArithShift"sv, "arithmetic right shift of unsigned type {} will always shift in zeros (use logical shift if that is intended)"sv, DiagnosticSeverity::Warning, "unsigned-arith-shift"sv)},
    {diag::UnsizedInConcat, std::make_tuple("UnsizedInConcat"sv, "unsized integer in concat; using a width of {}"sv, DiagnosticSeverity::Warning, "unsized-concat"sv)},
    {diag::UselessCast, std::make_tuple("UselessCast"sv, "useless cast from {} to the same type"sv, DiagnosticSeverity::Warning, "useless-cast"sv)},
    {diag::WidthExpand, std::make_tuple("WidthExpand"sv, "implicit conversion expands from {} to {} bits"sv, DiagnosticSeverity::Warning, "width-expand"sv)},
    {diag::WidthTruncate, std::make_tuple("WidthTruncate"sv, "implicit conversion truncates from {} to {} bits"sv, DiagnosticSeverity::Warning, "width-trunc"sv)},
    {diag::AttributesNotAllowed, std::make_tuple("AttributesNotAllowed"sv, "attributes are not allowed here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedExpression, std::make_tuple("ExpectedExpression"sv, "expected expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WrongLanguageVersion, std::make_tuple("WrongLanguageVersion"sv, "language feature is not supported in version {}; use the --std option to select a supported language version"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteAssignedHere, std::make_tuple("NoteAssignedHere"sv, "also assigned here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteConfigRule, std::make_tuple("NoteConfigRule"sv, "from configuration here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteDeclarationHere, std::make_tuple("NoteDeclarationHere"sv, "declared here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteDrivenHere, std::make_tuple("NoteDrivenHere"sv, "driven here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteFromHere2, std::make_tuple("NoteFromHere2"sv, "from '{}' and '{}'"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteOriginalAssign, std::make_tuple("NoteOriginalAssign"sv, "original assignment here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NotePreviousDefinition, std::make_tuple("NotePreviousDefinition"sv, "previous definition here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NotePreviousMatch, std::make_tuple("NotePreviousMatch"sv, "previous match here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NotePreviousUsage, std::make_tuple("NotePreviousUsage"sv, "previous usage here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteReferencedHere, std::make_tuple("NoteReferencedHere"sv, "referenced here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::BadBinaryDigit, std::make_tuple("BadBinaryDigit"sv, "expected binary digit"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadDecimalDigit, std::make_tuple("BadDecimalDigit"sv, "expected decimal digit"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadHexDigit, std::make_tuple("BadHexDigit"sv, "expected hexadecimal digit"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadOctalDigit, std::make_tuple("BadOctalDigit"sv, "expected octal digit"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DecimalDigitMultipleUnknown, std::make_tuple("DecimalDigitMultipleUnknown"sv, "decimal literals cannot have multiple digits if at least one of them is X or Z"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EmbeddedNull, std::make_tuple("EmbeddedNull"sv, "embedded NUL in source text"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EscapedWhitespace, std::make_tuple("EscapedWhitespace"sv, "unexpected whitespace after escape character"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedClosingQuote, std::make_tuple("ExpectedClosingQuote"sv, "missing closing quote"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIntegerBaseAfterSigned, std::make_tuple("ExpectedIntegerBaseAfterSigned"sv, "expected integer base specifier after signed specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidHexEscapeCode, std::make_tuple("InvalidHexEscapeCode"sv, "invalid hexadecimal number"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MisplacedDirectiveChar, std::make_tuple("MisplacedDirectiveChar"sv, "expected directive name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedBlockComment, std::make_tuple("NestedBlockComment"sv, "nested block comments are disallowed by SystemVerilog"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonPrintableChar, std::make_tuple("NonPrintableChar"sv, "non-printable control character in source text"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::OctalEscapeCodeTooBig, std::make_tuple("OctalEscapeCodeTooBig"sv, "octal escape code is too large to be an ASCII character"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyLexerErrors, std::make_tuple("TooManyLexerErrors"sv, "lexer has encountered too many errors (input is a binary file?)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UTF8Char, std::make_tuple("UTF8Char"sv, "UTF-8 sequence in source text; SystemVerilog identifiers must be ASCII"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnicodeBOM, std::make_tuple("UnicodeBOM"sv, "UTF-16 BOM at start of source text; source encoding must be UTF-8"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnterminatedBlockComment, std::make_tuple("UnterminatedBlockComment"sv, "block comment unclosed at end of file"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidEncodingByte, std::make_tuple("InvalidEncodingByte"sv, "invalid {} byte '{}' -- attempting to skip remaining encoded text"sv, DiagnosticSeverity::Warning, "invalid-encoding-byte"sv)},
    {diag::InvalidUTF8Seq, std::make_tuple("InvalidUTF8Seq"sv, "invalid UTF-8 sequence in source text"sv, DiagnosticSeverity::Warning, "invalid-source-encoding"sv)},
    {diag::NonstandardEscapeCode, std::make_tuple("NonstandardEscapeCode"sv, "non-standard character escape sequence '\\{}'"sv, DiagnosticSeverity::Warning, "nonstandard-escape-code"sv)},
    {diag::ProtectEncodingBytes, std::make_tuple("ProtectEncodingBytes"sv, "{} bytes decoded in protected envelope but encoding pragma said to expect {}"sv, DiagnosticSeverity::Warning, "protect-encoding-bytes"sv)},
    {diag::RawProtectEOF, std::make_tuple("RawProtectEOF"sv, "reached end of file while processing 'raw' encoded protected envelope"sv, DiagnosticSeverity::Warning, "raw-protect-eof"sv)},
    {diag::UnknownEscapeCode, std::make_tuple("UnknownEscapeCode"sv, "unknown character escape sequence '\\{}'"sv, DiagnosticSeverity::Warning, "unknown-escape-code"sv)},
    {diag::AmbiguousWildcardImport, std::make_tuple("AmbiguousWildcardImport"sv, "multiple imports found for identifier '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoVariableHierarchical, std::make_tuple("AutoVariableHierarchical"sv, "cannot refer to automatic variable via hierarchical reference"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadInstanceArrayRange, std::make_tuple("BadInstanceArrayRange"sv, "cannot select range of [{}:{}] from instance array of [{}:{}]"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerHierarchical, std::make_tuple("CheckerHierarchical"sv, "cannot access checker members hierarchically"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CompilationUnitFromPackage, std::make_tuple("CompilationUnitFromPackage"sv, "cannot reference compilation unit item from within a package"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CouldNotResolveHierarchicalPath, std::make_tuple("CouldNotResolveHierarchicalPath"sv, "could not resolve hierarchical path name '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefinitionUsedAsType, std::make_tuple("DefinitionUsedAsType"sv, "'{}' is {} definition but is used like a type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefinitionUsedAsValue, std::make_tuple("DefinitionUsedAsValue"sv, "'{}' is {} definition but is used as a value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DotIntoInstArray, std::make_tuple("DotIntoInstArray"sv, "object is an array so expecting an index here, not a dot"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DotOnType, std::make_tuple("DotOnType"sv, "cannot use dot operator on a type name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GenericClassScopeResolution, std::make_tuple("GenericClassScopeResolution"sv, "cannot refer to generic class with '::' without providing parameter assignments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::HierarchicalFromPackage, std::make_tuple("HierarchicalFromPackage"sv, "cannot use hierarchical reference from within a package"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceExtendIncomplete, std::make_tuple("IfaceExtendIncomplete"sv, "cannot extend or implement an incomplete forward typedef"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceExtendTypeParam, std::make_tuple("IfaceExtendTypeParam"sv, "cannot extend or implement a type parameter"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceImportExportTarget, std::make_tuple("IfaceImportExportTarget"sv, "could not find target for {} of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IllegalReferenceToProgramItem, std::make_tuple("IllegalReferenceToProgramItem"sv, "cannot reference program item from outside of a program"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ImportNameCollision, std::make_tuple("ImportNameCollision"sv, "import of '{}' collides with an existing declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InstanceArrayEndianMismatch, std::make_tuple("InstanceArrayEndianMismatch"sv, "endianness of selection [{}:{}] must match declared array range of [{}:{}]"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidConstructorAccess, std::make_tuple("InvalidConstructorAccess"sv, "cannot create instance of class '{}' because its constructor is declared '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidHierarchicalIfacePortConn, std::make_tuple("InvalidHierarchicalIfacePortConn"sv, "cannot connect interface port hierarchically through a generate block or instance array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidModportAccess, std::make_tuple("InvalidModportAccess"sv, "cannot access '{}' via modport '{}.{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidScopeIndexExpression, std::make_tuple("InvalidScopeIndexExpression"sv, "invalid hierarchical index expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidThisHandle, std::make_tuple("InvalidThisHandle"sv, "invalid use of 'this' outside of a non-static method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalMemberAccess, std::make_tuple("LocalMemberAccess"sv, "'{}' is a local member of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalNotAllowed, std::make_tuple("LocalNotAllowed"sv, "'local' qualifier not allowed here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedNonStaticClassMethod, std::make_tuple("NestedNonStaticClassMethod"sv, "call to non-static member function without object handle from nested class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedNonStaticClassProperty, std::make_tuple("NestedNonStaticClassProperty"sv, "invalid use of non-static class property '{}' from nested class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoDefaultSpecialization, std::make_tuple("NoDefaultSpecialization"sv, "generic class '{}' does not have a default specialization because some parameters have no default value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonStaticClassMethod, std::make_tuple("NonStaticClassMethod"sv, "call to non-static member function without object handle"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonStaticClassProperty, std::make_tuple("NonStaticClassProperty"sv, "invalid use of non-static class property '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAClass, std::make_tuple("NotAClass"sv, "'{}' is not a class type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAGenericClass, std::make_tuple("NotAGenericClass"sv, "'{}' is not a generic class type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAGenvar, std::make_tuple("NotAGenvar"sv, "'{}' is not a genvar"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAHierarchicalScope, std::make_tuple("NotAHierarchicalScope"sv, "cannot use dot operator on '{}'; it is not a variable or hierarchical scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAModport, std::make_tuple("NotAModport"sv, "'{}' is not a modport of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotASubroutine, std::make_tuple("NotASubroutine"sv, "'{}' is not a task or function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAType, std::make_tuple("NotAType"sv, "'{}' is not a type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAValue, std::make_tuple("NotAValue"sv, "'{}' cannot be used in an expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAnInterface, std::make_tuple("NotAnInterface"sv, "'{}' is not an interface instance or array of instances"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAnInterfaceOrPort, std::make_tuple("NotAnInterfaceOrPort"sv, "'{}' is not an interface instance or interface port name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ProtectedMemberAccess, std::make_tuple("ProtectedMemberAccess"sv, "'{}' is a protected member of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursiveDefinition, std::make_tuple("RecursiveDefinition"sv, "'{}' recursively depends on its own definition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::Redefinition, std::make_tuple("Redefinition"sv, "redefinition of '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RedefinitionDifferentType, std::make_tuple("RedefinitionDifferentType"sv, "redefinition of '{}' with a different type: {} vs {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ScopeIncompleteTypedef, std::make_tuple("ScopeIncompleteTypedef"sv, "cannot resolve scoped class member via incomplete forward typedef"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ScopeIndexOutOfRange, std::make_tuple("ScopeIndexOutOfRange"sv, "hierarchical index {} is out of scope's declared range"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ScopeNotIndexable, std::make_tuple("ScopeNotIndexable"sv, "hierarchical scope '{}' is not indexable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SuperNoBase, std::make_tuple("SuperNoBase"sv, "class '{}' does not have a super class"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SuperOutsideClass, std::make_tuple("SuperOutsideClass"sv, "cannot use 'super' handle outside of class scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeHierarchical, std::make_tuple("TypeHierarchical"sv, "cannot refer to type names via hierarchical reference"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypoIdentifier, std::make_tuple("TypoIdentifier"sv, "use of undeclared identifier '{}'; did you mean '{}'?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UndeclaredButFoundPackage, std::make_tuple("UndeclaredButFoundPackage"sv, "'{}' is a package, did you mean to use '::' here?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UndeclaredIdentifier, std::make_tuple("UndeclaredIdentifier"sv, "use of undeclared identifier '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedNameToken, std::make_tuple("UnexpectedNameToken"sv, "unexpected use of '{}' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedSelection, std::make_tuple("UnexpectedSelection"sv, "unexpected selection expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownClassMember, std::make_tuple("UnknownClassMember"sv, "no member named '{}' in class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownClassOrPackage, std::make_tuple("UnknownClassOrPackage"sv, "unknown class or package '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownCovergroupMember, std::make_tuple("UnknownCovergroupMember"sv, "no member named '{}' in covergroup '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownMember, std::make_tuple("UnknownMember"sv, "no member named '{}' in {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownPackageMember, std::make_tuple("UnknownPackageMember"sv, "no member named '{}' in package '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownSystemMethod, std::make_tuple("UnknownSystemMethod"sv, "unknown built-in method '{}' on type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnresolvedForwardTypedef, std::make_tuple("UnresolvedForwardTypedef"sv, "forward typedef '{}' does not resolve to a data type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UsedBeforeDeclared, std::make_tuple("UsedBeforeDeclared"sv, "identifier '{}' used before its declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteImportedFrom, std::make_tuple("NoteImportedFrom"sv, "imported from here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::DuplicateDefinition, std::make_tuple("DuplicateDefinition"sv, "duplicate definition of '{}'"sv, DiagnosticSeverity::Warning, "duplicate-definition"sv)},
    {diag::DuplicateImport, std::make_tuple("DuplicateImport"sv, "duplicate import declaration is redundant"sv, DiagnosticSeverity::Warning, "dup-import"sv)},
    {diag::UnknownSystemName, std::make_tuple("UnknownSystemName"sv, "unknown system name '{}'"sv, DiagnosticSeverity::Warning, "unknown-sys-name"sv)},
    {diag::TooManyErrors, std::make_tuple("TooManyErrors"sv, "too many errors emitted, stopping now [--error-limit=]"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownWarningOption, std::make_tuple("UnknownWarningOption"sv, "unknown warning option '{}'"sv, DiagnosticSeverity::Warning, "unknown-warning-option"sv)},
    {diag::DigitsLeadingUnderscore, std::make_tuple("DigitsLeadingUnderscore"sv, "numeric literals must not start with a leading underscore"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedVectorDigits, std::make_tuple("ExpectedVectorDigits"sv, "expected vector literal digits"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LiteralSizeIsZero, std::make_tuple("LiteralSizeIsZero"sv, "size of vector literal cannot be zero"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LiteralSizeTooLarge, std::make_tuple("LiteralSizeTooLarge"sv, "size of vector literal is too large (> {} bits)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingExponentDigits, std::make_tuple("MissingExponentDigits"sv, "expected exponent digits"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingFractionalDigits, std::make_tuple("MissingFractionalDigits"sv, "expected fractional digits after decimal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueExceedsMaxBitWidth, std::make_tuple("ValueExceedsMaxBitWidth"sv, "value exceeds maximum vector width ({} bits)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueMustBeIntegral, std::make_tuple("ValueMustBeIntegral"sv, "value must be integral"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueMustBePositive, std::make_tuple("ValueMustBePositive"sv, "value must be positive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueMustNotBeUnknown, std::make_tuple("ValueMustNotBeUnknown"sv, "value must not have any unknown bits"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ValueOutOfRange, std::make_tuple("ValueOutOfRange"sv, "{} is out of allowed range ({} to {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RealLiteralOverflow, std::make_tuple("RealLiteralOverflow"sv, "value of real literal is too large; maximum is {:.5e}"sv, DiagnosticSeverity::Warning, "real-overflow"sv)},
    {diag::RealLiteralUnderflow, std::make_tuple("RealLiteralUnderflow"sv, "value of real literal is too small; minimum is {:.5e}"sv, DiagnosticSeverity::Warning, "real-underflow"sv)},
    {diag::SignedIntegerOverflow, std::make_tuple("SignedIntegerOverflow"sv, "signed integer literal overflows 32 bits, will be truncated to {}"sv, DiagnosticSeverity::Warning, "int-overflow"sv)},
    {diag::VectorLiteralOverflow, std::make_tuple("VectorLiteralOverflow"sv, "vector literal too large for the given number of bits ({} bits needed)"sv, DiagnosticSeverity::Warning, "vector-overflow"sv)},
    {diag::AssertionPortDirNoLocal, std::make_tuple("AssertionPortDirNoLocal"sv, "assertion port cannot specify direction without also using the 'local' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionPortPropOutput, std::make_tuple("AssertionPortPropOutput"sv, "local variable formal arguments in properties cannot have direction 'output' or 'inout'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionPortRef, std::make_tuple("AssertionPortRef"sv, "assertion item port direction cannot be 'ref'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BindDirectiveInvalidName, std::make_tuple("BindDirectiveInvalidName"sv, "bind target name must be a simple module or interface identifier when a list of instances is provided"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CaseGenerateEmpty, std::make_tuple("CaseGenerateEmpty"sv, "case generate has no items"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CaseStatementEmpty, std::make_tuple("CaseStatementEmpty"sv, "{} statement has no items"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ChargeWithTriReg, std::make_tuple("ChargeWithTriReg"sv, "charge strength can only be specified for 'trireg' nets"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CheckerPortInout, std::make_tuple("CheckerPortInout"sv, "checker port direction cannot be 'inout'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClassSpecifierConflict, std::make_tuple("ClassSpecifierConflict"sv, "cannot specify both '{}' and '{}' on the same declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockingNameEmpty, std::make_tuple("ClockingNameEmpty"sv, "expected clocking block name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigMissingName, std::make_tuple("ConfigMissingName"sv, "cannot use 'config' without also specifying a target name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigParamLiteral, std::make_tuple("ConfigParamLiteral"sv, "parameters in configurations can only be set to literal values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigParamsOrdered, std::make_tuple("ConfigParamsOrdered"sv, "parameter assignments in configurations must use explicit name notation, not positional notation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConfigSpecificCellLiblist, std::make_tuple("ConfigSpecificCellLiblist"sv, "cannot specify a liblist when using a cell rule that targets a specific library already"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstFunctionPortRequiresRef, std::make_tuple("ConstFunctionPortRequiresRef"sv, "'const' in subroutine formal port requires 'ref' direction specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstraintQualOutOfBlock, std::make_tuple("ConstraintQualOutOfBlock"sv, "'{}' qualifier is not allowed on out-of-block constraint definitions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstructorOutsideClass, std::make_tuple("ConstructorOutsideClass"sv, "constructor cannot be declared outside of a class"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConstructorReturnType, std::make_tuple("ConstructorReturnType"sv, "class constructors cannot declare a return type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverCrossItems, std::make_tuple("CoverCrossItems"sv, "cover cross declaration requires at least two coverage items"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageBinDefSeqSize, std::make_tuple("CoverageBinDefSeqSize"sv, "default sequence bin cannot be declared as an array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageBinDefaultIgnore, std::make_tuple("CoverageBinDefaultIgnore"sv, "default coverage bins cannot be ignored"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageBinDefaultWildcard, std::make_tuple("CoverageBinDefaultWildcard"sv, "default coverage bins cannot be marked 'wildcard'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverageBinTransSize, std::make_tuple("CoverageBinTransSize"sv, "transition coverage bins cannot have an explicit size"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeclModifierConflict, std::make_tuple("DeclModifierConflict"sv, "modifier '{}' cannot be used together with '{}' in a declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeclModifierOrdering, std::make_tuple("DeclModifierOrdering"sv, "modifier '{}' must come before '{}' in a declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeclarationsAtStart, std::make_tuple("DeclarationsAtStart"sv, "declaration must come before all statements in the block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DefaultArgNotAllowed, std::make_tuple("DefaultArgNotAllowed"sv, "'default' argument is not allowed here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeferredDelayMustBeZero, std::make_tuple("DeferredDelayMustBeZero"sv, "deferred assertion delay must be zero"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::Delay3NotAllowed, std::make_tuple("Delay3NotAllowed"sv, "'{}' gates can have a maximum of two delay values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::Delay3UdpNotAllowed, std::make_tuple("Delay3UdpNotAllowed"sv, "instances of user-defined primitives can have a maximum of two delay values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DelaysNotAllowed, std::make_tuple("DelaysNotAllowed"sv, "delays are not allowed on '{}' gates"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DerivedCovergroupNoBase, std::make_tuple("DerivedCovergroupNoBase"sv, "covergroup is marked 'extends' but is in a class that has no base class"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DerivedCovergroupNotInClass, std::make_tuple("DerivedCovergroupNotInClass"sv, "covergroup inheritance can only be used inside a class"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DirectionOnInterfacePort, std::make_tuple("DirectionOnInterfacePort"sv, "direction specifier on interface port is not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DriveStrengthHighZ, std::make_tuple("DriveStrengthHighZ"sv, "combination of drive strengths is invalid; cannot combine 'highz0' and 'highz1'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DriveStrengthInvalid, std::make_tuple("DriveStrengthInvalid"sv, "combination of drive strengths is invalid; need one for value '0' and one for '1'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DriveStrengthNotAllowed, std::make_tuple("DriveStrengthNotAllowed"sv, "drive strengths are not allowed on '{}' gates"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateClassSpecifier, std::make_tuple("DuplicateClassSpecifier"sv, "duplicate '{}' specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateDeclModifier, std::make_tuple("DuplicateDeclModifier"sv, "duplicate '{}' modifier in declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DuplicateQualifier, std::make_tuple("DuplicateQualifier"sv, "duplicate '{}' qualifier in declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EdgeDescWrongKeyword, std::make_tuple("EdgeDescWrongKeyword"sv, "edge descriptor list cannot be used after '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EndNameMismatch, std::make_tuple("EndNameMismatch"sv, "'{}' doesn't match previous name '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EndNameNotEmpty, std::make_tuple("EndNameNotEmpty"sv, "trailing name not allowed on previously unnamed block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedAnsiPort, std::make_tuple("ExpectedAnsiPort"sv, "expected ansi port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedArgument, std::make_tuple("ExpectedArgument"sv, "expected argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedAssertionItemPort, std::make_tuple("ExpectedAssertionItemPort"sv, "expected assertion item construct port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedAssignmentKey, std::make_tuple("ExpectedAssignmentKey"sv, "expected assignment key"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedAttribute, std::make_tuple("ExpectedAttribute"sv, "expected attribute"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedCaseItem, std::make_tuple("ExpectedCaseItem"sv, "expected case item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedClassSpecifier, std::make_tuple("ExpectedClassSpecifier"sv, "expected class specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedClockingSkew, std::make_tuple("ExpectedClockingSkew"sv, "expected clocking skew"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedConditionalPattern, std::make_tuple("ExpectedConditionalPattern"sv, "expected conditional pattern"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedConstraintName, std::make_tuple("ExpectedConstraintName"sv, "invalid constraint block name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedContinuousAssignment, std::make_tuple("ExpectedContinuousAssignment"sv, "expected continuous assignment"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedDPISpecString, std::make_tuple("ExpectedDPISpecString"sv, "expected DPI spec string"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedDeclarator, std::make_tuple("ExpectedDeclarator"sv, "expected a declaration name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedDistItem, std::make_tuple("ExpectedDistItem"sv, "expected dist item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedEdgeDescriptor, std::make_tuple("ExpectedEdgeDescriptor"sv, "expected edge descriptor"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedEnumBase, std::make_tuple("ExpectedEnumBase"sv, "expected enum base type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedForInitializer, std::make_tuple("ExpectedForInitializer"sv, "expected for loop initializer"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedFunctionPort, std::make_tuple("ExpectedFunctionPort"sv, "expected subroutine port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedFunctionPortList, std::make_tuple("ExpectedFunctionPortList"sv, "expected function port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedGenvarIterVar, std::make_tuple("ExpectedGenvarIterVar"sv, "expected genvar iteration variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedHierarchicalInstantiation, std::make_tuple("ExpectedHierarchicalInstantiation"sv, "expected hierarchical instantiation"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIdentifier, std::make_tuple("ExpectedIdentifier"sv, "expected identifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIfOrCase, std::make_tuple("ExpectedIfOrCase"sv, "expected 'if' or 'case' after '{}' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIntegerLiteral, std::make_tuple("ExpectedIntegerLiteral"sv, "expected integer literal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedInterfaceClassName, std::make_tuple("ExpectedInterfaceClassName"sv, "expected interface class name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedMember, std::make_tuple("ExpectedMember"sv, "expected member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedModportPort, std::make_tuple("ExpectedModportPort"sv, "expected modport item port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedNetStrength, std::make_tuple("ExpectedNetStrength"sv, "expected net strength keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedNonAnsiPort, std::make_tuple("ExpectedNonAnsiPort"sv, "expected non-ansi port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPackageImport, std::make_tuple("ExpectedPackageImport"sv, "expected package import"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedParameterPort, std::make_tuple("ExpectedParameterPort"sv, "expected parameter declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPathOp, std::make_tuple("ExpectedPathOp"sv, "expected path operator ('*>' or '=>')"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPattern, std::make_tuple("ExpectedPattern"sv, "expected pattern"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPortConnection, std::make_tuple("ExpectedPortConnection"sv, "expected port connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPortList, std::make_tuple("ExpectedPortList"sv, "expected parameter list or port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedRsRule, std::make_tuple("ExpectedRsRule"sv, "expected randsequence production rule"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedSampleKeyword, std::make_tuple("ExpectedSampleKeyword"sv, "expected 'sample' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedStatement, std::make_tuple("ExpectedStatement"sv, "expected statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedStreamExpression, std::make_tuple("ExpectedStreamExpression"sv, "expected stream expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedStringLiteral, std::make_tuple("ExpectedStringLiteral"sv, "expected string literal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedSubroutineName, std::make_tuple("ExpectedSubroutineName"sv, "expected subroutine name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedToken, std::make_tuple("ExpectedToken"sv, "expected '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedUdpPort, std::make_tuple("ExpectedUdpPort"sv, "expected UDP port"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedUdpSymbol, std::make_tuple("ExpectedUdpSymbol"sv, "expected UDP symbol"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedValueRangeElement, std::make_tuple("ExpectedValueRangeElement"sv, "expected value range element"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedVariableAssignment, std::make_tuple("ExpectedVariableAssignment"sv, "expected variable assignment"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExternWildcardPortList, std::make_tuple("ExternWildcardPortList"sv, "extern declaration cannot have a wildcard port list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FinalSpecifierLast, std::make_tuple("FinalSpecifierLast"sv, "'final' specifier must come last in a list of class override specifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FinalWithPure, std::make_tuple("FinalWithPure"sv, "'final' specifier cannot be used with a pure virtual member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GlobalClockingEmpty, std::make_tuple("GlobalClockingEmpty"sv, "global clocking block cannot declare items"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfNoneEdgeSensitive, std::make_tuple("IfNoneEdgeSensitive"sv, "ifnone specify path cannot be an edge-sensitive path"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::IfaceMethodPure, std::make_tuple("IfaceMethodPure"sv, "method in interface class must be marked 'pure'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ImplicitNotAllowed, std::make_tuple("ImplicitNotAllowed"sv, "expected data type (implicit type name not allowed)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InOutDefaultSkew, std::make_tuple("InOutDefaultSkew"sv, "inout direction for default skew not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InitializerRequired, std::make_tuple("InitializerRequired"sv, "initializer expression required"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectDelaySyntax, std::make_tuple("InterconnectDelaySyntax"sv, "interconnect net delays can only be a single value"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectInitializer, std::make_tuple("InterconnectInitializer"sv, "interconnect nets cannot have initializers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InterconnectTypeSyntax, std::make_tuple("InterconnectTypeSyntax"sv, "interconnect nets cannot have an explicit type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidAccessDotColon, std::make_tuple("InvalidAccessDotColon"sv, "invalid access token; '{}' should be '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidConstraintQualifier, std::make_tuple("InvalidConstraintQualifier"sv, "invalid constraint qualifier '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidCoverageOption, std::make_tuple("InvalidCoverageOption"sv, "invalid coverage option assignment"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDelayValue, std::make_tuple("InvalidDelayValue"sv, "invalid delay value expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDistExpression, std::make_tuple("InvalidDistExpression"sv, "cannot use a 'dist' expression in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidEdgeDescriptor, std::make_tuple("InvalidEdgeDescriptor"sv, "invalid edge descriptor (expected 01, 10, or x/z transitions)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidForInitializer, std::make_tuple("InvalidForInitializer"sv, "for loop initializer must be an assignment expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidGenvarIterExpression, std::make_tuple("InvalidGenvarIterExpression"sv, "invalid genvar iteration expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidMethodQualifier, std::make_tuple("InvalidMethodQualifier"sv, "invalid method qualifier '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPackageDecl, std::make_tuple("InvalidPackageDecl"sv, "invalid package declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPropertyIndex, std::make_tuple("InvalidPropertyIndex"sv, "only a single count of cycles is allowed for '{}' expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPropertyQualifier, std::make_tuple("InvalidPropertyQualifier"sv, "invalid property qualifier '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPropertyRange, std::make_tuple("InvalidPropertyRange"sv, "expected a range of cycles for '{}' expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidPullStrength, std::make_tuple("InvalidPullStrength"sv, "invalid strength for '{}' gate"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidQualifierForConstructor, std::make_tuple("InvalidQualifierForConstructor"sv, "invalid qualifier for constructor"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidQualifierForIfaceMember, std::make_tuple("InvalidQualifierForIfaceMember"sv, "invalid qualifier for interface class member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidQualifierForMember, std::make_tuple("InvalidQualifierForMember"sv, "invalid qualifier for member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidRepeatRange, std::make_tuple("InvalidRepeatRange"sv, "invalid repetition range"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSuperNew, std::make_tuple("InvalidSuperNew"sv, "super class constructor can only be called from the first statement in a derived class's constructor"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LabelAndName, std::make_tuple("LabelAndName"sv, "cannot specify both a label and a name for the same block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MethodStaticLifetime, std::make_tuple("MethodStaticLifetime"sv, "class methods cannot have static lifetime"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MisplacedTrailingSeparator, std::make_tuple("MisplacedTrailingSeparator"sv, "misplaced trailing '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingModportPortDirection, std::make_tuple("MissingModportPortDirection"sv, "modport port declaration is missing direction specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultCases, std::make_tuple("MultipleDefaultCases"sv, "{} statement has multiple default cases"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleDefaultRules, std::make_tuple("MultipleDefaultRules"sv, "configuration cannot have more than one default rule"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleGenerateDefaultCases, std::make_tuple("MultipleGenerateDefaultCases"sv, "case generate has multiple default cases"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultipleParallelTerminals, std::make_tuple("MultipleParallelTerminals"sv, "cannot specify multiple terminals for parallel path connection"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedIface, std::make_tuple("NestedIface"sv, "interface classes cannot be nested"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NewKeywordQualified, std::make_tuple("NewKeywordQualified"sv, "invalid scope access on 'new' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoCommaInList, std::make_tuple("NoCommaInList"sv, "this list is delimited by spaces, not commas"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoLabelOnSemicolon, std::make_tuple("NoLabelOnSemicolon"sv, "labels are not allowed on empty semicolon"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInAnonymousProgram, std::make_tuple("NotAllowedInAnonymousProgram"sv, "member not allowed in anonymous program declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInCU, std::make_tuple("NotAllowedInCU"sv, "member not allowed at compilation unit scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInChecker, std::make_tuple("NotAllowedInChecker"sv, "member not allowed in checker declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInClass, std::make_tuple("NotAllowedInClass"sv, "member not allowed in class declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInClocking, std::make_tuple("NotAllowedInClocking"sv, "member not allowed in clocking block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInGenerate, std::make_tuple("NotAllowedInGenerate"sv, "member not allowed in generate block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInIfaceClass, std::make_tuple("NotAllowedInIfaceClass"sv, "member not allowed in interface class declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInInterface, std::make_tuple("NotAllowedInInterface"sv, "member not allowed in interface declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInModule, std::make_tuple("NotAllowedInModule"sv, "member not allowed in module declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInPackage, std::make_tuple("NotAllowedInPackage"sv, "member not allowed in package"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAllowedInProgram, std::make_tuple("NotAllowedInProgram"sv, "member not allowed in program declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::OverridingExtends, std::make_tuple("OverridingExtends"sv, "'{}' is marked 'extends' but doesn't override a base class virtual member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedDimsOnUnpacked, std::make_tuple("PackedDimsOnUnpacked"sv, "unpacked types cannot have packed dimensions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ParseTreeTooDeep, std::make_tuple("ParseTreeTooDeep"sv, "language constructs are too deeply nested"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PullStrengthHighZ, std::make_tuple("PullStrengthHighZ"sv, "pullup and pulldown strengths cannot be 'highz0' or 'highz1'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PulseControlPATHPULSE, std::make_tuple("PulseControlPATHPULSE"sv, "pulse control specparam names must start with 'PATHPULSE$'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PulseControlSpecifyParent, std::make_tuple("PulseControlSpecifyParent"sv, "pulse control specparams can only be declared in specify blocks"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PureRequiresVirtual, std::make_tuple("PureRequiresVirtual"sv, "'pure' keyword must be followed by 'virtual'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QualifierConflict, std::make_tuple("QualifierConflict"sv, "qualifier '{}' cannot be used together with '{}' in a declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QualifierNotFirst, std::make_tuple("QualifierNotFirst"sv, "'{}' must come first in a list of qualifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QualifiersOnOutOfBlock, std::make_tuple("QualifiersOnOutOfBlock"sv, "qualifiers are not allowed on out-of-block method definitions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandJoinNotEnough, std::make_tuple("RandJoinNotEnough"sv, "rand join list must contain at least two productions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandJoinProdItem, std::make_tuple("RandJoinProdItem"sv, "rand join list can only contain simple references to other productions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandOnPackedMember, std::make_tuple("RandOnPackedMember"sv, "packed members cannot have random modifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandOnUnionMember, std::make_tuple("RandOnUnionMember"sv, "members of unions cannot have random modifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RegAfterNettype, std::make_tuple("RegAfterNettype"sv, "net type keyword cannot be followed by the 'reg' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ScopedClassCopy, std::make_tuple("ScopedClassCopy"sv, "typed constructor calls are not allowed for a shallow copy"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SolveBeforeDisallowed, std::make_tuple("SolveBeforeDisallowed"sv, "constraint ordering directive is not allowed within a nested constraint block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SpecifiersNotAllowed, std::make_tuple("SpecifiersNotAllowed"sv, "class override specifiers are not allowed here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::StaticFuncSpecifier, std::make_tuple("StaticFuncSpecifier"sv, "static members cannot have override specifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SubroutinePrototypeScoped, std::make_tuple("SubroutinePrototypeScoped"sv, "subroutine prototype cannot have a scoped name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaggedStruct, std::make_tuple("TaggedStruct"sv, "structs cannot be declared '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaskConstructor, std::make_tuple("TaskConstructor"sv, "class constructors cannot be tasks"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaskReturnType, std::make_tuple("TaskReturnType"sv, "tasks cannot declare a return type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyEdgeDescriptors, std::make_tuple("TooManyEdgeDescriptors"sv, "cannot have more than six pairs of edge transitions in list"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeRefDeclVar, std::make_tuple("TypeRefDeclVar"sv, "a type reference cannot be used in a variable declaration without a preceeding 'var' keyword"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpCombState, std::make_tuple("UdpCombState"sv, "combinational primitive row should not have a current state field"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpDupTransition, std::make_tuple("UdpDupTransition"sv, "cannot have more than one input transition per row in a state table"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpEdgeInComb, std::make_tuple("UdpEdgeInComb"sv, "edge transition can only be used in a sequential primitive -- are you missing a 'reg' specifier on the output port?"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidEdgeSymbol, std::make_tuple("UdpInvalidEdgeSymbol"sv, "invalid symbol '{}' in edge transition specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidInputOnly, std::make_tuple("UdpInvalidInputOnly"sv, "'{}' is only allowed in input fields of sequential primitives"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidMinus, std::make_tuple("UdpInvalidMinus"sv, "'-' is only allowed in the output field of a sequential primitive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidOutput, std::make_tuple("UdpInvalidOutput"sv, "'{}' is not allowed in output field of state table"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidSymbol, std::make_tuple("UdpInvalidSymbol"sv, "invalid symbol '{}' in state table"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpInvalidTransition, std::make_tuple("UdpInvalidTransition"sv, "transition specifiers are only allowed in input fields"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpSequentialState, std::make_tuple("UdpSequentialState"sv, "sequential primitive row is missing a current state field"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpSingleChar, std::make_tuple("UdpSingleChar"sv, "state table entry can only be a single symbol"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpTransSameChar, std::make_tuple("UdpTransSameChar"sv, "edge transition must be between two different values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UdpTransitionLength, std::make_tuple("UdpTransitionLength"sv, "transition specifier requires exactly two symbols"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedEndDelim, std::make_tuple("UnexpectedEndDelim"sv, "unexpected '{}' delimiter"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedLetPortKeyword, std::make_tuple("UnexpectedLetPortKeyword"sv, "unexpected use of '{}' in 'let' port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedQualifiers, std::make_tuple("UnexpectedQualifiers"sv, "unexpected qualifiers on class member"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UniquePriorityAfterElse, std::make_tuple("UniquePriorityAfterElse"sv, "cannot use 'unique' or 'priority' keyword after 'else'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnpackedSigned, std::make_tuple("UnpackedSigned"sv, "unpacked type cannot have signedness declared"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VoidNotAllowed, std::make_tuple("VoidNotAllowed"sv, "'void' type not allowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WireDataType, std::make_tuple("WireDataType"sv, "expected a data type here; 'wire' is not a data type, it's a net type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WrongSpecifyDelayCount, std::make_tuple("WrongSpecifyDelayCount"sv, "expected one, two, three, six, or twelve delay values assigned to module path"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteLastBlockEnded, std::make_tuple("NoteLastBlockEnded"sv, "and ended here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteLastBlockStarted, std::make_tuple("NoteLastBlockStarted"sv, "last complete block started here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteToMatchThis, std::make_tuple("NoteToMatchThis"sv, "to match this '{}'"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::DPIPureTask, std::make_tuple("DPIPureTask"sv, "DPI tasks cannot be marked 'pure'"sv, DiagnosticSeverity::Warning, "dpi-pure-task"sv)},
    {diag::EmptyAssignmentPattern, std::make_tuple("EmptyAssignmentPattern"sv, "empty assignment patterns are disallowed by SystemVerilog"sv, DiagnosticSeverity::Warning, "empty-pattern"sv)},
    {diag::EmptyBody, std::make_tuple("EmptyBody"sv, "{} has empty body (put the semicolon on a separate line to silence this warning)"sv, DiagnosticSeverity::Warning, "empty-body"sv)},
    {diag::LifetimeForPrototype, std::make_tuple("LifetimeForPrototype"sv, "lifetime specifier is not allowed on prototype declaration"sv, DiagnosticSeverity::Warning, "lifetime-prototype"sv)},
    {diag::NonStandardGenBlock, std::make_tuple("NonStandardGenBlock"sv, "standalone generate block without loop or condition is not allowed in SystemVerilog"sv, DiagnosticSeverity::Warning, "nonstandard-generate"sv)},
    {diag::NonstandardDist, std::make_tuple("NonstandardDist"sv, "use of parentheses around 'dist' expression is non-standard"sv, DiagnosticSeverity::Warning, "nonstandard-dist"sv)},
    {diag::NonstandardForeach, std::make_tuple("NonstandardForeach"sv, "non-standard foreach loop variable list"sv, DiagnosticSeverity::Warning, "nonstandard-foreach"sv)},
    {diag::SplitDistWeightOp, std::make_tuple("SplitDistWeightOp"sv, "split dist weight operator is not allowed; SystemVerilog requires that they be joined together"sv, DiagnosticSeverity::Warning, "split-distweight-op"sv)},
    {diag::CouldNotOpenIncludeFile, std::make_tuple("CouldNotOpenIncludeFile"sv, "'{}': {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DirectiveInsideDesignElement, std::make_tuple("DirectiveInsideDesignElement"sv, "directive is not allowed inside a design element"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExceededMaxIncludeDepth, std::make_tuple("ExceededMaxIncludeDepth"sv, "exceeded max include depth"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedDriveStrength, std::make_tuple("ExpectedDriveStrength"sv, "expected pull1 or pull0 strength"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedIncludeFileName, std::make_tuple("ExpectedIncludeFileName"sv, "expected an include file name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedMacroArgs, std::make_tuple("ExpectedMacroArgs"sv, "expected macro arguments for function-like macro"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedMacroStringifyEnd, std::make_tuple("ExpectedMacroStringifyEnd"sv, "expected closing quote to end macro stringification"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedNetType, std::make_tuple("ExpectedNetType"sv, "expected net type specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPragmaExpression, std::make_tuple("ExpectedPragmaExpression"sv, "expected pragma expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedPragmaName, std::make_tuple("ExpectedPragmaName"sv, "expected pragma name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedTimeLiteral, std::make_tuple("ExpectedTimeLiteral"sv, "expected time literal"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidInferredTimeScale, std::make_tuple("InvalidInferredTimeScale"sv, "invalid inferred time scale of {} for scope; time precision must be at least as precise as the time unit (i.e. it cannot be a longer unit of time)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidLineDirectiveLevel, std::make_tuple("InvalidLineDirectiveLevel"sv, "invalid level for `line directive, must be 0, 1, or 2"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidMacroName, std::make_tuple("InvalidMacroName"sv, "can't redefine compiler directive as a macro"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidTimeScalePrecision, std::make_tuple("InvalidTimeScalePrecision"sv, "time precision must be at least as precise as the time unit (i.e. it cannot be a longer unit of time)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidTimeScaleSpecifier, std::make_tuple("InvalidTimeScaleSpecifier"sv, "time scale must have a value of 1, 10, or 100"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MacroOpsOutsideDefinition, std::make_tuple("MacroOpsOutsideDefinition"sv, "macro operators may only be used within a macro definition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MacroTokensAfterPragmaProtect, std::make_tuple("MacroTokensAfterPragmaProtect"sv, "unexpected macro expansion after pragma protect directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MismatchedEndKeywordsDirective, std::make_tuple("MismatchedEndKeywordsDirective"sv, "no opening `begin_keywords directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MissingEndIfDirective, std::make_tuple("MissingEndIfDirective"sv, "missing `endif directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotEnoughMacroArgs, std::make_tuple("NotEnoughMacroArgs"sv, "not enough arguments provided to function-like macro"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursiveMacro, std::make_tuple("RecursiveMacro"sv, "expansion of macro '{}' is recursive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyActualMacroArgs, std::make_tuple("TooManyActualMacroArgs"sv, "too many arguments provided to function-like macro"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnbalancedMacroArgDims, std::make_tuple("UnbalancedMacroArgDims"sv, "unbalanced macro argument delimiters ((), [], or {{}}); didn't see an end '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UndefineBuiltinDirective, std::make_tuple("UndefineBuiltinDirective"sv, "cannot `undef built-in directives"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedConditionalDirective, std::make_tuple("UnexpectedConditionalDirective"sv, "unexpected conditional directive"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownDirective, std::make_tuple("UnknownDirective"sv, "unknown macro or compiler directive '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnrecognizedKeywordVersion, std::make_tuple("UnrecognizedKeywordVersion"sv, "unsupported keyword version specified for `begin_keywords"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteDirectiveHere, std::make_tuple("NoteDirectiveHere"sv, "after protect directive here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::ExpectedDiagPragmaArg, std::make_tuple("ExpectedDiagPragmaArg"sv, "expected diagnostic pragma argument"sv, DiagnosticSeverity::Warning, "expected-diag-arg"sv)},
    {diag::ExpectedDiagPragmaLevel, std::make_tuple("ExpectedDiagPragmaLevel"sv, "expected diagnostic severity (ignore,warn,error,fatal)"sv, DiagnosticSeverity::Warning, "pragma-diag-level"sv)},
    {diag::ExpectedProtectArg, std::make_tuple("ExpectedProtectArg"sv, "'{}' pragma expects a single string argument"sv, DiagnosticSeverity::Warning, "expected-protect-arg"sv)},
    {diag::ExpectedProtectKeyword, std::make_tuple("ExpectedProtectKeyword"sv, "expected pragma protect keyword"sv, DiagnosticSeverity::Warning, "expected-protect-keyword"sv)},
    {diag::ExtraPragmaArgs, std::make_tuple("ExtraPragmaArgs"sv, "too many arguments provided for pragma '{}'"sv, DiagnosticSeverity::Warning, "extra-pragma-args"sv)},
    {diag::ExtraProtectEnd, std::make_tuple("ExtraProtectEnd"sv, "pragma protect '{}' seen without corresponding start of block"sv, DiagnosticSeverity::Warning, "extra-protect-end"sv)},
    {diag::IgnoredMacroPaste, std::make_tuple("IgnoredMacroPaste"sv, "paste token is pointless because it is adjacent to whitespace"sv, DiagnosticSeverity::Warning, "ignored-macro-paste"sv)},
    {diag::InvalidPragmaNumber, std::make_tuple("InvalidPragmaNumber"sv, "expected a 32-bit integer value for pragma option"sv, DiagnosticSeverity::Warning, "invalid-pragma-number"sv)},
    {diag::InvalidPragmaViewport, std::make_tuple("InvalidPragmaViewport"sv, "pragma protect viewport requires options to be specified in the form (object = <string>, access = <string>)"sv, DiagnosticSeverity::Warning, "invalid-pragma-viewport"sv)},
    {diag::NestedProtectBegin, std::make_tuple("NestedProtectBegin"sv, "nested pragma protect begin-end blocks are not allowed"sv, DiagnosticSeverity::Warning, "nested-protect-begin"sv)},
    {diag::ProtectArgList, std::make_tuple("ProtectArgList"sv, "protect {} directive expects a parenthesized list of key=value options"sv, DiagnosticSeverity::Warning, "protect-arglist"sv)},
    {diag::ProtectedEnvelope, std::make_tuple("ProtectedEnvelope"sv, "protected envelopes cannot be decrypted and will be skipped entirely"sv, DiagnosticSeverity::Warning, "protected-envelope"sv)},
    {diag::RedefiningMacro, std::make_tuple("RedefiningMacro"sv, "macro '{}' redefined"sv, DiagnosticSeverity::Warning, "redef-macro"sv)},
    {diag::UnknownDiagPragmaArg, std::make_tuple("UnknownDiagPragmaArg"sv, "unknown diagnostic pragma argument '{}'"sv, DiagnosticSeverity::Warning, "unknown-diag-arg"sv)},
    {diag::UnknownPragma, std::make_tuple("UnknownPragma"sv, "unknown pragma '{}'"sv, DiagnosticSeverity::Warning, "unknown-pragma"sv)},
    {diag::UnknownProtectEncoding, std::make_tuple("UnknownProtectEncoding"sv, "unknown protect encoding '{}', treating as 'raw' -- source text may not be processed correctly"sv, DiagnosticSeverity::Warning, "unknown-protect-encoding"sv)},
    {diag::UnknownProtectKeyword, std::make_tuple("UnknownProtectKeyword"sv, "unknown pragma protect keyword '{}'"sv, DiagnosticSeverity::Warning, "unknown-protect-keyword"sv)},
    {diag::UnknownProtectOption, std::make_tuple("UnknownProtectOption"sv, "unknown protect {} option '{}'"sv, DiagnosticSeverity::Warning, "unknown-protect-option"sv)},
    {diag::AlwaysFFEventControl, std::make_tuple("AlwaysFFEventControl"sv, "always_ff procedure must have one and only one event control"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssertionExprType, std::make_tuple("AssertionExprType"sv, "expression of type {} is not valid in concurrent assertions; type must be cast compatible with an integral type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadDisableSoft, std::make_tuple("BadDisableSoft"sv, "target of 'disable soft' constraint must be a 'rand' variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadForceNetType, std::make_tuple("BadForceNetType"sv, "force and release cannot be applied to nets with a user-defined nettype"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadProceduralAssign, std::make_tuple("BadProceduralAssign"sv, "lvalue of procedural assign/deassign must be a variable or concatenation of variables -- bit-selects, part-selects, and references to nets are disallowed"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadSolveBefore, std::make_tuple("BadSolveBefore"sv, "target of 'solve before' constraint must be a random variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadUniquenessType, std::make_tuple("BadUniquenessType"sv, "{} is not a valid type for a uniqueness constraint"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BlockingInAlwaysFF, std::make_tuple("BlockingInAlwaysFF"sv, "always_ff procedures cannot have blocking timing controls"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CaseInsideKeyword, std::make_tuple("CaseInsideKeyword"sv, "set membership cannot be used with {} statements"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockVarSyncDrive, std::make_tuple("ClockVarSyncDrive"sv, "clocking signal '{}' can only be written via a synchronous drive (with the '<=' operator)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClockingBlockEventEdge, std::make_tuple("ClockingBlockEventEdge"sv, "cannot specify an edge when waiting on a clocking item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ConcurrentAssertActionBlock, std::make_tuple("ConcurrentAssertActionBlock"sv, "cannot have '{}' statement in the action block of another concurrent assertion"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CoverStmtNoFail, std::make_tuple("CoverStmtNoFail"sv, "cover statement cannot have a fail statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeferredAssertAutoRefArg, std::make_tuple("DeferredAssertAutoRefArg"sv, "cannot pass automatic variable '{}' to 'ref' argument '{}' in a deferred assertion action"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeferredAssertNonVoid, std::make_tuple("DeferredAssertNonVoid"sv, "cannot invoke non-void function '{}' from a deferred assertion action"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DeferredAssertOutArg, std::make_tuple("DeferredAssertOutArg"sv, "cannot invoke a subroutine with 'output' or 'inout' arguments from a deferred assertion action"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DelayNotNumeric, std::make_tuple("DelayNotNumeric"sv, "delay expression type {} is not numeric"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DisableIffLocalVar, std::make_tuple("DisableIffLocalVar"sv, "local variables cannot be used in disable iff conditions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DisableIffMatched, std::make_tuple("DisableIffMatched"sv, "'matched' method cannot be used in disable iff conditions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExprNotConstraint, std::make_tuple("ExprNotConstraint"sv, "expression is not allowed in a constraint"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExprNotStatement, std::make_tuple("ExprNotStatement"sv, "expression is not allowed as a statement"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ForeachDynamicDimAfterSkipped, std::make_tuple("ForeachDynamicDimAfterSkipped"sv, "foreach index '{}' can't iterate over a dynamically sized dimension since a previous dimension was omitted"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ForeachWildcardIndex, std::make_tuple("ForeachWildcardIndex"sv, "foreach loops cannot be used with associative arrays that have a wildcard index"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ForkJoinAlwaysComb, std::make_tuple("ForkJoinAlwaysComb"sv, "fork-join is not allowed in {} procedure"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GlobalSampledValueNested, std::make_tuple("GlobalSampledValueNested"sv, "global clocking future sampled value functions may not be nested"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InequivalentUniquenessTypes, std::make_tuple("InequivalentUniquenessTypes"sv, "type of '{}' is {} which is not equivalent to the type of other variables in the constraint (previously saw {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidBlockEventTarget, std::make_tuple("InvalidBlockEventTarget"sv, "block event must specify a task, function, or named block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidCommaInPropExpr, std::make_tuple("InvalidCommaInPropExpr"sv, "invalid comma-separated list in property expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidConstraintExpr, std::make_tuple("InvalidConstraintExpr"sv, "{} is not a valid type for a constraint expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDeferredAssertAction, std::make_tuple("InvalidDeferredAssertAction"sv, "deferred assertion action must be a subroutine call"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidDisableTarget, std::make_tuple("InvalidDisableTarget"sv, "disable statement must specify a task or block name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidEventExpression, std::make_tuple("InvalidEventExpression"sv, "invalid type {} for event expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidForStepExpression, std::make_tuple("InvalidForStepExpression"sv, "for loop step expression must be an assignment, increment/decrement operator, or a subroutine call"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidMatchItem, std::make_tuple("InvalidMatchItem"sv, "sequence match item must be a local variable assignment, increment/decrement operator, or subroutine call"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSignalEventInSeq, std::make_tuple("InvalidSignalEventInSeq"sv, "invalid use of event expression in sequence"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidSyntaxInEventExpr, std::make_tuple("InvalidSyntaxInEventExpr"sv, "expression is not valid in an event expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidUniquenessExpr, std::make_tuple("InvalidUniquenessExpr"sv, "uniqueness constraints can only contain references to random variables"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LocalVarMatchItem, std::make_tuple("LocalVarMatchItem"sv, "sequence match items can only modify local variables"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::LoopVarShadowsArray, std::make_tuple("LoopVarShadowsArray"sv, "loop variable '{}' shadows foreach array target"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MatchItemsAdmitEmpty, std::make_tuple("MatchItemsAdmitEmpty"sv, "sequences with match items cannot admit an empty match"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NestedDisableIff, std::make_tuple("NestedDisableIff"sv, "cannot instantiate '{}' here because it has a disable iff condition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoDefaultClocking, std::make_tuple("NoDefaultClocking"sv, "cycle delay cannot be used because no default clocking has been specified"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NonIntegralConstraintLiteral, std::make_tuple("NonIntegralConstraintLiteral"sv, "literals in constraints must be integers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAnArray, std::make_tuple("NotAnArray"sv, "name must refer to an iterable array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NotAnEvent, std::make_tuple("NotAnEvent"sv, "expression is not a triggerable event"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::OutRefFuncConstraint, std::make_tuple("OutRefFuncConstraint"sv, "cannot call a function with ref or output arguments in constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropAbortLocalVar, std::make_tuple("PropAbortLocalVar"sv, "local variables cannot be used in property abort conditions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropAbortMatched, std::make_tuple("PropAbortMatched"sv, "'matched' method cannot be used in property abort conditions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropExprInSequence, std::make_tuple("PropExprInSequence"sv, "cannot use property expression within a sequence"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropInstanceRepetition, std::make_tuple("PropInstanceRepetition"sv, "property instances cannot specify a repetition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PropertyLhsInvalid, std::make_tuple("PropertyLhsInvalid"sv, "left-hand side of operator must be a sequence expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandCInDist, std::make_tuple("RandCInDist"sv, "'randc' variables cannot be used in 'dist' constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandCInSoft, std::make_tuple("RandCInSoft"sv, "'randc' variables cannot be used in 'soft' constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandCInSolveBefore, std::make_tuple("RandCInSolveBefore"sv, "'randc' variables cannot be used in 'solve before' constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandCInUnique, std::make_tuple("RandCInUnique"sv, "'randc' variables cannot be used in 'unique' constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RandNeededInDist, std::make_tuple("RandNeededInDist"sv, "'dist' expression must reference at least one 'rand' variable"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursivePropDisableIff, std::make_tuple("RecursivePropDisableIff"sv, "recursive properties cannot have disable iff conditions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RepeatControlNotEvent, std::make_tuple("RepeatControlNotEvent"sv, "repeat control must be an event to count"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RepeatNotNumeric, std::make_tuple("RepeatNotNumeric"sv, "repeat type {} is not numeric"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RestrictStmtNoFail, std::make_tuple("RestrictStmtNoFail"sv, "restrict statement cannot have an action block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ReturnInParallel, std::make_tuple("ReturnInParallel"sv, "return statement is not allowed in fork-join block"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ReturnNotInSubroutine, std::make_tuple("ReturnNotInSubroutine"sv, "return statement is only valid inside task and function blocks"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqEmptyMatch, std::make_tuple("SeqEmptyMatch"sv, "sequence must not admit an empty match"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqInstanceRepetition, std::make_tuple("SeqInstanceRepetition"sv, "sequences cannot specify a non-consecutive or go-to repetition"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqNoMatch, std::make_tuple("SeqNoMatch"sv, "sequence can never be matched"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqOnlyEmpty, std::make_tuple("SeqOnlyEmpty"sv, "sequence admits only empty matches"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqRangeMinMax, std::make_tuple("SeqRangeMinMax"sv, "sequence range minimum '{}' is greater than specified maximum '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::StatementNotInLoop, std::make_tuple("StatementNotInLoop"sv, "statement can only be used inside a loop"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SubroutineMatchAutoRefArg, std::make_tuple("SubroutineMatchAutoRefArg"sv, "cannot pass automatic variable '{}' to 'ref' argument '{}' in a subroutine invoked from a sequence match item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SubroutineMatchNonVoid, std::make_tuple("SubroutineMatchNonVoid"sv, "cannot invoke non-void function '{}' from a sequence match item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SubroutineMatchOutArg, std::make_tuple("SubroutineMatchOutArg"sv, "cannot invoke a subroutine with 'output' or 'inout' arguments from a sequence match item"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TaskInConstraint, std::make_tuple("TaskInConstraint"sv, "cannot invoke tasks in constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ThroughoutLhsInvalid, std::make_tuple("ThroughoutLhsInvalid"sv, "left-hand side of 'throughout' operator must be a simple expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TimingInFuncNotAllowed, std::make_tuple("TimingInFuncNotAllowed"sv, "statements that pass time are not allowed in this context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TooManyForeachVars, std::make_tuple("TooManyForeachVars"sv, "too many loop variables for array of type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnexpectedPortDecl, std::make_tuple("UnexpectedPortDecl"sv, "unexpected port declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownConstraintLiteral, std::make_tuple("UnknownConstraintLiteral"sv, "'x' and 'z' values are not allowed in constraints"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VoidCastFuncCall, std::make_tuple("VoidCastFuncCall"sv, "void casting is only allowed for function calls"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::WriteToInputClockVar, std::make_tuple("WriteToInputClockVar"sv, "cannot write to input clocking signal '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoteExpandedHere, std::make_tuple("NoteExpandedHere"sv, "expanded here"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::NoteWhileExpanding, std::make_tuple("NoteWhileExpanding"sv, "while expanding {} '{}'"sv, DiagnosticSeverity::Note, ""sv)},
    {diag::BadProceduralForce, std::make_tuple("BadProceduralForce"sv, "lvalue of force/release must be a net, a variable, a constant select of a net, or a concatenation of these"sv, DiagnosticSeverity::Warning, "bad-procedural-force"sv)},
    {diag::EmptyStatement, std::make_tuple("EmptyStatement"sv, "extra ';' has no effect"sv, DiagnosticSeverity::Warning, "empty-stmt"sv)},
    {diag::EventExpressionConstant, std::make_tuple("EventExpressionConstant"sv, "edge expression is constant"sv, DiagnosticSeverity::Warning, "event-const"sv)},
    {diag::MultiBitEdge, std::make_tuple("MultiBitEdge"sv, "edge of expression of type {} will only trigger on changes to the first bit"sv, DiagnosticSeverity::Warning, "multibit-edge"sv)},
    {diag::PointlessVoidCast, std::make_tuple("PointlessVoidCast"sv, "cast to void for void-returning function '{}' has no effect"sv, DiagnosticSeverity::Warning, "pointless-void-cast"sv)},
    {diag::UnusedResult, std::make_tuple("UnusedResult"sv, "ignoring return value of '{}', cast to void to suppress"sv, DiagnosticSeverity::Warning, "unused-result"sv)},
    {diag::ArrayLocatorWithClause, std::make_tuple("ArrayLocatorWithClause"sv, "'{}' requires 'with' expression for searching"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ArrayMethodComparable, std::make_tuple("ArrayMethodComparable"sv, "array method '{}' can only be called on unpacked arrays of comparable values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ArrayMethodIntegral, std::make_tuple("ArrayMethodIntegral"sv, "array method '{}' can only be called on unpacked arrays of integral values"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AssociativeWildcardNotAllowed, std::make_tuple("AssociativeWildcardNotAllowed"sv, "'{}' cannot be called with an associative array with wildcard index type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::AutoVarTraced, std::make_tuple("AutoVarTraced"sv, "automatic variable '{}' cannot be traced"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadSystemSubroutineArg, std::make_tuple("BadSystemSubroutineArg"sv, "invalid argument type {} to system {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DimensionIndexInvalid, std::make_tuple("DimensionIndexInvalid"sv, "{} is not a valid dimension for {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::DynamicDimensionIndex, std::make_tuple("DynamicDimensionIndex"sv, "cannot refer to a dynamically sized dimension with index {} greater than 1"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedClassPropertyName, std::make_tuple("ExpectedClassPropertyName"sv, "expected class property name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedModOrVarName, std::make_tuple("ExpectedModOrVarName"sv, "expected module or variable name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedModuleInstance, std::make_tuple("ExpectedModuleInstance"sv, "expected module instance"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedModuleName, std::make_tuple("ExpectedModuleName"sv, "expected module name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedNetRef, std::make_tuple("ExpectedNetRef"sv, "expected a reference to a net"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedScopeName, std::make_tuple("ExpectedScopeName"sv, "expected scope name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedScopeOrAssert, std::make_tuple("ExpectedScopeOrAssert"sv, "expected scope or assertion name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ExpectedVariableName, std::make_tuple("ExpectedVariableName"sv, "expected variable name"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatEmptyArg, std::make_tuple("FormatEmptyArg"sv, "empty argument not allowed -- expecting value for '%{}' format specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatMismatchedType, std::make_tuple("FormatMismatchedType"sv, "value of type {} is invalid for '%{}' format specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatNoArgument, std::make_tuple("FormatNoArgument"sv, "no argument provided for '%{}' format specifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatSpecifierInvalidWidth, std::make_tuple("FormatSpecifierInvalidWidth"sv, "field width is invalid"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatSpecifierNotFloat, std::make_tuple("FormatSpecifierNotFloat"sv, "floating point format specifier options used on non-floating point field"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatSpecifierWidthNotAllowed, std::make_tuple("FormatSpecifierWidthNotAllowed"sv, "field width not allowed on '%{}' format specifiers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatTooManyArgs, std::make_tuple("FormatTooManyArgs"sv, "too many arguments provided for format string"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::FormatUnspecifiedType, std::make_tuple("FormatUnspecifiedType"sv, "cannot format values of type {} without a specification string"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GlobalClockEventExpr, std::make_tuple("GlobalClockEventExpr"sv, "$global_clock system function can only be called as an event expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::GlobalSampledValueAssertionExpr, std::make_tuple("GlobalSampledValueAssertionExpr"sv, "global clocking future sampled value functions may be invoked only in sequence and property expressions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InferredValDefArg, std::make_tuple("InferredValDefArg"sv, "the {} system function can only be used as the entire default value expression for a sequence or property formal argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidStringArg, std::make_tuple("InvalidStringArg"sv, "value of type {} is not a valid string argument"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NoGlobalClocking, std::make_tuple("NoGlobalClocking"sv, "no global clocking is available in this scope"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PastNumTicksInvalid, std::make_tuple("PastNumTicksInvalid"sv, "'number_of_ticks' argument must be greater than or equal to 1"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PlaRangeInAscendingOrder, std::make_tuple("PlaRangeInAscendingOrder"sv, "must specify dimensions in ascending order for PLA input type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QueryOnAssociativeNonIntegral, std::make_tuple("QueryOnAssociativeNonIntegral"sv, "'{}' cannot be called with an associative array with non-integral index type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QueryOnAssociativeWildcard, std::make_tuple("QueryOnAssociativeWildcard"sv, "'{}' cannot be called with an associative array with non-integral (or wildcard) index type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::QueryOnDynamicType, std::make_tuple("QueryOnDynamicType"sv, "array query function '{}' cannot be called on a dynamically sized type identifier"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SampledValueLocalVar, std::make_tuple("SampledValueLocalVar"sv, "local variables cannot be used in sampled value system functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SampledValueMatched, std::make_tuple("SampledValueMatched"sv, "'matched' method cannot be used in sampled value system functions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SeqMethodInputLocalVar, std::make_tuple("SeqMethodInputLocalVar"sv, "cannot call '{}' on a sequence that has 'input' or 'inout' local variable formal arguments"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SequenceMethodLocalVar, std::make_tuple("SequenceMethodLocalVar"sv, "local variables can only be passed to sequences on which '{}' is called if they are the entire argument and not a sub-expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SysFuncHierarchicalNotAllowed, std::make_tuple("SysFuncHierarchicalNotAllowed"sv, "hierarchical references are not allowed in calls to '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::SysFuncNotConst, std::make_tuple("SysFuncNotConst"sv, "'{}' is not allowed in a constant context"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeIsNotAClass, std::make_tuple("TypeIsNotAClass"sv, "{} is not a class type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::UnknownFormatSpecifier, std::make_tuple("UnknownFormatSpecifier"sv, "unknown format specifier '%{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::BadFinishNum, std::make_tuple("BadFinishNum"sv, "finish argument must have value of 0, 1, or 2"sv, DiagnosticSeverity::Warning, "finish-num"sv)},
    {diag::FormatMultibitStrength, std::make_tuple("FormatMultibitStrength"sv, "formatting strength values for multi-bit nets is non-standard"sv, DiagnosticSeverity::Warning, "format-multibit-strength"sv)},
    {diag::FormatRealInt, std::make_tuple("FormatRealInt"sv, "real value provided for integer format specifier '%{}'"sv, DiagnosticSeverity::Warning, "format-real"sv)},
    {diag::IsUnboundedParamArg, std::make_tuple("IsUnboundedParamArg"sv, "argument to $isunbounded must be the name of a parameter"sv, DiagnosticSeverity::Warning, "isunbounded-param-arg"sv)},
    {diag::MissingFormatSpecifier, std::make_tuple("MissingFormatSpecifier"sv, "missing format specifier"sv, DiagnosticSeverity::Warning, "missing-format"sv)},
    {diag::NonstandardSysFunc, std::make_tuple("NonstandardSysFunc"sv, "system function '{}' is non-standard"sv, DiagnosticSeverity::Warning, "nonstandard-sys-func"sv)},
    {diag::ArrayDimTooLarge, std::make_tuple("ArrayDimTooLarge"sv, "array dimension of {} is too large; maximum number of elements is {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::CannotDeclareType, std::make_tuple("CannotDeclareType"sv, "cannot declare a type here"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ClassInheritanceCycle, std::make_tuple("ClassInheritanceCycle"sv, "circular dependency in inheritance chain for class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumIncrementUnknown, std::make_tuple("EnumIncrementUnknown"sv, "cannot increment previous value {} because it has unknown bits"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumRangeMultiDimensional, std::make_tuple("EnumRangeMultiDimensional"sv, "enum range cannot be multidimensional"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumValueDuplicate, std::make_tuple("EnumValueDuplicate"sv, "redefinition of enum value {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumValueOutOfRange, std::make_tuple("EnumValueOutOfRange"sv, "enum value {} is out of range for base type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumValueOverflow, std::make_tuple("EnumValueOverflow"sv, "incrementing previous value {} would overflow enum base type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumValueUnknownBits, std::make_tuple("EnumValueUnknownBits"sv, "value of {} is invalid for enum with base type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ForwardTypedefDoesNotMatch, std::make_tuple("ForwardTypedefDoesNotMatch"sv, "forward typedef basic type '{}' does not match declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ForwardTypedefVisibility, std::make_tuple("ForwardTypedefVisibility"sv, "declared visibility of forward typedef does not match the visibility of the actual type declaration"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidArrayElemType, std::make_tuple("InvalidArrayElemType"sv, "cannot declare an array with elements of type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidArraySize, std::make_tuple("InvalidArraySize"sv, "{} is not a valid size for an array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidAssociativeIndexType, std::make_tuple("InvalidAssociativeIndexType"sv, "index type cannot be or contain floating point types"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidCoverageExpr, std::make_tuple("InvalidCoverageExpr"sv, "{} is not a valid type for a coverage expression"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidEnumBase, std::make_tuple("InvalidEnumBase"sv, "invalid enum base type {} (must be a single dimensional integer type)"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::InvalidUnionMember, std::make_tuple("InvalidUnionMember"sv, "untagged unions cannot have members of type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::MultiplePackedOpenArrays, std::make_tuple("MultiplePackedOpenArrays"sv, "cannot declare more than one packed dimension when using an open array"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveArgModify, std::make_tuple("NTResolveArgModify"sv, "resolution function for nettype '{}' cannot modify its input argument '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveClass, std::make_tuple("NTResolveClass"sv, "resolution function for nettype '{}' cannot be a non-static class method"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveReturn, std::make_tuple("NTResolveReturn"sv, "resolution function for nettype '{}' should have a return type of {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveSingleArg, std::make_tuple("NTResolveSingleArg"sv, "resolution function for nettype '{}' should have a single input argument of type {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveTask, std::make_tuple("NTResolveTask"sv, "resolution function for nettype '{}' cannot be a task"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::NTResolveUserDef, std::make_tuple("NTResolveUserDef"sv, "resolution function for nettype '{}' must be a normal user-defined function"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::ObjectTooLarge, std::make_tuple("ObjectTooLarge"sv, "object size exceeds implementation limit of 2^31 bytes"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedArrayNotIntegral, std::make_tuple("PackedArrayNotIntegral"sv, "packed array elements must be of integral type (not {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedDimsOnPredefinedType, std::make_tuple("PackedDimsOnPredefinedType"sv, "packed dimensions not allowed on predefined integer type '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedMemberHasInitializer, std::make_tuple("PackedMemberHasInitializer"sv, "packed members can not have initializers"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedMemberNotIntegral, std::make_tuple("PackedMemberNotIntegral"sv, "packed members must be of integral type (not {})"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedTypeTooLarge, std::make_tuple("PackedTypeTooLarge"sv, "packed type of {} bits is too large; maximum width is {} bits"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::PackedUnionWidthMismatch, std::make_tuple("PackedUnionWidthMismatch"sv, "all members of a packed union must have the same width; '{}' has width of {}, previously seen width was {}"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::RecursiveClassSpecialization, std::make_tuple("RecursiveClassSpecialization"sv, "potentially infinitely recursive specialization of class '{}'"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeRefHierarchical, std::make_tuple("TypeRefHierarchical"sv, "'type' expression cannot contain hierarchical references"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::TypeRefVoid, std::make_tuple("TypeRefVoid"sv, "cannot create a type reference to the 'void' type"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::VirtualInterfaceUnionMember, std::make_tuple("VirtualInterfaceUnionMember"sv, "virtual interfaces cannot be used as members of unions"sv, DiagnosticSeverity::Error, ""sv)},
    {diag::EnumRangeLiteral, std::make_tuple("EnumRangeLiteral"sv, "enum element ranges must be integer literals"sv, DiagnosticSeverity::Warning, "enum-range"sv)},
};

static const flat_hash_map<std::string_view, std::vector<DiagCode>> optionMap = {
    {"arith-op-mismatch"sv, { diag::ArithOpMismatch }},
    {"bad-procedural-force"sv, { diag::BadProceduralForce }},
    {"bitwise-op-mismatch"sv, { diag::BitwiseOpMismatch }},
    {"case-gen-dup"sv, { diag::CaseGenerateDup }},
    {"case-gen-none"sv, { diag::CaseGenerateNoBlock }},
    {"comparison-mismatch"sv, { diag::ComparisonMismatch }},
    {"constant-conversion"sv, { diag::ConstantConversion }},
    {"constraint-missing"sv, { diag::NoConstraintBody }},
    {"dpi-pure-task"sv, { diag::DPIPureTask }},
    {"dpi-spec"sv, { diag::DPISpecDisallowed }},
    {"dup-attr"sv, { diag::DuplicateAttribute }},
    {"dup-config-rule"sv, { diag::DupConfigRule }},
    {"dup-import"sv, { diag::DuplicateImport }},
    {"dup-timing-path"sv, { diag::DupTimingPath }},
    {"duplicate-definition"sv, { diag::DuplicateDefinition }},
    {"duplicate-defparam"sv, { diag::DuplicateDefparam }},
    {"dynarray-index"sv, { diag::ConstEvalDynamicArrayIndex }},
    {"dynarray-range"sv, { diag::ConstEvalDynamicArrayRange }},
    {"elem-not-found"sv, { diag::ConstEvalAssociativeElementNotFound }},
    {"empty-body"sv, { diag::EmptyBody }},
    {"empty-member"sv, { diag::EmptyMember }},
    {"empty-pattern"sv, { diag::EmptyAssignmentPattern }},
    {"empty-queue"sv, { diag::ConstEvalEmptyQueue }},
    {"empty-stmt"sv, { diag::EmptyStatement }},
    {"enum-range"sv, { diag::EnumRangeLiteral }},
    {"event-const"sv, { diag::EventExpressionConstant }},
    {"expected-diag-arg"sv, { diag::ExpectedDiagPragmaArg }},
    {"expected-protect-arg"sv, { diag::ExpectedProtectArg }},
    {"expected-protect-keyword"sv, { diag::ExpectedProtectKeyword }},
    {"explicit-static"sv, { diag::StaticInitializerMustBeExplicit }},
    {"extra-pragma-args"sv, { diag::ExtraPragmaArgs }},
    {"extra-protect-end"sv, { diag::ExtraProtectEnd }},
    {"finish-num"sv, { diag::BadFinishNum }},
    {"float-bool-conv"sv, { diag::FloatBoolConv }},
    {"float-int-conv"sv, { diag::FloatIntConv }},
    {"float-narrow"sv, { diag::FloatNarrow }},
    {"float-widen"sv, { diag::FloatWiden }},
    {"format-multibit-strength"sv, { diag::FormatMultibitStrength }},
    {"format-real"sv, { diag::FormatRealInt }},
    {"ignored-macro-paste"sv, { diag::IgnoredMacroPaste }},
    {"ignored-slice"sv, { diag::IgnoredSlice }},
    {"implicit-conv"sv, { diag::ImplicitConvert }},
    {"implicit-net-port"sv, { diag::ImplicitNetPortNoDefault }},
    {"implicit-port-type-mismatch"sv, { diag::ImplicitNamedPortTypeMismatch }},
    {"index-oob"sv, { diag::IndexOOB }},
    {"ineffective-sign"sv, { diag::SignednessNoEffect }},
    {"int-bool-conv"sv, { diag::IntBoolConv }},
    {"int-float-conv"sv, { diag::IntFloatConv }},
    {"int-overflow"sv, { diag::SignedIntegerOverflow }},
    {"invalid-encoding-byte"sv, { diag::InvalidEncodingByte }},
    {"invalid-pragma-number"sv, { diag::InvalidPragmaNumber }},
    {"invalid-pragma-viewport"sv, { diag::InvalidPragmaViewport }},
    {"invalid-pulsestyle"sv, { diag::InvalidPulseStyle }},
    {"invalid-source-encoding"sv, { diag::InvalidUTF8Seq }},
    {"isunbounded-param-arg"sv, { diag::IsUnboundedParamArg }},
    {"lifetime-prototype"sv, { diag::LifetimeForPrototype }},
    {"missing-format"sv, { diag::MissingFormatSpecifier }},
    {"missing-top"sv, { diag::NoTopModules }},
    {"multibit-edge"sv, { diag::MultiBitEdge }},
    {"negative-timing-limit"sv, { diag::NegativeTimingLimit }},
    {"nested-protect-begin"sv, { diag::NestedProtectBegin }},
    {"net-inconsistent"sv, { diag::NetInconsistent, diag::NetRangeInconsistent }},
    {"nonblocking-final"sv, { diag::NonblockingInFinal }},
    {"nonstandard-dist"sv, { diag::NonstandardDist }},
    {"nonstandard-escape-code"sv, { diag::NonstandardEscapeCode }},
    {"nonstandard-foreach"sv, { diag::NonstandardForeach }},
    {"nonstandard-generate"sv, { diag::NonStandardGenBlock }},
    {"nonstandard-sys-func"sv, { diag::NonstandardSysFunc }},
    {"pointless-void-cast"sv, { diag::PointlessVoidCast }},
    {"port-coercion"sv, { diag::InputPortCoercion, diag::OutputPortCoercion }},
    {"port-width-expand"sv, { diag::PortWidthExpand }},
    {"port-width-trunc"sv, { diag::PortWidthTruncate }},
    {"pragma-diag-level"sv, { diag::ExpectedDiagPragmaLevel }},
    {"protect-arglist"sv, { diag::ProtectArgList }},
    {"protect-encoding-bytes"sv, { diag::ProtectEncodingBytes }},
    {"protected-envelope"sv, { diag::ProtectedEnvelope }},
    {"queue-range"sv, { diag::ConstEvalQueueRange }},
    {"range-oob"sv, { diag::RangeOOB }},
    {"range-width-oob"sv, { diag::RangeWidthOOB }},
    {"raw-protect-eof"sv, { diag::RawProtectEOF }},
    {"real-overflow"sv, { diag::RealLiteralOverflow }},
    {"real-underflow"sv, { diag::RealLiteralUnderflow }},
    {"redef-macro"sv, { diag::RedefiningMacro }},
    {"reversed-range"sv, { diag::ReversedValueRange }},
    {"sign-compare"sv, { diag::SignCompare }},
    {"sign-conversion"sv, { diag::SignConversion }},
    {"specify-condition-expr"sv, { diag::SpecifyPathConditionExpr }},
    {"specify-param"sv, { diag::SpecifyBlockParam }},
    {"split-distweight-op"sv, { diag::SplitDistWeightOp }},
    {"static-init-order"sv, { diag::StaticInitOrder }},
    {"static-init-value"sv, { diag::StaticInitValue }},
    {"static-skipped"sv, { diag::ConstEvalStaticSkipped }},
    {"task-ignored"sv, { diag::ConstSysTaskIgnored }},
    {"udp-port-empty"sv, { diag::EmptyUdpPort }},
    {"unassigned-variable"sv, { diag::UnassignedVariable }},
    {"unconnected-port"sv, { diag::UnconnectedNamedPort }},
    {"unconnected-unnamed-port"sv, { diag::UnconnectedUnnamedPort }},
    {"undriven-net"sv, { diag::UndrivenNet }},
    {"undriven-port"sv, { diag::UndrivenPort }},
    {"unknown-diag-arg"sv, { diag::UnknownDiagPragmaArg }},
    {"unknown-escape-code"sv, { diag::UnknownEscapeCode }},
    {"unknown-library"sv, { diag::WarnUnknownLibrary }},
    {"unknown-pragma"sv, { diag::UnknownPragma }},
    {"unknown-protect-encoding"sv, { diag::UnknownProtectEncoding }},
    {"unknown-protect-keyword"sv, { diag::UnknownProtectKeyword }},
    {"unknown-protect-option"sv, { diag::UnknownProtectOption }},
    {"unknown-sys-name"sv, { diag::UnknownSystemName }},
    {"unknown-warning-option"sv, { diag::UnknownWarningOption }},
    {"unsigned-arith-shift"sv, { diag::UnsignedArithShift }},
    {"unsized-concat"sv, { diag::UnsizedInConcat }},
    {"unused-argument"sv, { diag::UnusedArgument }},
    {"unused-assertion-decl"sv, { diag::UnusedAssertionDecl }},
    {"unused-but-set-net"sv, { diag::UnusedButSetNet }},
    {"unused-but-set-port"sv, { diag::UnusedButSetPort }},
    {"unused-but-set-variable"sv, { diag::UnusedButSetVariable }},
    {"unused-config-cell"sv, { diag::UnusedConfigCell }},
    {"unused-config-instance"sv, { diag::UnusedConfigInstance }},
    {"unused-def"sv, { diag::UnusedDefinition }},
    {"unused-genvar"sv, { diag::UnusedGenvar }},
    {"unused-implicit-net"sv, { diag::UnusedImplicitNet }},
    {"unused-import"sv, { diag::UnusedImport }},
    {"unused-net"sv, { diag::UnusedNet }},
    {"unused-parameter"sv, { diag::UnusedParameter }},
    {"unused-port"sv, { diag::UnusedPort }},
    {"unused-result"sv, { diag::UnusedResult }},
    {"unused-type-parameter"sv, { diag::UnusedTypeParameter }},
    {"unused-typedef"sv, { diag::UnusedTypedef }},
    {"unused-variable"sv, { diag::UnusedVariable }},
    {"unused-wildcard-import"sv, { diag::UnusedWildcardImport }},
    {"useless-cast"sv, { diag::UselessCast }},
    {"vector-overflow"sv, { diag::VectorLiteralOverflow }},
    {"warning-task"sv, { diag::WarningTask }},
    {"width-expand"sv, { diag::WidthExpand }},
    {"width-trunc"sv, { diag::WidthTruncate }},
};

static const flat_hash_map<std::string_view, DiagGroup> groupMap = {
    {"conversion"sv, DiagGroup("conversion", { diag::ConstantConversion, diag::FloatBoolConv, diag::FloatIntConv, diag::FloatNarrow, diag::FloatWiden, diag::ImplicitConvert, diag::IntBoolConv, diag::IntFloatConv, diag::PortWidthExpand, diag::PortWidthTruncate, diag::SignConversion, diag::WidthExpand, diag::WidthTruncate })},
    {"default"sv, DiagGroup("default", { diag::BadProceduralForce, diag::NoConstraintBody, diag::DPIPureTask, diag::DPISpecDisallowed, diag::DupConfigRule, diag::DupTimingPath, diag::DuplicateDefinition, diag::DuplicateDefparam, diag::ConstEvalDynamicArrayIndex, diag::ConstEvalDynamicArrayRange, diag::ConstEvalAssociativeElementNotFound, diag::EmptyBody, diag::ConstEvalEmptyQueue, diag::EnumRangeLiteral, diag::ExpectedDiagPragmaArg, diag::ExpectedProtectArg, diag::ExpectedProtectKeyword, diag::StaticInitializerMustBeExplicit, diag::ExtraPragmaArgs, diag::ExtraProtectEnd, diag::BadFinishNum, diag::ImplicitConvert, diag::ImplicitNamedPortTypeMismatch, diag::IndexOOB, diag::SignedIntegerOverflow, diag::InvalidEncodingByte, diag::InvalidPragmaNumber, diag::InvalidPragmaViewport, diag::InvalidPulseStyle, diag::InvalidUTF8Seq, diag::LifetimeForPrototype, diag::MissingFormatSpecifier, diag::NoTopModules, diag::MultiBitEdge, diag::NegativeTimingLimit, diag::NestedProtectBegin, diag::NetInconsistent, diag::NetRangeInconsistent, diag::NonblockingInFinal, diag::InputPortCoercion, diag::OutputPortCoercion, diag::ExpectedDiagPragmaLevel, diag::ProtectArgList, diag::ProtectEncodingBytes, diag::ProtectedEnvelope, diag::ConstEvalQueueRange, diag::RangeOOB, diag::RangeWidthOOB, diag::RawProtectEOF, diag::RealLiteralOverflow, diag::RealLiteralUnderflow, diag::RedefiningMacro, diag::ReversedValueRange, diag::SpecifyPathConditionExpr, diag::SpecifyBlockParam, diag::SplitDistWeightOp, diag::ConstEvalStaticSkipped, diag::EmptyUdpPort, diag::UnconnectedNamedPort, diag::UnconnectedUnnamedPort, diag::UnknownDiagPragmaArg, diag::UnknownEscapeCode, diag::WarnUnknownLibrary, diag::UnknownPragma, diag::UnknownProtectEncoding, diag::UnknownProtectKeyword, diag::UnknownProtectOption, diag::UnknownSystemName, diag::UnknownWarningOption, diag::UnsizedInConcat, diag::UnusedConfigCell, diag::UnusedConfigInstance, diag::VectorLiteralOverflow, diag::WarningTask })},
    {"extra"sv, DiagGroup("extra", { diag::CaseGenerateDup, diag::CaseGenerateNoBlock, diag::ConstantConversion, diag::DuplicateAttribute, diag::DuplicateImport, diag::EmptyMember, diag::EmptyStatement, diag::EventExpressionConstant, diag::FloatBoolConv, diag::FloatIntConv, diag::FloatNarrow, diag::FormatRealInt, diag::IgnoredSlice, diag::SignednessNoEffect, diag::IntBoolConv, diag::PointlessVoidCast, diag::PortWidthTruncate, diag::StaticInitOrder, diag::StaticInitValue, diag::ConstSysTaskIgnored, diag::UnsignedArithShift, diag::UnusedResult, diag::UselessCast, diag::WidthTruncate })},
    {"pedantic"sv, DiagGroup("pedantic", { diag::EmptyAssignmentPattern, diag::FormatMultibitStrength, diag::ImplicitNetPortNoDefault, diag::IsUnboundedParamArg, diag::NonstandardDist, diag::NonstandardEscapeCode, diag::NonstandardForeach, diag::NonStandardGenBlock, diag::NonstandardSysFunc })},
    {"unused"sv, DiagGroup("unused", { diag::UnassignedVariable, diag::UndrivenNet, diag::UndrivenPort, diag::UnusedArgument, diag::UnusedAssertionDecl, diag::UnusedButSetNet, diag::UnusedButSetPort, diag::UnusedButSetVariable, diag::UnusedConfigCell, diag::UnusedConfigInstance, diag::UnusedDefinition, diag::UnusedGenvar, diag::UnusedImplicitNet, diag::UnusedImport, diag::UnusedNet, diag::UnusedParameter, diag::UnusedPort, diag::UnusedTypeParameter, diag::UnusedTypedef, diag::UnusedVariable, diag::UnusedWildcardImport })},
};

std::ostream& operator<<(std::ostream& os, DiagCode code) {
    os << toString(code);
    return os;
}

std::string_view toString(DiagCode code) {
    if (auto it = data.find(code); it != data.end())
        return std::get<0>(it->second);
    return "<user-diag>"sv;
}

std::string_view getDefaultMessage(DiagCode code) {
    if (auto it = data.find(code); it != data.end())
        return std::get<1>(it->second);
    return ""sv;
}

DiagnosticSeverity getDefaultSeverity(DiagCode code) {
    if (auto it = data.find(code); it != data.end())
        return std::get<2>(it->second);
    return DiagnosticSeverity::Ignored;
}

std::string_view getDefaultOptionName(DiagCode code) {
    if (auto it = data.find(code); it != data.end())
        return std::get<3>(it->second);
    return ""sv;
}

std::span<const DiagCode> findDiagsFromOptionName(std::string_view name) {
    if (auto it = optionMap.find(name); it != optionMap.end())
        return it->second;
    return {};
}

const DiagGroup* findDefaultDiagGroup(std::string_view name) {
    if (auto it = groupMap.find(name); it != groupMap.end())
        return &it->second;
    return nullptr;
}

static const DiagCode AllGeneratedCodes[] = {
    diag::BindTypeParamMismatch,
    diag::BindTypeParamNotFound,
    diag::ConfigParamsIgnored,
    diag::DPIExportDifferentScope,
    diag::DPIExportDuplicate,
    diag::DPIExportDuplicateCId,
    diag::DPIExportImportedFunc,
    diag::DPIExportKindMismatch,
    diag::DPISignatureMismatch,
    diag::DefParamCycle,
    diag::DefParamTargetChange,
    diag::ExternDeclMismatchImpl,
    diag::ExternDeclMismatchPrev,
    diag::InfinitelyRecursiveHierarchy,
    diag::InvalidBindTarget,
    diag::InvalidDPICIdentifier,
    diag::InvalidParamOverrideOpt,
    diag::InvalidTopModule,
    diag::MaxInstanceDepthExceeded,
    diag::MissingExportImpl,
    diag::MissingExternImpl,
    diag::MissingExternModuleImpl,
    diag::MissingTimeScale,
    diag::MultipleDefaultClocking,
    diag::MultipleDefaultDisable,
    diag::MultipleGlobalClocking,
    diag::MultipleTopDupName,
    diag::NestedConfigMultipleTops,
    diag::NoDeclInClass,
    diag::TopModuleIfacePort,
    diag::TopModuleRefPort,
    diag::TopModuleUnnamedRefPort,
    diag::UnknownLibrary,
    diag::WrongBindTargetDef,
    diag::DuplicateDefparam,
    diag::NoTopModules,
    diag::UnassignedVariable,
    diag::UndrivenNet,
    diag::UndrivenPort,
    diag::UnusedArgument,
    diag::UnusedAssertionDecl,
    diag::UnusedButSetNet,
    diag::UnusedButSetPort,
    diag::UnusedButSetVariable,
    diag::UnusedDefinition,
    diag::UnusedGenvar,
    diag::UnusedImplicitNet,
    diag::UnusedImport,
    diag::UnusedNet,
    diag::UnusedParameter,
    diag::UnusedPort,
    diag::UnusedTypeParameter,
    diag::UnusedTypedef,
    diag::UnusedVariable,
    diag::UnusedWildcardImport,
    diag::ConstEvalAssertionFailed,
    diag::ConstEvalAssociativeIndexInvalid,
    diag::ConstEvalBitstreamCastSize,
    diag::ConstEvalCaseItemsNotUnique,
    diag::ConstEvalCheckers,
    diag::ConstEvalClassType,
    diag::ConstEvalCovergroupType,
    diag::ConstEvalDPINotConstant,
    diag::ConstEvalDisableTarget,
    diag::ConstEvalDynamicToFixedSize,
    diag::ConstEvalExceededMaxCallDepth,
    diag::ConstEvalExceededMaxSteps,
    diag::ConstEvalFunctionArgDirection,
    diag::ConstEvalFunctionIdentifiersMustBeLocal,
    diag::ConstEvalFunctionInsideGenerate,
    diag::ConstEvalHierarchicalName,
    diag::ConstEvalIdUsedInCEBeforeDecl,
    diag::ConstEvalIfItemsNotUnique,
    diag::ConstEvalMethodNotConstant,
    diag::ConstEvalNoCaseItemsMatched,
    diag::ConstEvalNoIfItemsMatched,
    diag::ConstEvalNonConstVariable,
    diag::ConstEvalParallelBlockNotConst,
    diag::ConstEvalParamCycle,
    diag::ConstEvalProceduralAssign,
    diag::ConstEvalRandValue,
    diag::ConstEvalReplicationCountInvalid,
    diag::ConstEvalSubroutineNotConstant,
    diag::ConstEvalTaggedUnion,
    diag::ConstEvalTaskNotConstant,
    diag::ConstEvalTimedStmtNotConst,
    diag::ConstEvalVoidNotConstant,
    diag::NoteInCallTo,
    diag::NoteSkippingFrames,
    diag::ConstEvalAssociativeElementNotFound,
    diag::ConstEvalDynamicArrayIndex,
    diag::ConstEvalDynamicArrayRange,
    diag::ConstEvalEmptyQueue,
    diag::ConstEvalQueueRange,
    diag::ConstEvalStaticSkipped,
    diag::ConstSysTaskIgnored,
    diag::ConstantConversion,
    diag::AlwaysInChecker,
    diag::AnsiIfacePortDefault,
    diag::AssertionPortOutputDefault,
    diag::AssignedToLocalBodyParam,
    diag::AssignedToLocalPortParam,
    diag::AutomaticNotAllowed,
    diag::BadTypeParamExpr,
    diag::BaseConstructorDuplicate,
    diag::BaseConstructorNotCalled,
    diag::BiDiSwitchNetTypes,
    diag::BindTargetPrimitive,
    diag::BindUnderBind,
    diag::BodyForPure,
    diag::BodyForPureConstraint,
    diag::BodyParamNoInitializer,
    diag::CantDeclarePortSigned,
    diag::CheckerBlockingAssign,
    diag::CheckerClassBadInstantiation,
    diag::CheckerFuncArg,
    diag::CheckerFuncBadInstantiation,
    diag::CheckerInCheckerProc,
    diag::CheckerInForkJoin,
    diag::CheckerOutputBadType,
    diag::CheckerParameterAssign,
    diag::CheckerPortDirectionType,
    diag::CheckerTimingControl,
    diag::ConfigDupTop,
    diag::ConfigInstanceUnderOtherConfig,
    diag::ConfigInstanceWrongTop,
    diag::ConfigOverrideTop,
    diag::ConfigParamsForPrimitive,
    diag::ConstPortNotAllowed,
    diag::ConstVarNoInitializer,
    diag::ConstraintNotInClass,
    diag::CoverageBinTargetName,
    diag::CoverageOptionDup,
    diag::CoverageSetType,
    diag::CovergroupOutArg,
    diag::DPIPureArg,
    diag::DPIPureReturn,
    diag::DPIRefArg,
    diag::DefParamLocal,
    diag::DefParamTarget,
    diag::DefaultSuperArgLocalReference,
    diag::DefparamBadHierarchy,
    diag::Delay3OnVar,
    diag::DimensionRequiresConstRange,
    diag::DirectionWithInterfacePort,
    diag::DisallowedPortDefault,
    diag::DupInterfaceExternMethod,
    diag::DuplicateParamAssignment,
    diag::DuplicatePortConnection,
    diag::DuplicateWildcardPortConnection,
    diag::ErrorTask,
    diag::ExpectedImportExport,
    diag::ExtendClassFromIface,
    diag::ExtendFromFinal,
    diag::ExtendIfaceFromClass,
    diag::ExternFuncForkJoin,
    diag::ExternIfaceArrayMethod,
    diag::FatalTask,
    diag::GenvarDuplicate,
    diag::GenvarUnknownBits,
    diag::GlobalClockingGenerate,
    diag::IfaceMethodHidden,
    diag::IfaceMethodNoImpl,
    diag::IfaceMethodNotExtern,
    diag::IfaceMethodNotVirtual,
    diag::IfaceNameConflict,
    diag::IfacePortInExpr,
    diag::ImplementNonIface,
    diag::ImplicitConnNetInconsistent,
    diag::ImplicitNamedPortNotFound,
    diag::InOutPortCannotBeVariable,
    diag::InOutUWirePort,
    diag::InheritFromAbstract,
    diag::InheritFromAbstractConstraint,
    diag::InstanceMissingParens,
    diag::InstanceNameRequired,
    diag::InstanceWithDelay,
    diag::InstanceWithStrength,
    diag::InterconnectMultiPort,
    diag::InterconnectPortVar,
    diag::InterfacePortNotConnected,
    diag::InterfacePortTypeMismatch,
    diag::InvalidClockingSignal,
    diag::InvalidDPIArgType,
    diag::InvalidDPIReturnType,
    diag::InvalidDimensionRange,
    diag::InvalidInstanceForParent,
    diag::InvalidMethodOverride,
    diag::InvalidNGateCount,
    diag::InvalidNetType,
    diag::InvalidPortSubType,
    diag::InvalidPortType,
    diag::InvalidPrimInstanceForParent,
    diag::InvalidPrimitivePortConn,
    diag::InvalidRandType,
    diag::InvalidRandomizeOverride,
    diag::InvalidSpecifyDest,
    diag::InvalidSpecifyPath,
    diag::InvalidSpecifySource,
    diag::InvalidSpecifyType,
    diag::InvalidStmtInChecker,
    diag::InvalidTimingCheckNotifierArg,
    diag::InvalidUserDefinedNetType,
    diag::LocalParamNoInitializer,
    diag::LocalVarTypeRequired,
    diag::MaxGenerateStepsExceeded,
    diag::MaxInstanceArrayExceeded,
    diag::MemberDefinitionBeforeClass,
    diag::MethodArgCountMismatch,
    diag::MethodArgDefaultMismatch,
    diag::MethodArgDirectionMismatch,
    diag::MethodArgNameMismatch,
    diag::MethodArgNoDefault,
    diag::MethodArgTypeMismatch,
    diag::MethodKindMismatch,
    diag::MethodReturnMismatch,
    diag::MethodReturnTypeScoped,
    diag::MismatchConstraintSpecifiers,
    diag::MismatchStaticConstraint,
    diag::MismatchedTimeScales,
    diag::MismatchedUserDefPortConn,
    diag::MismatchedUserDefPortDir,
    diag::MissingExternWildcardPorts,
    diag::MissingPortIODeclaration,
    diag::MixingOrderedAndNamedParams,
    diag::MixingOrderedAndNamedPorts,
    diag::MixingSubroutinePortKinds,
    diag::ModportConnMismatch,
    diag::MultipleDefaultConstructorArg,
    diag::MultipleDefaultInputSkew,
    diag::MultipleDefaultOutputSkew,
    diag::NetAliasCommonNetType,
    diag::NetAliasHierarchical,
    diag::NetAliasNotANet,
    diag::NetAliasWidthMismatch,
    diag::NoChangeEdgeRequired,
    diag::NoMemberImplFound,
    diag::NotAChecker,
    diag::NotAClockingBlock,
    diag::NotAProduction,
    diag::NotAllowedInModport,
    diag::NullPortExpression,
    diag::OverridingFinal,
    diag::OverridingInitial,
    diag::PackageExportSelf,
    diag::PackageImportSelf,
    diag::PackageNetInit,
    diag::PackedDimsRequireFullRange,
    diag::ParallelPathWidth,
    diag::ParamHasNoValue,
    diag::ParameterDoesNotExist,
    diag::PathPulseInvalidPathName,
    diag::PortConcatInOut,
    diag::PortConcatRef,
    diag::PortConnDimensionsMismatch,
    diag::PortDeclDimensionsMismatch,
    diag::PortDeclInANSIModule,
    diag::PortDoesNotExist,
    diag::PortTypeNotInterfaceOrData,
    diag::PrimitiveAnsiMix,
    diag::PrimitiveDupInitial,
    diag::PrimitiveDupOutput,
    diag::PrimitiveInitVal,
    diag::PrimitiveInitialInComb,
    diag::PrimitiveOutputFirst,
    diag::PrimitivePortCountWrong,
    diag::PrimitivePortDup,
    diag::PrimitivePortMissing,
    diag::PrimitivePortUnknown,
    diag::PrimitiveRegDup,
    diag::PrimitiveRegInput,
    diag::PrimitiveTwoPorts,
    diag::PrimitiveWrongInitial,
    diag::PropertyPortInLet,
    diag::PropertyPortInSeq,
    diag::PureConstraintInAbstract,
    diag::PureInAbstract,
    diag::RandJoinNotNumeric,
    diag::RealCoverpointBins,
    diag::RealCoverpointDefaultArray,
    diag::RealCoverpointImplicit,
    diag::RealCoverpointTransBins,
    diag::RealCoverpointWildcardBins,
    diag::RealCoverpointWithExpr,
    diag::RefArgAutomaticFunc,
    diag::RefPortMustBeVariable,
    diag::RefPortUnconnected,
    diag::RefPortUnnamedUnconnected,
    diag::SingleBitVectored,
    diag::SpecifyPathMultiDim,
    diag::StaticAssert,
    diag::StaticConstNoInitializer,
    diag::SubroutinePortInitializer,
    diag::TimeScaleFirstInScope,
    diag::TimingCheckEventEdgeRequired,
    diag::TimingCheckEventNotAllowed,
    diag::TooManyParamAssignments,
    diag::TooManyPortConnections,
    diag::TypeRestrictionMismatch,
    diag::UdpAllX,
    diag::UdpDupDiffOutput,
    diag::UdpWrongInputCount,
    diag::UnknownCovergroupBase,
    diag::UnknownInterface,
    diag::UnknownModule,
    diag::UnknownPackage,
    diag::UnknownPrimitive,
    diag::UnknownSystemTimingCheck,
    diag::UnpackedArrayParamType,
    diag::UnusedPortDecl,
    diag::UserDefPortMixedConcat,
    diag::UserDefPortTwoSided,
    diag::VarDeclWithDelay,
    diag::VarWithInterfacePort,
    diag::VirtualArgCountMismatch,
    diag::VirtualArgDirectionMismatch,
    diag::VirtualArgNameMismatch,
    diag::VirtualArgNoDerivedDefault,
    diag::VirtualArgNoParentDefault,
    diag::VirtualArgTypeMismatch,
    diag::VirtualInterfaceIfaceMember,
    diag::VirtualKindMismatch,
    diag::VirtualReturnMismatch,
    diag::WildcardPortGenericIface,
    diag::InfoTask,
    diag::NoteCommonAncestor,
    diag::NoteComparisonReduces,
    diag::CaseGenerateDup,
    diag::CaseGenerateNoBlock,
    diag::DPISpecDisallowed,
    diag::DupConfigRule,
    diag::DupTimingPath,
    diag::DuplicateAttribute,
    diag::EmptyMember,
    diag::EmptyUdpPort,
    diag::ImplicitNamedPortTypeMismatch,
    diag::ImplicitNetPortNoDefault,
    diag::InvalidPulseStyle,
    diag::NetInconsistent,
    diag::NetRangeInconsistent,
    diag::NoConstraintBody,
    diag::SignednessNoEffect,
    diag::StaticInitOrder,
    diag::StaticInitValue,
    diag::StaticInitializerMustBeExplicit,
    diag::UnconnectedNamedPort,
    diag::UnconnectedUnnamedPort,
    diag::UnusedConfigCell,
    diag::UnusedConfigInstance,
    diag::WarnUnknownLibrary,
    diag::WarningTask,
    diag::ArgCannotBeEmpty,
    diag::ArgDoesNotExist,
    diag::AssertionArgNeedsRegExpr,
    diag::AssertionArgTypeMismatch,
    diag::AssertionArgTypeSequence,
    diag::AssertionDelayFormalType,
    diag::AssertionFuncArg,
    diag::AssertionOutputLocalVar,
    diag::AssertionPortTypedLValue,
    diag::AssignToCHandle,
    diag::AssignToNet,
    diag::AssignmentNotAllowed,
    diag::AssignmentPatternAssociativeType,
    diag::AssignmentPatternDynamicDefault,
    diag::AssignmentPatternDynamicType,
    diag::AssignmentPatternKeyDupDefault,
    diag::AssignmentPatternKeyDupName,
    diag::AssignmentPatternKeyDupValue,
    diag::AssignmentPatternKeyExpr,
    diag::AssignmentPatternLValueDynamic,
    diag::AssignmentPatternMissingElements,
    diag::AssignmentPatternNoContext,
    diag::AssignmentPatternNoMember,
    diag::AssignmentRequiresParens,
    diag::AssignmentToConstVar,
    diag::AutoFromNonBlockingTiming,
    diag::AutoFromNonProcedural,
    diag::AutoFromStaticInit,
    diag::AutoVarToRefStatic,
    diag::BadAssignment,
    diag::BadAssignmentPatternType,
    diag::BadBinaryExpression,
    diag::BadCastType,
    diag::BadConcatExpression,
    diag::BadConditionalExpression,
    diag::BadConversion,
    diag::BadIndexExpression,
    diag::BadIntegerCast,
    diag::BadReplicationExpression,
    diag::BadSetMembershipType,
    diag::BadSliceType,
    diag::BadStreamCast,
    diag::BadStreamContext,
    diag::BadStreamExprType,
    diag::BadStreamSize,
    diag::BadStreamSlice,
    diag::BadStreamSourceType,
    diag::BadStreamTargetType,
    diag::BadStreamWithOrder,
    diag::BadStreamWithType,
    diag::BadUnaryExpression,
    diag::BadValueRange,
    diag::BlockingAssignToFreeVar,
    diag::CHandleInAssertion,
    diag::CannotCompareTwoInstances,
    diag::CannotIndexScalar,
    diag::CantModifyConst,
    diag::ChainedMethodParens,
    diag::CheckerArgCannotBeEmpty,
    diag::ClassMemberInAssertion,
    diag::ClassPrivateMembersBitstream,
    diag::ClockVarAssignConcat,
    diag::ClockVarBadTiming,
    diag::ClockVarOutputRead,
    diag::ClockVarTargetAssign,
    diag::ConcatWithStringInt,
    diag::ConstVarToRef,
    diag::CopyClassTarget,
    diag::CoverOptionImmutable,
    diag::CoverageExprVar,
    diag::CoverageSampleFormal,
    diag::CycleDelayNonClock,
    diag::DistRealRangeWeight,
    diag::DuplicateArgAssignment,
    diag::DynamicNotProcedural,
    diag::EmptyArgNotAllowed,
    diag::EmptyConcatNotAllowed,
    diag::EnumValueSizeMismatch,
    diag::EventExprAssertionArg,
    diag::EventExpressionFuncArg,
    diag::ExpectedIterationExpression,
    diag::ExpectedIteratorName,
    diag::ExpectedNetDelay,
    diag::ExprMustBeIntegral,
    diag::ExpressionNotAssignable,
    diag::ExpressionNotCallable,
    diag::GateUDNTConn,
    diag::InOutUWireConn,
    diag::InOutVarPortConn,
    diag::IncDecNotAllowed,
    diag::IndexValueInvalid,
    diag::InputPortAssign,
    diag::InterconnectReference,
    diag::InterfacePortInvalidExpression,
    diag::InvalidArgumentExpr,
    diag::InvalidBinsMatches,
    diag::InvalidBinsTarget,
    diag::InvalidClassAccess,
    diag::InvalidExtendsDefault,
    diag::InvalidMemberAccess,
    diag::InvalidRefArg,
    diag::InvalidSuperNewDefault,
    diag::IteratorArgsWithoutWithClause,
    diag::LetHierarchical,
    diag::LocalFormalVarMultiAssign,
    diag::LocalVarEventExpr,
    diag::LocalVarOutputEmptyMatch,
    diag::MissingConstraintBlock,
    diag::MissingInvocationParens,
    diag::MissingReturnValue,
    diag::MissingReturnValueProd,
    diag::MixedVarAssigns,
    diag::MixingOrderedAndNamedArgs,
    diag::MultipleAlwaysAssigns,
    diag::MultipleContAssigns,
    diag::MultipleDefaultDistWeight,
    diag::MultipleUDNTDrivers,
    diag::MultipleUWireDrivers,
    diag::NameListWithScopeRandomize,
    diag::NamedArgNotAllowed,
    diag::NewArrayTarget,
    diag::NewClassTarget,
    diag::NewInterfaceClass,
    diag::NewVirtualClass,
    diag::NoCommonComparisonType,
    diag::NoImplicitConversion,
    diag::NonProceduralFuncArg,
    diag::NonblockingAssignmentToAuto,
    diag::NonblockingDynamicAssign,
    diag::NotBooleanConvertible,
    diag::PathPulseInExpr,
    diag::PatternStructTooFew,
    diag::PatternStructTooMany,
    diag::PatternStructType,
    diag::PatternTaggedType,
    diag::PortConnArrayMismatch,
    diag::RangeSelectAssociative,
    diag::RangeWidthOverflow,
    diag::RecursiveLet,
    diag::RecursivePropArgExpr,
    diag::RecursivePropNegation,
    diag::RecursivePropTimeAdvance,
    diag::RecursiveSequence,
    diag::RefArgForkJoin,
    diag::RefTypeMismatch,
    diag::ReplicationZeroOutsideConcat,
    diag::SelectAfterRangeSelect,
    diag::SelectEndianDynamic,
    diag::SelectEndianMismatch,
    diag::SelectOfVectoredNet,
    diag::SpecifyPathBadReference,
    diag::SpecparamInConstant,
    diag::TaggedUnionMissingInit,
    diag::TaggedUnionTarget,
    diag::TaskFromFinal,
    diag::TaskFromFunction,
    diag::TimingControlNotAllowed,
    diag::TooFewArguments,
    diag::TooManyArguments,
    diag::UnboundedNotAllowed,
    diag::UnconnectedArg,
    diag::UnexpectedClockingExpr,
    diag::UnexpectedConstraintBlock,
    diag::UnexpectedWithClause,
    diag::UnpackedConcatAssociative,
    diag::UnpackedConcatSize,
    diag::UserDefPartialDriver,
    diag::ValueRangeUnbounded,
    diag::VirtualIfaceDefparam,
    diag::VoidAssignment,
    diag::WithClauseNotAllowed,
    diag::WrongNumberAssignmentPatterns,
    diag::ArithOpMismatch,
    diag::BitwiseOpMismatch,
    diag::ComparisonMismatch,
    diag::FloatBoolConv,
    diag::FloatIntConv,
    diag::FloatNarrow,
    diag::FloatWiden,
    diag::IgnoredSlice,
    diag::ImplicitConvert,
    diag::IndexOOB,
    diag::InputPortCoercion,
    diag::IntBoolConv,
    diag::IntFloatConv,
    diag::NegativeTimingLimit,
    diag::NonblockingInFinal,
    diag::OutputPortCoercion,
    diag::PortWidthExpand,
    diag::PortWidthTruncate,
    diag::RangeOOB,
    diag::RangeWidthOOB,
    diag::ReversedValueRange,
    diag::SignCompare,
    diag::SignConversion,
    diag::SpecifyBlockParam,
    diag::SpecifyPathConditionExpr,
    diag::UnsignedArithShift,
    diag::UnsizedInConcat,
    diag::UselessCast,
    diag::WidthExpand,
    diag::WidthTruncate,
    diag::AttributesNotAllowed,
    diag::ExpectedExpression,
    diag::WrongLanguageVersion,
    diag::NoteAssignedHere,
    diag::NoteConfigRule,
    diag::NoteDeclarationHere,
    diag::NoteDrivenHere,
    diag::NoteFromHere2,
    diag::NoteOriginalAssign,
    diag::NotePreviousDefinition,
    diag::NotePreviousMatch,
    diag::NotePreviousUsage,
    diag::NoteReferencedHere,
    diag::BadBinaryDigit,
    diag::BadDecimalDigit,
    diag::BadHexDigit,
    diag::BadOctalDigit,
    diag::DecimalDigitMultipleUnknown,
    diag::EmbeddedNull,
    diag::EscapedWhitespace,
    diag::ExpectedClosingQuote,
    diag::ExpectedIntegerBaseAfterSigned,
    diag::InvalidHexEscapeCode,
    diag::MisplacedDirectiveChar,
    diag::NestedBlockComment,
    diag::NonPrintableChar,
    diag::OctalEscapeCodeTooBig,
    diag::TooManyLexerErrors,
    diag::UTF8Char,
    diag::UnicodeBOM,
    diag::UnterminatedBlockComment,
    diag::InvalidEncodingByte,
    diag::InvalidUTF8Seq,
    diag::NonstandardEscapeCode,
    diag::ProtectEncodingBytes,
    diag::RawProtectEOF,
    diag::UnknownEscapeCode,
    diag::AmbiguousWildcardImport,
    diag::AutoVariableHierarchical,
    diag::BadInstanceArrayRange,
    diag::CheckerHierarchical,
    diag::CompilationUnitFromPackage,
    diag::CouldNotResolveHierarchicalPath,
    diag::DefinitionUsedAsType,
    diag::DefinitionUsedAsValue,
    diag::DotIntoInstArray,
    diag::DotOnType,
    diag::GenericClassScopeResolution,
    diag::HierarchicalFromPackage,
    diag::IfaceExtendIncomplete,
    diag::IfaceExtendTypeParam,
    diag::IfaceImportExportTarget,
    diag::IllegalReferenceToProgramItem,
    diag::ImportNameCollision,
    diag::InstanceArrayEndianMismatch,
    diag::InvalidConstructorAccess,
    diag::InvalidHierarchicalIfacePortConn,
    diag::InvalidModportAccess,
    diag::InvalidScopeIndexExpression,
    diag::InvalidThisHandle,
    diag::LocalMemberAccess,
    diag::LocalNotAllowed,
    diag::NestedNonStaticClassMethod,
    diag::NestedNonStaticClassProperty,
    diag::NoDefaultSpecialization,
    diag::NonStaticClassMethod,
    diag::NonStaticClassProperty,
    diag::NotAClass,
    diag::NotAGenericClass,
    diag::NotAGenvar,
    diag::NotAHierarchicalScope,
    diag::NotAModport,
    diag::NotASubroutine,
    diag::NotAType,
    diag::NotAValue,
    diag::NotAnInterface,
    diag::NotAnInterfaceOrPort,
    diag::ProtectedMemberAccess,
    diag::RecursiveDefinition,
    diag::Redefinition,
    diag::RedefinitionDifferentType,
    diag::ScopeIncompleteTypedef,
    diag::ScopeIndexOutOfRange,
    diag::ScopeNotIndexable,
    diag::SuperNoBase,
    diag::SuperOutsideClass,
    diag::TypeHierarchical,
    diag::TypoIdentifier,
    diag::UndeclaredButFoundPackage,
    diag::UndeclaredIdentifier,
    diag::UnexpectedNameToken,
    diag::UnexpectedSelection,
    diag::UnknownClassMember,
    diag::UnknownClassOrPackage,
    diag::UnknownCovergroupMember,
    diag::UnknownMember,
    diag::UnknownPackageMember,
    diag::UnknownSystemMethod,
    diag::UnresolvedForwardTypedef,
    diag::UsedBeforeDeclared,
    diag::NoteImportedFrom,
    diag::DuplicateDefinition,
    diag::DuplicateImport,
    diag::UnknownSystemName,
    diag::TooManyErrors,
    diag::UnknownWarningOption,
    diag::DigitsLeadingUnderscore,
    diag::ExpectedVectorDigits,
    diag::LiteralSizeIsZero,
    diag::LiteralSizeTooLarge,
    diag::MissingExponentDigits,
    diag::MissingFractionalDigits,
    diag::ValueExceedsMaxBitWidth,
    diag::ValueMustBeIntegral,
    diag::ValueMustBePositive,
    diag::ValueMustNotBeUnknown,
    diag::ValueOutOfRange,
    diag::RealLiteralOverflow,
    diag::RealLiteralUnderflow,
    diag::SignedIntegerOverflow,
    diag::VectorLiteralOverflow,
    diag::AssertionPortDirNoLocal,
    diag::AssertionPortPropOutput,
    diag::AssertionPortRef,
    diag::BindDirectiveInvalidName,
    diag::CaseGenerateEmpty,
    diag::CaseStatementEmpty,
    diag::ChargeWithTriReg,
    diag::CheckerPortInout,
    diag::ClassSpecifierConflict,
    diag::ClockingNameEmpty,
    diag::ConfigMissingName,
    diag::ConfigParamLiteral,
    diag::ConfigParamsOrdered,
    diag::ConfigSpecificCellLiblist,
    diag::ConstFunctionPortRequiresRef,
    diag::ConstraintQualOutOfBlock,
    diag::ConstructorOutsideClass,
    diag::ConstructorReturnType,
    diag::CoverCrossItems,
    diag::CoverageBinDefSeqSize,
    diag::CoverageBinDefaultIgnore,
    diag::CoverageBinDefaultWildcard,
    diag::CoverageBinTransSize,
    diag::DeclModifierConflict,
    diag::DeclModifierOrdering,
    diag::DeclarationsAtStart,
    diag::DefaultArgNotAllowed,
    diag::DeferredDelayMustBeZero,
    diag::Delay3NotAllowed,
    diag::Delay3UdpNotAllowed,
    diag::DelaysNotAllowed,
    diag::DerivedCovergroupNoBase,
    diag::DerivedCovergroupNotInClass,
    diag::DirectionOnInterfacePort,
    diag::DriveStrengthHighZ,
    diag::DriveStrengthInvalid,
    diag::DriveStrengthNotAllowed,
    diag::DuplicateClassSpecifier,
    diag::DuplicateDeclModifier,
    diag::DuplicateQualifier,
    diag::EdgeDescWrongKeyword,
    diag::EndNameMismatch,
    diag::EndNameNotEmpty,
    diag::ExpectedAnsiPort,
    diag::ExpectedArgument,
    diag::ExpectedAssertionItemPort,
    diag::ExpectedAssignmentKey,
    diag::ExpectedAttribute,
    diag::ExpectedCaseItem,
    diag::ExpectedClassSpecifier,
    diag::ExpectedClockingSkew,
    diag::ExpectedConditionalPattern,
    diag::ExpectedConstraintName,
    diag::ExpectedContinuousAssignment,
    diag::ExpectedDPISpecString,
    diag::ExpectedDeclarator,
    diag::ExpectedDistItem,
    diag::ExpectedEdgeDescriptor,
    diag::ExpectedEnumBase,
    diag::ExpectedForInitializer,
    diag::ExpectedFunctionPort,
    diag::ExpectedFunctionPortList,
    diag::ExpectedGenvarIterVar,
    diag::ExpectedHierarchicalInstantiation,
    diag::ExpectedIdentifier,
    diag::ExpectedIfOrCase,
    diag::ExpectedIntegerLiteral,
    diag::ExpectedInterfaceClassName,
    diag::ExpectedMember,
    diag::ExpectedModportPort,
    diag::ExpectedNetStrength,
    diag::ExpectedNonAnsiPort,
    diag::ExpectedPackageImport,
    diag::ExpectedParameterPort,
    diag::ExpectedPathOp,
    diag::ExpectedPattern,
    diag::ExpectedPortConnection,
    diag::ExpectedPortList,
    diag::ExpectedRsRule,
    diag::ExpectedSampleKeyword,
    diag::ExpectedStatement,
    diag::ExpectedStreamExpression,
    diag::ExpectedStringLiteral,
    diag::ExpectedSubroutineName,
    diag::ExpectedToken,
    diag::ExpectedUdpPort,
    diag::ExpectedUdpSymbol,
    diag::ExpectedValueRangeElement,
    diag::ExpectedVariableAssignment,
    diag::ExternWildcardPortList,
    diag::FinalSpecifierLast,
    diag::FinalWithPure,
    diag::GlobalClockingEmpty,
    diag::IfNoneEdgeSensitive,
    diag::IfaceMethodPure,
    diag::ImplicitNotAllowed,
    diag::InOutDefaultSkew,
    diag::InitializerRequired,
    diag::InterconnectDelaySyntax,
    diag::InterconnectInitializer,
    diag::InterconnectTypeSyntax,
    diag::InvalidAccessDotColon,
    diag::InvalidConstraintQualifier,
    diag::InvalidCoverageOption,
    diag::InvalidDelayValue,
    diag::InvalidDistExpression,
    diag::InvalidEdgeDescriptor,
    diag::InvalidForInitializer,
    diag::InvalidGenvarIterExpression,
    diag::InvalidMethodQualifier,
    diag::InvalidPackageDecl,
    diag::InvalidPropertyIndex,
    diag::InvalidPropertyQualifier,
    diag::InvalidPropertyRange,
    diag::InvalidPullStrength,
    diag::InvalidQualifierForConstructor,
    diag::InvalidQualifierForIfaceMember,
    diag::InvalidQualifierForMember,
    diag::InvalidRepeatRange,
    diag::InvalidSuperNew,
    diag::LabelAndName,
    diag::MethodStaticLifetime,
    diag::MisplacedTrailingSeparator,
    diag::MissingModportPortDirection,
    diag::MultipleDefaultCases,
    diag::MultipleDefaultRules,
    diag::MultipleGenerateDefaultCases,
    diag::MultipleParallelTerminals,
    diag::NestedIface,
    diag::NewKeywordQualified,
    diag::NoCommaInList,
    diag::NoLabelOnSemicolon,
    diag::NotAllowedInAnonymousProgram,
    diag::NotAllowedInCU,
    diag::NotAllowedInChecker,
    diag::NotAllowedInClass,
    diag::NotAllowedInClocking,
    diag::NotAllowedInGenerate,
    diag::NotAllowedInIfaceClass,
    diag::NotAllowedInInterface,
    diag::NotAllowedInModule,
    diag::NotAllowedInPackage,
    diag::NotAllowedInProgram,
    diag::OverridingExtends,
    diag::PackedDimsOnUnpacked,
    diag::ParseTreeTooDeep,
    diag::PullStrengthHighZ,
    diag::PulseControlPATHPULSE,
    diag::PulseControlSpecifyParent,
    diag::PureRequiresVirtual,
    diag::QualifierConflict,
    diag::QualifierNotFirst,
    diag::QualifiersOnOutOfBlock,
    diag::RandJoinNotEnough,
    diag::RandJoinProdItem,
    diag::RandOnPackedMember,
    diag::RandOnUnionMember,
    diag::RegAfterNettype,
    diag::ScopedClassCopy,
    diag::SolveBeforeDisallowed,
    diag::SpecifiersNotAllowed,
    diag::StaticFuncSpecifier,
    diag::SubroutinePrototypeScoped,
    diag::TaggedStruct,
    diag::TaskConstructor,
    diag::TaskReturnType,
    diag::TooManyEdgeDescriptors,
    diag::TypeRefDeclVar,
    diag::UdpCombState,
    diag::UdpDupTransition,
    diag::UdpEdgeInComb,
    diag::UdpInvalidEdgeSymbol,
    diag::UdpInvalidInputOnly,
    diag::UdpInvalidMinus,
    diag::UdpInvalidOutput,
    diag::UdpInvalidSymbol,
    diag::UdpInvalidTransition,
    diag::UdpSequentialState,
    diag::UdpSingleChar,
    diag::UdpTransSameChar,
    diag::UdpTransitionLength,
    diag::UnexpectedEndDelim,
    diag::UnexpectedLetPortKeyword,
    diag::UnexpectedQualifiers,
    diag::UniquePriorityAfterElse,
    diag::UnpackedSigned,
    diag::VoidNotAllowed,
    diag::WireDataType,
    diag::WrongSpecifyDelayCount,
    diag::NoteLastBlockEnded,
    diag::NoteLastBlockStarted,
    diag::NoteToMatchThis,
    diag::DPIPureTask,
    diag::EmptyAssignmentPattern,
    diag::EmptyBody,
    diag::LifetimeForPrototype,
    diag::NonStandardGenBlock,
    diag::NonstandardDist,
    diag::NonstandardForeach,
    diag::SplitDistWeightOp,
    diag::CouldNotOpenIncludeFile,
    diag::DirectiveInsideDesignElement,
    diag::ExceededMaxIncludeDepth,
    diag::ExpectedDriveStrength,
    diag::ExpectedIncludeFileName,
    diag::ExpectedMacroArgs,
    diag::ExpectedMacroStringifyEnd,
    diag::ExpectedNetType,
    diag::ExpectedPragmaExpression,
    diag::ExpectedPragmaName,
    diag::ExpectedTimeLiteral,
    diag::InvalidInferredTimeScale,
    diag::InvalidLineDirectiveLevel,
    diag::InvalidMacroName,
    diag::InvalidTimeScalePrecision,
    diag::InvalidTimeScaleSpecifier,
    diag::MacroOpsOutsideDefinition,
    diag::MacroTokensAfterPragmaProtect,
    diag::MismatchedEndKeywordsDirective,
    diag::MissingEndIfDirective,
    diag::NotEnoughMacroArgs,
    diag::RecursiveMacro,
    diag::TooManyActualMacroArgs,
    diag::UnbalancedMacroArgDims,
    diag::UndefineBuiltinDirective,
    diag::UnexpectedConditionalDirective,
    diag::UnknownDirective,
    diag::UnrecognizedKeywordVersion,
    diag::NoteDirectiveHere,
    diag::ExpectedDiagPragmaArg,
    diag::ExpectedDiagPragmaLevel,
    diag::ExpectedProtectArg,
    diag::ExpectedProtectKeyword,
    diag::ExtraPragmaArgs,
    diag::ExtraProtectEnd,
    diag::IgnoredMacroPaste,
    diag::InvalidPragmaNumber,
    diag::InvalidPragmaViewport,
    diag::NestedProtectBegin,
    diag::ProtectArgList,
    diag::ProtectedEnvelope,
    diag::RedefiningMacro,
    diag::UnknownDiagPragmaArg,
    diag::UnknownPragma,
    diag::UnknownProtectEncoding,
    diag::UnknownProtectKeyword,
    diag::UnknownProtectOption,
    diag::AlwaysFFEventControl,
    diag::AssertionExprType,
    diag::BadDisableSoft,
    diag::BadForceNetType,
    diag::BadProceduralAssign,
    diag::BadSolveBefore,
    diag::BadUniquenessType,
    diag::BlockingInAlwaysFF,
    diag::CaseInsideKeyword,
    diag::ClockVarSyncDrive,
    diag::ClockingBlockEventEdge,
    diag::ConcurrentAssertActionBlock,
    diag::CoverStmtNoFail,
    diag::DeferredAssertAutoRefArg,
    diag::DeferredAssertNonVoid,
    diag::DeferredAssertOutArg,
    diag::DelayNotNumeric,
    diag::DisableIffLocalVar,
    diag::DisableIffMatched,
    diag::ExprNotConstraint,
    diag::ExprNotStatement,
    diag::ForeachDynamicDimAfterSkipped,
    diag::ForeachWildcardIndex,
    diag::ForkJoinAlwaysComb,
    diag::GlobalSampledValueNested,
    diag::InequivalentUniquenessTypes,
    diag::InvalidBlockEventTarget,
    diag::InvalidCommaInPropExpr,
    diag::InvalidConstraintExpr,
    diag::InvalidDeferredAssertAction,
    diag::InvalidDisableTarget,
    diag::InvalidEventExpression,
    diag::InvalidForStepExpression,
    diag::InvalidMatchItem,
    diag::InvalidSignalEventInSeq,
    diag::InvalidSyntaxInEventExpr,
    diag::InvalidUniquenessExpr,
    diag::LocalVarMatchItem,
    diag::LoopVarShadowsArray,
    diag::MatchItemsAdmitEmpty,
    diag::NestedDisableIff,
    diag::NoDefaultClocking,
    diag::NonIntegralConstraintLiteral,
    diag::NotAnArray,
    diag::NotAnEvent,
    diag::OutRefFuncConstraint,
    diag::PropAbortLocalVar,
    diag::PropAbortMatched,
    diag::PropExprInSequence,
    diag::PropInstanceRepetition,
    diag::PropertyLhsInvalid,
    diag::RandCInDist,
    diag::RandCInSoft,
    diag::RandCInSolveBefore,
    diag::RandCInUnique,
    diag::RandNeededInDist,
    diag::RecursivePropDisableIff,
    diag::RepeatControlNotEvent,
    diag::RepeatNotNumeric,
    diag::RestrictStmtNoFail,
    diag::ReturnInParallel,
    diag::ReturnNotInSubroutine,
    diag::SeqEmptyMatch,
    diag::SeqInstanceRepetition,
    diag::SeqNoMatch,
    diag::SeqOnlyEmpty,
    diag::SeqRangeMinMax,
    diag::StatementNotInLoop,
    diag::SubroutineMatchAutoRefArg,
    diag::SubroutineMatchNonVoid,
    diag::SubroutineMatchOutArg,
    diag::TaskInConstraint,
    diag::ThroughoutLhsInvalid,
    diag::TimingInFuncNotAllowed,
    diag::TooManyForeachVars,
    diag::UnexpectedPortDecl,
    diag::UnknownConstraintLiteral,
    diag::VoidCastFuncCall,
    diag::WriteToInputClockVar,
    diag::NoteExpandedHere,
    diag::NoteWhileExpanding,
    diag::BadProceduralForce,
    diag::EmptyStatement,
    diag::EventExpressionConstant,
    diag::MultiBitEdge,
    diag::PointlessVoidCast,
    diag::UnusedResult,
    diag::ArrayLocatorWithClause,
    diag::ArrayMethodComparable,
    diag::ArrayMethodIntegral,
    diag::AssociativeWildcardNotAllowed,
    diag::AutoVarTraced,
    diag::BadSystemSubroutineArg,
    diag::DimensionIndexInvalid,
    diag::DynamicDimensionIndex,
    diag::ExpectedClassPropertyName,
    diag::ExpectedModOrVarName,
    diag::ExpectedModuleInstance,
    diag::ExpectedModuleName,
    diag::ExpectedNetRef,
    diag::ExpectedScopeName,
    diag::ExpectedScopeOrAssert,
    diag::ExpectedVariableName,
    diag::FormatEmptyArg,
    diag::FormatMismatchedType,
    diag::FormatNoArgument,
    diag::FormatSpecifierInvalidWidth,
    diag::FormatSpecifierNotFloat,
    diag::FormatSpecifierWidthNotAllowed,
    diag::FormatTooManyArgs,
    diag::FormatUnspecifiedType,
    diag::GlobalClockEventExpr,
    diag::GlobalSampledValueAssertionExpr,
    diag::InferredValDefArg,
    diag::InvalidStringArg,
    diag::NoGlobalClocking,
    diag::PastNumTicksInvalid,
    diag::PlaRangeInAscendingOrder,
    diag::QueryOnAssociativeNonIntegral,
    diag::QueryOnAssociativeWildcard,
    diag::QueryOnDynamicType,
    diag::SampledValueLocalVar,
    diag::SampledValueMatched,
    diag::SeqMethodInputLocalVar,
    diag::SequenceMethodLocalVar,
    diag::SysFuncHierarchicalNotAllowed,
    diag::SysFuncNotConst,
    diag::TypeIsNotAClass,
    diag::UnknownFormatSpecifier,
    diag::BadFinishNum,
    diag::FormatMultibitStrength,
    diag::FormatRealInt,
    diag::IsUnboundedParamArg,
    diag::MissingFormatSpecifier,
    diag::NonstandardSysFunc,
    diag::ArrayDimTooLarge,
    diag::CannotDeclareType,
    diag::ClassInheritanceCycle,
    diag::EnumIncrementUnknown,
    diag::EnumRangeMultiDimensional,
    diag::EnumValueDuplicate,
    diag::EnumValueOutOfRange,
    diag::EnumValueOverflow,
    diag::EnumValueUnknownBits,
    diag::ForwardTypedefDoesNotMatch,
    diag::ForwardTypedefVisibility,
    diag::InvalidArrayElemType,
    diag::InvalidArraySize,
    diag::InvalidAssociativeIndexType,
    diag::InvalidCoverageExpr,
    diag::InvalidEnumBase,
    diag::InvalidUnionMember,
    diag::MultiplePackedOpenArrays,
    diag::NTResolveArgModify,
    diag::NTResolveClass,
    diag::NTResolveReturn,
    diag::NTResolveSingleArg,
    diag::NTResolveTask,
    diag::NTResolveUserDef,
    diag::ObjectTooLarge,
    diag::PackedArrayNotIntegral,
    diag::PackedDimsOnPredefinedType,
    diag::PackedMemberHasInitializer,
    diag::PackedMemberNotIntegral,
    diag::PackedTypeTooLarge,
    diag::PackedUnionWidthMismatch,
    diag::RecursiveClassSpecialization,
    diag::TypeRefHierarchical,
    diag::TypeRefVoid,
    diag::VirtualInterfaceUnionMember,
    diag::EnumRangeLiteral,
};

decltype(DiagCode::KnownCodes) DiagCode::KnownCodes = AllGeneratedCodes;

}